@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2002-2005 MySQL AB
+ Copyright  2002-2005 MySQL AB, 2008 Sun Microsystems
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License as 
@@ -25,15 +25,13 @@
 package com.mysql.jdbc;
 
 import java.io.UnsupportedEncodingException;
-
 import java.nio.ByteBuffer;
-
 import java.sql.SQLException;
 
 /**
  * Buffer contains code to read and write packets from/to the MySQL server.
  * 
- * @version $Id: Buffer.java 6445 2007-06-07 15:25:59Z mmatthews $
+ * @version $Id$
  * @author Mark Matthews
  */
 class Buffer {
@@ -424,7 +422,7 @@ class Buffer {
 		return s;
 	}
 
-	final String readString(String encoding) throws SQLException {
+	final String readString(String encoding, ExceptionInterceptor exceptionInterceptor) throws SQLException {
 		int i = this.position;
 		int len = 0;
 		int maxLen = getBufLength();
@@ -438,7 +436,7 @@ class Buffer {
 			return new String(this.byteBuffer, this.position, len, encoding);
 		} catch (UnsupportedEncodingException uEE) {
 			throw SQLError.createSQLException(Messages.getString("ByteArrayBuffer.1") //$NON-NLS-1$
-					+ encoding + "'", SQLError.SQL_STATE_ILLEGAL_ARGUMENT); //$NON-NLS-1$
+					+ encoding + "'", SQLError.SQL_STATE_ILLEGAL_ARGUMENT, exceptionInterceptor); //$NON-NLS-1$
 		} finally {
 			this.position += (len + 1); // update cursor
 		}
@@ -582,7 +580,7 @@ class Buffer {
 			b = converter.toBytes(s);
 		} else {
 			b = StringUtils.getBytes(s, encoding, serverEncoding,
-					parserKnowsUnicode, conn);
+					parserKnowsUnicode, conn, conn.getExceptionInterceptor());
 		}
 
 		int len = b.length;
@@ -663,7 +661,7 @@ class Buffer {
 			String serverEncoding, boolean parserKnowsUnicode, ConnectionImpl conn)
 			throws UnsupportedEncodingException, SQLException {
 		byte[] b = StringUtils.getBytes(s, encoding, serverEncoding,
-				parserKnowsUnicode, conn);
+				parserKnowsUnicode, conn, conn.getExceptionInterceptor());
 
 		int len = b.length;
 		ensureCapacity(len);
