@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2007 MySQL AB
+ Copyright  2007 MySQL AB, 2008 Sun Microsystems
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License as 
@@ -96,8 +96,10 @@ public class BufferRow extends ResultSetRow {
 
 	private List openStreams;
 
-	public BufferRow(Buffer buf, Field[] fields, boolean isBinaryEncoded)
+	public BufferRow(Buffer buf, Field[] fields, boolean isBinaryEncoded, ExceptionInterceptor exceptionInterceptor)
 			throws SQLException {
+		super(exceptionInterceptor);
+		
 		this.rowFromServer = buf;
 		this.metadata = fields;
 		this.isBinaryEncoded = isBinaryEncoded;
@@ -283,7 +285,7 @@ public class BufferRow extends ResultSetRow {
 						+ Messages.getString("MysqlIO.99") //$NON-NLS-1$ //$NON-NLS-2$
 						+ this.metadata.length
 						+ Messages.getString("MysqlIO.100"), //$NON-NLS-1$
-						SQLError.SQL_STATE_GENERAL_ERROR);
+						SQLError.SQL_STATE_GENERAL_ERROR, this.exceptionInterceptor);
 			}
 		}
 
@@ -380,7 +382,7 @@ public class BufferRow extends ResultSetRow {
 					+ (index + 1)
 					+ Messages.getString("MysqlIO.99") //$NON-NLS-1$ //$NON-NLS-2$
 					+ this.metadata.length + Messages.getString("MysqlIO.100"), //$NON-NLS-1$
-					SQLError.SQL_STATE_GENERAL_ERROR);
+					SQLError.SQL_STATE_GENERAL_ERROR, this.exceptionInterceptor);
 		}
 	}
 
@@ -503,7 +505,7 @@ public class BufferRow extends ResultSetRow {
 			return new InputStreamReader(stream, this.metadata[columnIndex]
 					.getCharacterSet());
 		} catch (UnsupportedEncodingException e) {
-			SQLException sqlEx = SQLError.createSQLException("");
+			SQLException sqlEx = SQLError.createSQLException("", this.exceptionInterceptor);
 
 			sqlEx.initCause(e);
 
@@ -600,8 +602,11 @@ public class BufferRow extends ResultSetRow {
 			return false;
 		}
 
+		int offset = this.rowFromServer.getPosition();
+		byte[] buffer = this.rowFromServer.getByteBuffer();
+		
 		for (int i = 0; i < (int) length; i++) {
-			char c = (char) this.rowFromServer.readByte();
+			char c = (char) buffer[offset + i];
 
 			if ((c == 'e') || (c == 'E')) {
 				return true;
@@ -703,7 +708,7 @@ public class BufferRow extends ResultSetRow {
 	}
 
 	public java.sql.Date getNativeDate(int columnIndex, ConnectionImpl conn,
-			ResultSetImpl rs) throws SQLException {
+			ResultSetImpl rs, Calendar cal) throws SQLException {
 		if (isNull(columnIndex)) {
 			return null;
 		}
@@ -715,7 +720,7 @@ public class BufferRow extends ResultSetRow {
 		int offset = this.rowFromServer.getPosition();
 		
 		return getNativeDate(columnIndex, this.rowFromServer.getByteBuffer(),
-				offset, (int) length, conn, rs);
+				offset, (int) length, conn, rs, cal);
 	}
 
 	public Object getNativeDateTimeValue(int columnIndex, Calendar targetCalendar,
