@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2007 MySQL AB
+ Copyright  2007 MySQL AB, 2008 Sun Microsystems
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License as 
@@ -44,7 +44,9 @@ public class ByteArrayRow extends ResultSetRow {
 
 	byte[][] internalRowData;
 
-	public ByteArrayRow(byte[][] internalRowData) {
+	public ByteArrayRow(byte[][] internalRowData, ExceptionInterceptor exceptionInterceptor) {
+		super(exceptionInterceptor);
+		
 		this.internalRowData = internalRowData;
 	}
 
@@ -203,7 +205,7 @@ public class ByteArrayRow extends ResultSetRow {
 			return new InputStreamReader(stream, this.metadata[columnIndex]
 					.getCharacterSet());
 		} catch (UnsupportedEncodingException e) {
-			SQLException sqlEx = SQLError.createSQLException("");
+			SQLException sqlEx = SQLError.createSQLException("", this.exceptionInterceptor);
 
 			sqlEx.initCause(e);
 
@@ -252,7 +254,7 @@ public class ByteArrayRow extends ResultSetRow {
 	}
 
 	public Date getNativeDate(int columnIndex, ConnectionImpl conn,
-			ResultSetImpl rs) throws SQLException {
+			ResultSetImpl rs, Calendar cal) throws SQLException {
 		byte[] columnValue = this.internalRowData[columnIndex];
 
 		if (columnValue == null) {
@@ -260,7 +262,7 @@ public class ByteArrayRow extends ResultSetRow {
 		}
 
 		return getNativeDate(columnIndex, columnValue, 0, columnValue.length,
-				conn, rs);
+				conn, rs, cal);
 	}
 
 	public Time getNativeTime(int columnIndex, Calendar targetCalendar,
