@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2002-2007 MySQL AB
+ Copyright  2002-2007 MySQL AB, 2008 Sun Microsystems
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License as 
@@ -34,7 +34,9 @@ import java.sql.Clob;
 import java.sql.Date;
 import java.sql.ParameterMetaData;
 import java.sql.Ref;
+import java.sql.ResultSet;
 import java.sql.SQLException;
+import java.sql.Statement;
 import java.sql.Time;
 import java.sql.Timestamp;
 import java.sql.Types;
@@ -147,6 +149,17 @@ public class CallableStatement extends PreparedStatement implements
 
 		Map parameterMap;
 
+		
+		/**
+		 * synchronized externally in checkReadOnlyProcedure()
+		 */
+		boolean isReadOnlySafeProcedure = false;
+		
+		/**
+		 * synchronized externally in checkReadOnlyProcedure()
+		 */
+		boolean isReadOnlySafeChecked = false;
+
 		/**
 		 * Constructor that converts a full list of parameter metadata into one
 		 * that only represents the placeholders present in the {CALL ()}.
@@ -161,6 +174,8 @@ public class CallableStatement extends PreparedStatement implements
 			int[] localParameterMap = placeholderToParameterIndexMap;
 			int parameterMapLength = localParameterMap.length;
 			
+			this.isReadOnlySafeProcedure = fullParamInfo.isReadOnlySafeProcedure;
+			this.isReadOnlySafeChecked = fullParamInfo.isReadOnlySafeChecked;
 			parameterList = new ArrayList(fullParamInfo.numParameters);
 			parameterMap = new HashMap(fullParamInfo.numParameters);
 			
@@ -257,7 +272,7 @@ public class CallableStatement extends PreparedStatement implements
 				throw SQLError.createSQLException(
 						Messages.getString("CallableStatement.11") + paramIndex //$NON-NLS-1$
 								+ Messages.getString("CallableStatement.12") + numParameters //$NON-NLS-1$
-								+ Messages.getString("CallableStatement.13"), SQLError.SQL_STATE_ILLEGAL_ARGUMENT); //$NON-NLS-1$
+								+ Messages.getString("CallableStatement.13"), SQLError.SQL_STATE_ILLEGAL_ARGUMENT, getExceptionInterceptor()); //$NON-NLS-1$
 			}
 		}
 
@@ -267,7 +282,6 @@ public class CallableStatement extends PreparedStatement implements
 		 * @see java.lang.Object#clone()
 		 */
 		protected Object clone() throws CloneNotSupportedException {
-			// TODO Auto-generated method stub
 			return super.clone();
 		}
 
@@ -418,7 +432,7 @@ public class CallableStatement extends PreparedStatement implements
 	    		return Util.cast(iface, this);
 	        } catch (ClassCastException cce) {
 	            throw SQLError.createSQLException("Unable to unwrap to " + iface.toString(), 
-	            		SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+	            		SQLError.SQL_STATE_ILLEGAL_ARGUMENT, getExceptionInterceptor());
 	        }
 	    }
 	}
@@ -487,6 +501,8 @@ public class CallableStatement extends PreparedStatement implements
 		if (this.callingStoredFunction) {
 			this.parameterCount += 1;
 		}
+		
+		this.retrieveGeneratedKeys = true; // not provided for in the JDBC spec
 	}
 
 	/**
@@ -504,7 +520,7 @@ public class CallableStatement extends PreparedStatement implements
 
 		return (CallableStatement) Util.handleNewInstance(
 				JDBC_4_CSTMT_4_ARGS_CTOR, new Object[] { conn, sql, catalog,
-						Boolean.valueOf(isFunctionCall) });
+						Boolean.valueOf(isFunctionCall) }, conn.getExceptionInterceptor());
 	}
 	
 	/**
@@ -521,7 +537,7 @@ public class CallableStatement extends PreparedStatement implements
 		}
 
 		return (CallableStatement) Util.handleNewInstance(
-				JDBC_4_CSTMT_2_ARGS_CTOR, new Object[] { conn, paramInfo });
+				JDBC_4_CSTMT_2_ARGS_CTOR, new Object[] { conn, paramInfo }, conn.getExceptionInterceptor());
 
 	}
 	
@@ -616,6 +632,8 @@ public class CallableStatement extends PreparedStatement implements
 			
 			this.parameterCount += 1;
 		}
+		
+		this.retrieveGeneratedKeys = true; // not provided for in the JDBC spec
 	}
 
 	/*
@@ -671,7 +689,7 @@ public class CallableStatement extends PreparedStatement implements
 			throw SQLError.createSQLException(
 					Messages.getString("CallableStatement.9") + paramIndex //$NON-NLS-1$
 							+ Messages.getString("CallableStatement.10"), //$NON-NLS-1$
-					SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+					SQLError.SQL_STATE_ILLEGAL_ARGUMENT, getExceptionInterceptor());
 		}
 
 		this.hasOutputParams = true;
@@ -701,7 +719,7 @@ public class CallableStatement extends PreparedStatement implements
 	private void checkStreamability() throws SQLException {
 		if (this.hasOutputParams && createStreamingResultSet()) {
 			throw SQLError.createSQLException(Messages.getString("CallableStatement.14"), //$NON-NLS-1$
-					SQLError.SQL_STATE_DRIVER_NOT_CAPABLE);
+					SQLError.SQL_STATE_DRIVER_NOT_CAPABLE, getExceptionInterceptor());
 		}
 	}
 
@@ -777,7 +795,7 @@ public class CallableStatement extends PreparedStatement implements
 
 			row[12] = null;
 
-			resultRows.add(new ByteArrayRow(row));
+			resultRows.add(new ByteArrayRow(row, getExceptionInterceptor()));
 		}
 
 		java.sql.ResultSet paramTypesRs = DatabaseMetaData.buildResultSet(
@@ -966,7 +984,7 @@ public class CallableStatement extends PreparedStatement implements
 		}
 		
 		throw SQLError.createSQLException(Messages.getString("CallableStatement.1"), //$NON-NLS-1$
-				SQLError.SQL_STATE_GENERAL_ERROR);
+				SQLError.SQL_STATE_GENERAL_ERROR, getExceptionInterceptor());
 	}
 
 	/**
@@ -984,12 +1002,13 @@ public class CallableStatement extends PreparedStatement implements
 		if ((paramNameIn == null) || (paramNameIn.length() == 0)) {
 			throw SQLError.createSQLException(
 					((Messages.getString("CallableStatement.0") + paramNameIn) == null) //$NON-NLS-1$
-							? Messages.getString("CallableStatement.15") : Messages.getString("CallableStatement.16"), SQLError.SQL_STATE_ILLEGAL_ARGUMENT); //$NON-NLS-1$ //$NON-NLS-2$
+							? Messages.getString("CallableStatement.15") : Messages.getString("CallableStatement.16"), SQLError.SQL_STATE_ILLEGAL_ARGUMENT, 
+									getExceptionInterceptor()); //$NON-NLS-1$ //$NON-NLS-2$
 		}
 
 		if (this.connection.getNoAccessToProcedureBodies()) {
 			throw SQLError.createSQLException("No access to parameters by name when connection has been configured not to access procedure bodies",
-					SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+					SQLError.SQL_STATE_ILLEGAL_ARGUMENT, getExceptionInterceptor());
 		}
 		
 		return mangleParameterName(paramNameIn);
@@ -1410,18 +1429,18 @@ public class CallableStatement extends PreparedStatement implements
 	throws SQLException {
 		if (this.connection.getNoAccessToProcedureBodies()) {
 			throw SQLError.createSQLException("No access to parameters by name when connection has been configured not to access procedure bodies",
-					SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+					SQLError.SQL_STATE_ILLEGAL_ARGUMENT, getExceptionInterceptor());
 		}
 		
 		if ((paramName == null) || (paramName.length() == 0)) {
 			throw SQLError.createSQLException(Messages.getString("CallableStatement.2"), //$NON-NLS-1$
-					SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+					SQLError.SQL_STATE_ILLEGAL_ARGUMENT, getExceptionInterceptor());
 		}
 
 		if (this.paramInfo == null) {
 			throw SQLError.createSQLException(
 					Messages.getString("CallableStatement.3") + paramName + Messages.getString("CallableStatement.4"), //$NON-NLS-1$ //$NON-NLS-2$
-					SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+					SQLError.SQL_STATE_ILLEGAL_ARGUMENT, getExceptionInterceptor());
 		}
 
 		CallableStatementParam namedParamInfo = this.paramInfo
@@ -1431,7 +1450,7 @@ public class CallableStatement extends PreparedStatement implements
 			throw SQLError.createSQLException(
 					Messages.getString("CallableStatement.5") + paramName //$NON-NLS-1$
 					+ Messages.getString("CallableStatement.6"), //$NON-NLS-1$
-					SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+					SQLError.SQL_STATE_ILLEGAL_ARGUMENT, getExceptionInterceptor());
 		}
 
 
@@ -1446,7 +1465,7 @@ public class CallableStatement extends PreparedStatement implements
 		}
 
 		throw SQLError.createSQLException("Can't find local placeholder mapping for parameter named \"" + 
-				paramName + "\".", SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+				paramName + "\".", SQLError.SQL_STATE_ILLEGAL_ARGUMENT, getExceptionInterceptor());
 	}
 
 	/**
@@ -1535,10 +1554,10 @@ public class CallableStatement extends PreparedStatement implements
 			if (this.paramInfo.numberOfParameters() == 0) {
 				throw SQLError.createSQLException(Messages
 						.getString("CallableStatement.7"), //$NON-NLS-1$
-						SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+						SQLError.SQL_STATE_ILLEGAL_ARGUMENT, getExceptionInterceptor());
 			}
 			throw SQLError.createSQLException(Messages.getString("CallableStatement.8"), //$NON-NLS-1$
-					SQLError.SQL_STATE_GENERAL_ERROR);
+					SQLError.SQL_STATE_GENERAL_ERROR, getExceptionInterceptor());
 		}
 
 		return this.outputParameterResults;
@@ -1811,7 +1830,7 @@ public class CallableStatement extends PreparedStatement implements
 			throw SQLError.createSQLException(
 					Messages.getString("CallableStatement.21") + paramIndex //$NON-NLS-1$
 							+ Messages.getString("CallableStatement.22"), //$NON-NLS-1$
-					SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+					SQLError.SQL_STATE_ILLEGAL_ARGUMENT, getExceptionInterceptor());
 		}
 
 		return rsIndex + 1;
@@ -2193,7 +2212,7 @@ public class CallableStatement extends PreparedStatement implements
 									this.charConverter, this.charEncoding,
 									this.connection
 											.getServerCharacterEncoding(),
-									this.connection.parserKnowsUnicode()));
+									this.connection.parserKnowsUnicode(), getExceptionInterceptor()));
 				}
 			}
 		}
@@ -2265,7 +2284,7 @@ public class CallableStatement extends PreparedStatement implements
 	public int[] executeBatch() throws SQLException {
 		if (this.hasOutputParams) {
 			throw SQLError.createSQLException("Can't call executeBatch() on CallableStatement with OUTPUT parameters",
-					SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+					SQLError.SQL_STATE_ILLEGAL_ARGUMENT, getExceptionInterceptor());
 		}
 		
 		return super.executeBatch();
@@ -2348,5 +2367,79 @@ public class CallableStatement extends PreparedStatement implements
 		setNCharacterStream(getNamedParamIndex(parameterName, false), value, length);
 		
 	}
+	
+	/**
+	 * Check whether the stored procedure alters any data or is safe for read-only usage.
+	 * 
+	 * @return true if procedure does not alter data
+	 * @throws SQLException
+	 */
+	private boolean checkReadOnlyProcedure() throws SQLException {
+		if (this.connection.getNoAccessToProcedureBodies()) {
+			return false;
+		}
+
+		synchronized (this.paramInfo) {
+			if (this.paramInfo.isReadOnlySafeChecked) {
+				return this.paramInfo.isReadOnlySafeProcedure;
+			}
+
+			ResultSet rs = null;
+			PreparedStatement ps = null;
+			
+			try {
+				String procName = extractProcedureName();
+
+				String catalog = this.currentCatalog;
+
+				if (procName.indexOf(".") != -1) {
+					catalog = procName.substring(0, procName.indexOf("."));
+					procName = procName.substring(procName.indexOf(".") + 1);
+					procName = new String(StringUtils.stripEnclosure(procName
+							.getBytes(), "`", "`"));
+				}
+				ps = ((DatabaseMetaData) this.connection
+						.getMetaData())
+						.prepareMetaDataSafeStatement("SELECT SQL_DATA_ACCESS FROM "
+								+ " information_schema.routines "
+								+ " WHERE routine_schema = ? "
+								+ " AND routine_name = ?");
+
+				ps.setString(1, catalog);
+				ps.setString(2, procName);
+				rs = ps.executeQuery();
+				if (rs.next()) {
+					String sqlDataAccess = rs.getString(1);
+					if ("READS SQL DATA".equalsIgnoreCase(sqlDataAccess)
+							|| "NO SQL".equalsIgnoreCase(sqlDataAccess)) {
+						synchronized (this.paramInfo) {
+							this.paramInfo.isReadOnlySafeChecked = true;
+							this.paramInfo.isReadOnlySafeProcedure = true;
+						}
+						return true;
+					}
+				}
+			} catch (SQLException e) {
+				// swallow the Exception
+			} finally {
+				if(rs != null){
+					rs.close();
+				}
+				if(ps != null){
+					ps.close();
+				}
+				
+			}
+			this.paramInfo.isReadOnlySafeChecked = false;
+			this.paramInfo.isReadOnlySafeProcedure = false;
+		}
+		return false;
+					
+	}
+
+	protected boolean checkReadOnlySafeStatement() throws SQLException {
+		return (super.checkReadOnlySafeStatement() || this.checkReadOnlyProcedure());
+	}
+
 
 }
