@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2007 MySQL AB
+ Copyright  2007 MySQL AB, 2008 Sun Microsystems
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License as 
@@ -376,4 +376,9 @@ public interface Connection extends java.sql.Connection, ConnectionProperties {
 	public abstract boolean isAbonormallyLongQuery(long millisOrNanos);
 
 	public abstract void initializeExtension(Extension ex) throws SQLException;
+	
+	/** Returns the -session- value of 'auto_increment_increment' from the server if it exists,
+	 * or '1' if not.
+	 */
+	public abstract int getAutoIncrementIncrement();
 }
