@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2002-2007 MySQL AB
+ Copyright  2002-2007 MySQL AB, 2008 Sun Microsystems
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License as 
@@ -1574,4 +1574,63 @@ public interface ConnectionProperties {
 	public abstract String getConnectionLifecycleInterceptors();
 
 	public abstract void setConnectionLifecycleInterceptors(String interceptors);
+	
+	public abstract String getProfilerEventHandler();
+
+	public abstract  void setProfilerEventHandler(String handler);
+	
+	public boolean getVerifyServerCertificate();
+
+	public abstract void setVerifyServerCertificate(boolean flag);
+	
+	public abstract boolean getUseLegacyDatetimeCode();
+
+	public abstract void setUseLegacyDatetimeCode(boolean flag);
+	
+	public abstract int getSelfDestructOnPingSecondsLifetime();
+
+	public abstract void setSelfDestructOnPingSecondsLifetime(int seconds);
+
+	public abstract int getSelfDestructOnPingMaxOperations();
+
+	public abstract void setSelfDestructOnPingMaxOperations(int maxOperations);
+	
+	public abstract boolean getUseColumnNamesInFindColumn();
+
+	public abstract void setUseColumnNamesInFindColumn(boolean flag);
+	
+	public abstract boolean getUseLocalTransactionState();
+
+	public abstract void setUseLocalTransactionState(boolean flag);
+	
+	public abstract boolean getCompensateOnDuplicateKeyUpdateCounts();
+
+	public abstract void setCompensateOnDuplicateKeyUpdateCounts(boolean flag);
+	
+	public abstract void setUseAffectedRows(boolean flag);
+
+	public abstract boolean getUseAffectedRows();
+	
+	public abstract void setPasswordCharacterEncoding(String characterSet);
+
+	public abstract String getPasswordCharacterEncoding();
+	
+	public abstract int getLoadBalanceBlacklistTimeout();
+
+	public abstract void setLoadBalanceBlacklistTimeout(int loadBalanceBlacklistTimeout);
+	
+	public abstract void setRetriesAllDown(int retriesAllDown);
+	
+	public abstract int getRetriesAllDown();
+
+	public ExceptionInterceptor getExceptionInterceptor();
+	
+	public abstract void setExceptionInterceptors(String exceptionInterceptors);
+
+	public abstract String getExceptionInterceptors();
+	
+
+	public abstract boolean getQueryTimeoutKillsConnection();
+
+	public abstract void setQueryTimeoutKillsConnection(boolean queryTimeoutKillsConnection);
 }
