@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2002-2004 MySQL AB
+ Copyright  2002-2004 MySQL AB, 2008 Sun Microsystems
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License as 
@@ -104,15 +104,17 @@ public class EscapeTokenizer {
 				this.sawVariableUse = true;
 			}
 
-			if (c == '\'' || c == '"') {
+			if ((c == '\'' || c == '"') && !inComment) {
 				if (this.inQuotes && c == quoteChar) {
 					if (this.pos + 1 < this.sourceLength) {
 						if (this.source.charAt(this.pos + 1) == quoteChar) {
-							// Doubled-up quote escape
-							tokenBuf.append(quoteChar);
-							tokenBuf.append(quoteChar);
-							this.pos++;
-							continue;
+							// Doubled-up quote escape, if the first quote isn't already escaped
+							if (this.lastChar != '\\') {
+								tokenBuf.append(quoteChar);
+								tokenBuf.append(quoteChar);
+								this.pos++;
+								continue;
+							}
 						}
 					}
 				}
