@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2002-2004 MySQL AB
+ Copyright  2002-2004 MySQL AB, 2008 Sun Microsystems
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License as
@@ -33,7 +33,7 @@ import java.util.regex.PatternSyntaxException;
  * Field is a class used to describe fields in a ResultSet
  *
  * @author Mark Matthews
- * @version $Id: Field.java 6643 2007-10-23 17:47:15Z mmatthews $
+ * @version $Id$
  */
 public class Field {
 
@@ -157,10 +157,9 @@ public class Field {
 
         checkForImplicitTemporaryTable();
 		// Re-map to 'real' blob type, if we're a BLOB
-
+        boolean isFromFunction = this.originalTableNameLength == 0;
+        
 		if (this.mysqlType == MysqlDefs.FIELD_TYPE_BLOB) {
-		    boolean isFromFunction = this.originalTableNameLength == 0;
-
 		    if (this.connection != null && this.connection.getBlobsAreStrings() ||
 		            (this.connection.getFunctionsNeverReturnBlobs() && isFromFunction)) {
 		        this.sqlType = Types.VARCHAR;
@@ -208,9 +207,12 @@ public class Field {
 					this.mysqlType == MysqlDefs.FIELD_TYPE_VAR_STRING &&
 					isBinary &&
 					this.charsetIndex == 63) {
-				if (this.isOpaqueBinary()) {
+				if (this.connection != null && (this.connection.getFunctionsNeverReturnBlobs() && isFromFunction)) {
+			        this.sqlType = Types.VARCHAR;
+			        this.mysqlType = MysqlDefs.FIELD_TYPE_VARCHAR;
+				} else if (this.isOpaqueBinary()) {
 					this.sqlType = Types.VARBINARY;
-				}
+				} 
 			}
 
 			if (this.connection.versionMeetsMinimum(4, 1, 0) &&
@@ -307,7 +309,7 @@ public class Field {
 							SQLException sqlEx = SQLError
 									.createSQLException(
 											"Illegal regex specified for \"utf8OutsideBmpIncludedColumnNamePattern\"",
-											SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+											SQLError.SQL_STATE_ILLEGAL_ARGUMENT, this.connection.getExceptionInterceptor());
 
 							if (!this.connection.getParanoid()) {
 								sqlEx.initCause(pse);
@@ -323,7 +325,7 @@ public class Field {
 				SQLException sqlEx = SQLError
 						.createSQLException(
 								"Illegal regex specified for \"utf8OutsideBmpExcludedColumnNamePattern\"",
-								SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+								SQLError.SQL_STATE_ILLEGAL_ARGUMENT, this.connection.getExceptionInterceptor());
 
 				if (!this.connection.getParanoid()) {
 					sqlEx.initCause(pse);
@@ -396,6 +398,14 @@ public class Field {
 		this.colFlag = 0;
 		this.colDecimals = 0;
 		this.charsetIndex = charsetIndex;
+		
+		switch (this.sqlType) {
+		case Types.BINARY:
+		case Types.VARBINARY:
+			this.colFlag |= 128;
+			this.colFlag |= 16;
+			break;
+		}
 	}
 	
 	private void checkForImplicitTemporaryTable() {
@@ -894,6 +904,10 @@ public class Field {
 		return ((this.colFlag & 32) > 0);
 	}
 
+	public void setUnsigned() {
+		this.colFlag |= 32;
+	}
+	
 	/**
 	 * DOCUMENT ME!
 	 *
