@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2002-2007 MySQL AB
+ Copyright  2002-2007 MySQL AB, 2008 Sun Microsystems
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License as 
@@ -23,6 +23,8 @@
 
 package com.mysql.jdbc;
 
+import com.mysql.jdbc.ExceptionInterceptor;
+
 
 /**
  * Simplistic implementation of java.sql.NClob for MySQL Connector/J
@@ -32,11 +34,11 @@ package com.mysql.jdbc;
  */
 public class JDBC4NClob extends Clob implements java.sql.NClob {
 
-	JDBC4NClob() {
-        super();
+	JDBC4NClob(ExceptionInterceptor exceptionInterceptor) {
+        super(exceptionInterceptor);
     }
 	
-	JDBC4NClob(String charDataInit) {
-        super(charDataInit);
+	JDBC4NClob(String charDataInit, ExceptionInterceptor exceptionInterceptor) {
+        super(charDataInit, exceptionInterceptor);
     }
 }
