@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2002-2007 MySQL AB
+ Copyright  2002-2007 MySQL AB, 2008 Sun Microsystems
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License as 
@@ -123,7 +123,7 @@ public class JDBC4ResultSet extends ResultSetImpl {
 				return null;
 			}
 
-			return new com.mysql.jdbc.JDBC4NClob(asString);
+			return new com.mysql.jdbc.JDBC4NClob(asString, getExceptionInterceptor());
 		}
 
 		return getNativeNClob(columnIndex);
@@ -185,7 +185,7 @@ public class JDBC4ResultSet extends ResultSetImpl {
 			}
 		} catch (UnsupportedEncodingException uee) {
 			throw SQLError.createSQLException("Unsupported character encoding "
-					+ forcedEncoding, SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+					+ forcedEncoding, SQLError.SQL_STATE_ILLEGAL_ARGUMENT, getExceptionInterceptor());
 		}
 
 		return asString;
@@ -193,7 +193,7 @@ public class JDBC4ResultSet extends ResultSetImpl {
 	
 	private final java.sql.NClob getNClobFromString(String stringVal,
 			int columnIndex) throws SQLException {
-		return new com.mysql.jdbc.JDBC4NClob(stringVal);
+		return new com.mysql.jdbc.JDBC4NClob(stringVal, getExceptionInterceptor());
 	}
 	
 	/**
@@ -314,7 +314,7 @@ public class JDBC4ResultSet extends ResultSetImpl {
 	public SQLXML getSQLXML(int columnIndex) throws SQLException {
 		checkColumnBounds(columnIndex);
 		
-		return new JDBC4MysqlSQLXML(this, columnIndex);
+		return new JDBC4MysqlSQLXML(this, columnIndex, getExceptionInterceptor());
 	}
 
 	public SQLXML getSQLXML(String columnLabel) throws SQLException {
@@ -520,7 +520,7 @@ public class JDBC4ResultSet extends ResultSetImpl {
             return iface.cast(this);
         } catch (ClassCastException cce) {
             throw SQLError.createSQLException("Unable to unwrap to " + iface.toString(), 
-            		SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+            		SQLError.SQL_STATE_ILLEGAL_ARGUMENT, getExceptionInterceptor());
         }
     }
 }
