@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2007 MySQL AB
+ Copyright  2007 MySQL AB, 2008 Sun Microsystems
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License as 
@@ -34,6 +34,7 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Properties;
+import java.util.Set;
 
 /**
  * An implementation of java.sql.Connection that load balances requests across a
@@ -44,9 +45,10 @@ import java.util.Properties;
  * reading data.
  * 
  * This implementation will invalidate connections that it detects have had
- * communication errors when processing a request. A new connection to the
- * problematic host will be attempted the next time it is selected by the load
- * balancing algorithm.
+ * communication errors when processing a request.  Problematic hosts will
+ * be added to a global blacklist for loadBalanceBlacklistTimeout ms, after
+ * which they will be removed from the blacklist and made eligible once again
+ * to be selected for new connections.
  * 
  * This implementation is thread-safe, but it's questionable whether sharing a
  * connection instance amongst threads is a good idea, given that transactions
@@ -58,6 +60,8 @@ import java.util.Properties;
 public class LoadBalancingConnectionProxy implements InvocationHandler, PingTarget {
 
 	private static Method getLocalTimeMethod;
+	
+	public static final String BLACKLIST_TIMEOUT_PROPERTY_KEY = "loadBalanceBlacklistTimeout";
 
 	static {
 		try {
@@ -121,6 +125,10 @@ public class LoadBalancingConnectionProxy implements InvocationHandler, PingTarg
 	private BalanceStrategy balancer;
 
 	private int retriesAllDown;
+	
+	private static Map globalBlacklist = new HashMap();
+
+	private int globalBlacklistTimeout = 0;
 
 	/**
 	 * Creates a proxy for java.sql.Connection that routes requests between the
@@ -162,20 +170,30 @@ public class LoadBalancingConnectionProxy implements InvocationHandler, PingTarg
 			throw SQLError.createSQLException(Messages.getString(
 					"LoadBalancingConnectionProxy.badValueForRetriesAllDown",
 					new Object[] { retriesAllDownAsString }),
-					SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+					SQLError.SQL_STATE_ILLEGAL_ARGUMENT, null);
+		}
+		String blacklistTimeoutAsString = this.localProps.getProperty(BLACKLIST_TIMEOUT_PROPERTY_KEY, "0");
+		
+		try {
+			this.globalBlacklistTimeout = Integer.parseInt(blacklistTimeoutAsString);
+		} catch (NumberFormatException nfe) {
+			throw SQLError.createSQLException(Messages.getString(
+					"LoadBalancingConnectionProxy.badValueForLoadBalanceBlacklistTimeout",
+					new Object[] { retriesAllDownAsString }),
+					SQLError.SQL_STATE_ILLEGAL_ARGUMENT, null);
 		}
 		
 		if ("random".equals(strategy)) {
 			this.balancer = (BalanceStrategy) Util.loadExtensions(null, props,
 					"com.mysql.jdbc.RandomBalanceStrategy",
-					"InvalidLoadBalanceStrategy").get(0);
+					"InvalidLoadBalanceStrategy", null).get(0);
 		} else if ("bestResponseTime".equals(strategy)) {
 			this.balancer = (BalanceStrategy) Util.loadExtensions(null, props,
 					"com.mysql.jdbc.BestResponseTimeBalanceStrategy",
-			"InvalidLoadBalanceStrategy").get(0);
+			"InvalidLoadBalanceStrategy", null).get(0);
 		} else {
 			this.balancer = (BalanceStrategy) Util.loadExtensions(null, props,
-					strategy, "InvalidLoadBalanceStrategy").get(0);
+					strategy, "InvalidLoadBalanceStrategy", null).get(0);
 		}
 
 		this.balancer.init(null, props);
@@ -259,10 +277,26 @@ public class LoadBalancingConnectionProxy implements InvocationHandler, PingTarg
 			}
 
 		} finally {
+			// add host to the global blacklist, if enabled
+			if (this.isGlobalBlacklistEnabled()) {
+				this.addToGlobalBlacklist((String) this.connectionsToHostsMap.get(this.currentConn)); 
+				
+			}
+			// remove from liveConnections
 			this.liveConnections.remove(this.connectionsToHostsMap
 					.get(this.currentConn));
+			
+			int hostIndex = ((Integer) this.hostsToListIndexMap
+					.get(this.connectionsToHostsMap.get(this.currentConn)))
+					.intValue();
+
+			// reset the statistics for the host
+			synchronized (this.responseTimes) {
+				this.responseTimes[hostIndex] = 0;
+			}
+
 			this.connectionsToHostsMap.remove(this.currentConn);
-		}
+			}
 	}
 
 	/**
@@ -275,8 +309,16 @@ public class LoadBalancingConnectionProxy implements InvocationHandler, PingTarg
 
 		String methodName = method.getName();
 
+		if ("equals".equals(methodName) && args.length == 1) {
+			if (args[0] instanceof Proxy) {
+				return Boolean.valueOf((((Proxy)args[0]).equals(this)));
+			}
+			
+			return Boolean.valueOf(equals(args[0]));
+		}
+		
 		if ("close".equals(methodName)) {
-			synchronized (this.liveConnections) {
+			synchronized (this) {
 				// close all underlying connections
 				Iterator allConnections = this.liveConnections.values()
 						.iterator();
@@ -303,7 +345,7 @@ public class LoadBalancingConnectionProxy implements InvocationHandler, PingTarg
 		if (this.isClosed) {
 			throw SQLError.createSQLException(
 					"No operations allowed after connection closed.",
-					SQLError.SQL_STATE_CONNECTION_NOT_OPEN);
+					SQLError.SQL_STATE_CONNECTION_NOT_OPEN, null /* no access to a interceptor here... */);
 		}
 
 		if (!inTransaction) {
@@ -330,13 +372,19 @@ public class LoadBalancingConnectionProxy implements InvocationHandler, PingTarg
 				this.inTransaction = false;
 
 				// Update stats
-				int hostIndex = ((Integer) this.hostsToListIndexMap
-						.get(this.connectionsToHostsMap.get(this.currentConn)))
-						.intValue();
-
-				synchronized (this.responseTimes) {
-					this.responseTimes[hostIndex] = getLocalTimeBestResolution()
-							- this.transactionStartTime;
+				String host = (String) this.connectionsToHostsMap.get(this.currentConn);
+				// avoid NPE if the connection has already been removed from connectionsToHostsMap
+				// in invalidateCurrenctConnection()
+				if ( host != null ) {
+					int hostIndex = ((Integer) this.hostsToListIndexMap
+							.get( host ))
+							.intValue();
+	
+					
+					synchronized (this.responseTimes) {
+						this.responseTimes[hostIndex] = getLocalTimeBestResolution()
+								- this.transactionStartTime;
+					}
 				}
 
 				pickNewConnection();
@@ -425,10 +473,87 @@ public class LoadBalancingConnectionProxy implements InvocationHandler, PingTarg
 	}
 
 	public synchronized void doPing() throws SQLException {
-		Iterator allConns = this.liveConnections.values().iterator();
-		
-		while (allConns.hasNext()) {
-			((Connection)allConns.next()).ping();
+		if(this.isGlobalBlacklistEnabled()){
+			SQLException se = null;
+			boolean foundHost = false;
+			synchronized(this){
+				for(Iterator i = this.hostList.iterator(); i.hasNext(); ){
+					String host = (String) i.next();
+					Connection conn = (Connection) this.liveConnections.get(host);
+					if(conn == null){
+						continue;
+					}
+					try{
+						conn.ping();
+						foundHost = true;
+					} catch (SQLException e){
+						se = e;
+						this.addToGlobalBlacklist(host);
+					}
+				}
+			}
+			if(!foundHost){
+				throw se;
+			}
+		} else {
+			Iterator allConns = this.liveConnections.values().iterator();
+			while (allConns.hasNext()) {
+				((Connection)allConns.next()).ping();
+			}			
+		}
+
+	}
+	
+	public void addToGlobalBlacklist(String host) {
+		if(this.isGlobalBlacklistEnabled()) {
+			synchronized(globalBlacklist){
+				globalBlacklist.put(host, new Long(System.currentTimeMillis() 
+					+ this.globalBlacklistTimeout));
+			}
 		}
 	}
+	
+	public boolean isGlobalBlacklistEnabled() {
+		return (this.globalBlacklistTimeout > 0);
+	}
+	
+	public Map getGlobalBlacklist() {
+		if(!this.isGlobalBlacklistEnabled()) {
+			return new HashMap(1);
+		}
+		
+		// Make a local copy of the blacklist
+		Map blacklistClone = new HashMap(globalBlacklist.size());
+		// Copy everything from synchronized global blacklist to local copy for manipulation
+		synchronized (globalBlacklist) {
+			blacklistClone.putAll(globalBlacklist);
+		}
+		Set keys = blacklistClone.keySet();
+		
+		// we're only interested in blacklisted hosts that are in the hostList
+		keys.retainAll(this.hostList);
+		if(keys.size() == this.hostList.size()){
+			// return an empty blacklist, let the BalanceStrategy implementations try to connect to everything
+			// since it appears that all hosts are unavailable - we don't want to wait for 
+			// loadBalanceBlacklistTimeout to expire.
+			return new HashMap(1); 			
+		}
+		
+		// Don't need to synchronize here as we using a local copy
+		for(Iterator i = keys.iterator(); i.hasNext(); ) {
+			String host = (String) i.next();
+			// OK if null is returned because another thread already purged Map entry.
+			Long timeout = (Long) globalBlacklist.get(host);
+			if(timeout != null && timeout.longValue() < System.currentTimeMillis()){
+				// Timeout has expired, remove from blacklist
+				synchronized(globalBlacklist){
+					globalBlacklist.remove(host);
+				}
+				i.remove();
+			}
+				
+		}
+		
+		return blacklistClone;
+	}
 }
\ No newline at end of file
