@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2005 MySQL AB
+ Copyright  2005 MySQL AB, 2008 Sun Microsystems
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License as 
@@ -27,8 +27,6 @@ import java.sql.ParameterMetaData;
 import java.sql.SQLException;
 import java.sql.Types;
 
-import com.mysql.jdbc.exceptions.NotYetImplementedException;
-
 public class MysqlParameterMetadata implements ParameterMetaData {
 	boolean returnSimpleMetadata = false;
 
@@ -36,10 +34,13 @@ public class MysqlParameterMetadata implements ParameterMetaData {
 
 	int parameterCount = 0;
 
-	MysqlParameterMetadata(Field[] fieldInfo, int parameterCount) {
-		this.metadata = new ResultSetMetaData(fieldInfo, false);
+	private ExceptionInterceptor exceptionInterceptor;
+	
+	MysqlParameterMetadata(Field[] fieldInfo, int parameterCount, ExceptionInterceptor exceptionInterceptor) {
+		this.metadata = new ResultSetMetaData(fieldInfo, false, exceptionInterceptor);
 
 		this.parameterCount = parameterCount;
+		this.exceptionInterceptor = exceptionInterceptor;
 	}
 
 	/**
@@ -67,7 +68,7 @@ public class MysqlParameterMetadata implements ParameterMetaData {
 		if (this.metadata == null || this.metadata.fields == null) {
 			throw SQLError.createSQLException(
 					"Parameter metadata not available for the given statement",
-					SQLError.SQL_STATE_DRIVER_NOT_CAPABLE);
+					SQLError.SQL_STATE_DRIVER_NOT_CAPABLE, this.exceptionInterceptor);
 		}
 	}
 
@@ -151,7 +152,7 @@ public class MysqlParameterMetadata implements ParameterMetaData {
 		if (paramNumber < 1) {
 			throw SQLError.createSQLException("Parameter index of '"
 					+ paramNumber + "' is invalid.",
-					SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+					SQLError.SQL_STATE_ILLEGAL_ARGUMENT, this.exceptionInterceptor);
 		}
 
 		if (paramNumber > this.parameterCount) {
@@ -159,7 +160,7 @@ public class MysqlParameterMetadata implements ParameterMetaData {
 					+ paramNumber
 					+ "' is greater than number of parameters, which is '"
 					+ this.parameterCount + "'.",
-					SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+					SQLError.SQL_STATE_ILLEGAL_ARGUMENT, this.exceptionInterceptor);
 
 		}
 	}
@@ -207,7 +208,7 @@ public class MysqlParameterMetadata implements ParameterMetaData {
     		return Util.cast(iface, this);
         } catch (ClassCastException cce) {
             throw SQLError.createSQLException("Unable to unwrap to " + iface.toString(), 
-            		SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+            		SQLError.SQL_STATE_ILLEGAL_ARGUMENT, this.exceptionInterceptor);
         }
     }
 }
