@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2007 MySQL AB
+ Copyright  2007 MySQL AB, 2008 Sun Microsystems
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License as 
@@ -47,6 +47,12 @@ import java.util.TimeZone;
  * @version $Id: $
  */
 public abstract class ResultSetRow {
+	protected ExceptionInterceptor exceptionInterceptor;
+	
+	protected ResultSetRow(ExceptionInterceptor exceptionInterceptor) {
+		this.exceptionInterceptor = exceptionInterceptor;
+	}
+	
 	/**
 	 * The metadata of the fields of this result set.
 	 */
@@ -134,7 +140,7 @@ public abstract class ResultSetRow {
 					throw SQLError.createSQLException("Value '"
 							+ new String(dateAsBytes)
 							+ "' can not be represented as java.sql.Date",
-							SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+							SQLError.SQL_STATE_ILLEGAL_ARGUMENT, this.exceptionInterceptor);
 				}
 
 				// We're left with the case of 'round' to a date Java _can_
@@ -144,6 +150,7 @@ public abstract class ResultSetRow {
 			} else if (this.metadata[columnIndex].getMysqlType() == MysqlDefs.FIELD_TYPE_TIMESTAMP) {
 				// Convert from TIMESTAMP
 				switch (length) {
+				case 29:
 				case 21:
 				case 19: { // java.sql.Timestamp format
 					year = StringUtils.getInt(dateAsBytes, offset + 0,
@@ -222,7 +229,7 @@ public abstract class ResultSetRow {
 																	dateAsBytes),
 															Constants
 																	.integerValueOf(columnIndex + 1) }),
-									SQLError.SQL_STATE_ILLEGAL_ARGUMENT); //$NON-NLS-1$
+									SQLError.SQL_STATE_ILLEGAL_ARGUMENT, this.exceptionInterceptor); //$NON-NLS-1$
 				} /* endswitch */
 			} else if (this.metadata[columnIndex].getMysqlType() == MysqlDefs.FIELD_TYPE_YEAR) {
 
@@ -261,7 +268,7 @@ public abstract class ResultSetRow {
 																	dateAsBytes),
 															Constants
 																	.integerValueOf(columnIndex + 1) }),
-									SQLError.SQL_STATE_ILLEGAL_ARGUMENT); //$NON-NLS-1$
+									SQLError.SQL_STATE_ILLEGAL_ARGUMENT, this.exceptionInterceptor); //$NON-NLS-1$
 				}
 
 				if (length != 18) {
@@ -291,7 +298,7 @@ public abstract class ResultSetRow {
 					"ResultSet.Bad_format_for_Date", new Object[] {
 							new String(dateAsBytes),
 							Constants.integerValueOf(columnIndex + 1) }),
-					SQLError.SQL_STATE_ILLEGAL_ARGUMENT); //$NON-NLS-1$
+					SQLError.SQL_STATE_ILLEGAL_ARGUMENT, this.exceptionInterceptor); //$NON-NLS-1$
 			sqlEx.initCause(e);
 			
 			throw sqlEx;
@@ -326,7 +333,7 @@ public abstract class ResultSetRow {
 	public abstract long getLong(int columnIndex) throws SQLException;
 
 	protected java.sql.Date getNativeDate(int columnIndex, byte[] bits,
-			int offset, int length, ConnectionImpl conn, ResultSetImpl rs)
+			int offset, int length, ConnectionImpl conn, ResultSetImpl rs, Calendar cal)
 			throws SQLException {
 
 		int year = 0;
@@ -349,7 +356,7 @@ public abstract class ResultSetRow {
 				throw SQLError
 						.createSQLException(
 								"Value '0000-00-00' can not be represented as java.sql.Date",
-								SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+								SQLError.SQL_STATE_ILLEGAL_ARGUMENT, this.exceptionInterceptor);
 			}
 
 			year = 1;
@@ -358,15 +365,15 @@ public abstract class ResultSetRow {
 		}
 
 		if (!rs.useLegacyDatetimeCode) {
-			return TimeUtil.fastDateCreate(year, month, day, null);
+			return TimeUtil.fastDateCreate(year, month, day, cal);
 		}
 		
-		return rs.fastDateCreate(rs.getCalendarInstanceForSessionOrNew(), year,
+		return rs.fastDateCreate(cal == null ? rs.getCalendarInstanceForSessionOrNew() : cal, year,
 				month, day);
 	}
 
 	public abstract Date getNativeDate(int columnIndex, ConnectionImpl conn,
-			ResultSetImpl rs) throws SQLException;
+			ResultSetImpl rs, Calendar cal) throws SQLException;
 
 	protected Object getNativeDateTimeValue(int columnIndex, byte[] bits,
 			int offset, int length, Calendar targetCalendar, int jdbcType,
@@ -455,12 +462,12 @@ public abstract class ResultSetRow {
 		case Types.TIME:
 			if (populatedFromDateTimeValue) {
 				if (!rs.useLegacyDatetimeCode) {
-					return TimeUtil.fastTimeCreate(hour, minute, seconds, targetCalendar);
+					return TimeUtil.fastTimeCreate(hour, minute, seconds, targetCalendar, this.exceptionInterceptor);
 				}
 				
 				Time time = TimeUtil.fastTimeCreate(rs
 						.getCalendarInstanceForSessionOrNew(), hour, minute,
-						seconds);
+						seconds, this.exceptionInterceptor);
 
 				Time adjustedTime = TimeUtil.changeTimezone(conn,
 						sessionCalendar, targetCalendar, time, conn
@@ -631,14 +638,14 @@ public abstract class ResultSetRow {
 		}
 
 		if (!rs.useLegacyDatetimeCode) {
-			return TimeUtil.fastTimeCreate(hour, minute, seconds, targetCalendar);
+			return TimeUtil.fastTimeCreate(hour, minute, seconds, targetCalendar, this.exceptionInterceptor);
 		}
 		
 		Calendar sessionCalendar = rs.getCalendarInstanceForSessionOrNew();
 
 		synchronized (sessionCalendar) {
 			Time time = TimeUtil.fastTimeCreate(sessionCalendar, hour, minute,
-					seconds);
+					seconds, this.exceptionInterceptor);
 
 			Time adjustedTime = TimeUtil.changeTimezone(conn, sessionCalendar,
 					targetCalendar, time, conn.getServerTimezoneTZ(), tz,
@@ -694,7 +701,7 @@ public abstract class ResultSetRow {
 				throw SQLError
 						.createSQLException(
 								"Value '0000-00-00' can not be represented as java.sql.Timestamp",
-								SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+								SQLError.SQL_STATE_ILLEGAL_ARGUMENT, this.exceptionInterceptor);
 			}
 
 			year = 1;
@@ -794,7 +801,7 @@ public abstract class ResultSetRow {
 						.createSQLException(
 								Messages
 										.getString("ResultSet.Unsupported_character_encoding____101") //$NON-NLS-1$
-										+ encoding + "'.", "0S100");
+										+ encoding + "'.", "0S100", this.exceptionInterceptor);
 			}
 		} else {
 			stringVal = StringUtils.toAsciiString(value, offset, length);
@@ -852,7 +859,7 @@ public abstract class ResultSetRow {
 					throw SQLError.createSQLException("Value '"
 							+ new String(timeAsBytes)
 							+ "' can not be represented as java.sql.Time",
-							SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+							SQLError.SQL_STATE_ILLEGAL_ARGUMENT, this.exceptionInterceptor);
 				}
 
 				// We're left with the case of 'round' to a time Java _can_
@@ -906,7 +913,7 @@ public abstract class ResultSetRow {
 											+ (columnIndex + 1)
 											+ "("
 											+ timeColField + ").",
-									SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+									SQLError.SQL_STATE_ILLEGAL_ARGUMENT, this.exceptionInterceptor);
 				} /* endswitch */
 
 				SQLWarning precisionLost = new SQLWarning(
@@ -945,7 +952,7 @@ public abstract class ResultSetRow {
 							+ new String(timeAsBytes)
 							+ Messages.getString("ResultSet.___in_column__268")
 							+ (columnIndex + 1),
-							SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+							SQLError.SQL_STATE_ILLEGAL_ARGUMENT, this.exceptionInterceptor);
 				}
 
 				hr = StringUtils.getInt(timeAsBytes, offset + 0, offset + 2);
@@ -968,7 +975,7 @@ public abstract class ResultSetRow {
 			}
 		} catch (Exception ex) {
 			SQLException sqlEx = SQLError.createSQLException(ex.toString(),
-					SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+					SQLError.SQL_STATE_ILLEGAL_ARGUMENT, this.exceptionInterceptor);
 			sqlEx.initCause(ex);
 			
 			throw sqlEx;
@@ -1029,7 +1036,7 @@ public abstract class ResultSetRow {
 										"Value '"
 												+ timestampAsBytes
 												+ "' can not be represented as java.sql.Timestamp",
-										SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+										SQLError.SQL_STATE_ILLEGAL_ARGUMENT, this.exceptionInterceptor);
 					}
 
 					if (!rs.useLegacyDatetimeCode) {
@@ -1069,6 +1076,7 @@ public abstract class ResultSetRow {
 					int nanos = 0;
 					
 					switch (length) {
+					case 29:
 					case 26:
 					case 25:
 					case 24:
@@ -1106,6 +1114,13 @@ public abstract class ResultSetRow {
 									nanos = StringUtils.getInt(
 											timestampAsBytes, decimalIndex + 1,
 											offset + length);
+									
+									int numDigits = (offset + length) - (decimalIndex + 1);
+									
+									if (numDigits < 9) {
+										int factor = (int)(Math.pow(10, 9 - numDigits));
+										nanos = nanos * factor;
+									}
 								} else {
 									throw new IllegalArgumentException(); // re-thrown
 									// further
@@ -1321,7 +1336,7 @@ public abstract class ResultSetRow {
 			SQLException sqlEx = SQLError.createSQLException("Cannot convert value '"
 					+ getString(columnIndex, "ISO8859_1", conn)
 					+ "' from column " + (columnIndex + 1) + " to TIMESTAMP.",
-					SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+					SQLError.SQL_STATE_ILLEGAL_ARGUMENT, this.exceptionInterceptor);
 			sqlEx.initCause(e);
 			
 			throw sqlEx;
