@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2002-2007 MySQL AB
+ Copyright  2002-2007 MySQL AB, 2008 Sun Microsystems
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License as 
@@ -24,6 +24,7 @@
  */
 package com.mysql.jdbc;
 
+import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.sql.Statement;
 
@@ -35,7 +36,7 @@ import com.mysql.jdbc.profiler.ProfilerEventHandlerFactory;
  * Allows streaming of MySQL data.
  * 
  * @author dgan
- * @version $Id: RowDataDynamic.java 6706 2008-01-04 02:40:19Z mmatthews $
+ * @version $Id$
  */
 public class RowDataDynamic implements RowData {
 
@@ -56,7 +57,7 @@ public class RowDataDynamic implements RowData {
 
 	private boolean isAfterEnd = false;
 
-	private boolean isAtEnd = false;
+	private boolean noMoreRows = false;
 
 	private boolean isBinaryEncoded = false;
 
@@ -72,6 +73,8 @@ public class RowDataDynamic implements RowData {
 
 	private boolean moreResultsExisted;
 
+	private ExceptionInterceptor exceptionInterceptor;
+	
 	/**
 	 * Creates a new RowDataDynamic object.
 	 * 
@@ -92,7 +95,7 @@ public class RowDataDynamic implements RowData {
 		this.columnCount = colCount;
 		this.isBinaryEncoded = isBinaryEncoded;
 		this.metadata = fields;
-		
+		this.exceptionInterceptor = this.io.getExceptionInterceptor();
 		this.useBufferRowExplicit = MysqlIO.useBufferRowExplicit(this.metadata);
 	}
 
@@ -192,7 +195,7 @@ public class RowDataDynamic implements RowData {
 					
 					try {
 						stmt = conn.createStatement();
-						stmt.executeUpdate("SET net_write_timeout=" + oldValue);
+						((com.mysql.jdbc.StatementImpl)stmt).executeSimpleNonQuery(conn, "SET net_write_timeout=" + oldValue);
 					} finally {
 						if (stmt != null) {
 							stmt.close();
@@ -409,14 +412,15 @@ public class RowDataDynamic implements RowData {
 	private void nextRecord() throws SQLException {
 
 		try {
-			if (!this.isAtEnd) {				
+			if (!this.noMoreRows) {				
 				this.nextRow = this.io.nextRow(this.metadata, this.columnCount,
 						this.isBinaryEncoded,
 						java.sql.ResultSet.CONCUR_READ_ONLY, true, 
 						this.useBufferRowExplicit, true, null);
 
 				if (this.nextRow == null) {
-					this.isAtEnd = true;
+					this.noMoreRows = true;
+					this.isAfterEnd = true;
 					this.moreResultsExisted = this.io.tackOnMoreStreamingResults(this.owner);
 
 					if (this.index == -1) {
@@ -443,7 +447,7 @@ public class RowDataDynamic implements RowData {
 			SQLException sqlEx = SQLError.createSQLException(
 					Messages.getString("RowDataDynamic.8") //$NON-NLS-1$
 							+ exceptionType
-							+ Messages.getString("RowDataDynamic.9") + exceptionMessage, SQLError.SQL_STATE_GENERAL_ERROR); //$NON-NLS-1$
+							+ Messages.getString("RowDataDynamic.9") + exceptionMessage, SQLError.SQL_STATE_GENERAL_ERROR, this.exceptionInterceptor); //$NON-NLS-1$
 			sqlEx.initCause(ex);
 			
 			throw sqlEx;
