@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2002-2007 MySQL AB
+ Copyright  2002-2007 MySQL AB, 2008 Sun Microsystems
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License as 
@@ -755,7 +755,7 @@ public class SQLError {
 				if (forTruncationOnly) {
 					if (code == 1265 || code == 1264) {
 						DataTruncation newTruncation = new MysqlDataTruncation(
-								warnRs.getString("Message"), 0, false, false, 0, 0); //$NON-NLS-1$
+								warnRs.getString("Message"), 0, false, false, 0, 0, code); //$NON-NLS-1$
 
 						if (currentWarning == null) {
 							currentWarning = newTruncation;
@@ -922,22 +922,22 @@ public class SQLError {
 	 */
 
 	public static SQLException createSQLException(String message,
-			String sqlState) {
-		return createSQLException(message, sqlState, 0);
+			String sqlState, ExceptionInterceptor interceptor) {
+		return createSQLException(message, sqlState, 0, interceptor);
 	}
 
-	public static SQLException createSQLException(String message) {
+	public static SQLException createSQLException(String message, ExceptionInterceptor interceptor) {
 		return new SQLException(message);
 	}
 
-	public static SQLException createSQLException(String message, String sqlState, Throwable cause) {
+	public static SQLException createSQLException(String message, String sqlState, Throwable cause, ExceptionInterceptor interceptor) {
 		if (THROWABLE_INIT_CAUSE_METHOD == null) {
 			if (cause != null) {
 				message = message + " due to " + cause.toString();
 			}
 		}
 		
-		SQLException sqlEx = createSQLException(message, sqlState);
+		SQLException sqlEx = createSQLException(message, sqlState, interceptor);
 		
 		if (cause != null && THROWABLE_INIT_CAUSE_METHOD != null) {
 			try {
@@ -952,12 +952,12 @@ public class SQLError {
 	}
 	
 	public static SQLException createSQLException(String message,
-			String sqlState, int vendorErrorCode) {
-		return createSQLException(message, sqlState, vendorErrorCode, false);
+			String sqlState, int vendorErrorCode, ExceptionInterceptor interceptor) {
+		return createSQLException(message, sqlState, vendorErrorCode, false, interceptor);
 	}
 	
 	public static SQLException createSQLException(String message,
-			String sqlState, int vendorErrorCode, boolean isTransient) {
+			String sqlState, int vendorErrorCode, boolean isTransient, ExceptionInterceptor interceptor) {
 		try {
 			if (sqlState != null) {
 				if (sqlState.startsWith("08")) {
@@ -973,7 +973,7 @@ public class SQLError {
 										new Class[] { String.class,
 												String.class, Integer.TYPE },
 										new Object[] { message, sqlState,
-												Constants.integerValueOf(vendorErrorCode) });
+												Constants.integerValueOf(vendorErrorCode) }, interceptor);
 					}
 
 					if (!Util.isJdbc4()) {
@@ -987,7 +987,7 @@ public class SQLError {
 									new Class[] { String.class, String.class,
 											Integer.TYPE  }, new Object[] {
 											message, sqlState,
-											Constants.integerValueOf(vendorErrorCode) });
+											Constants.integerValueOf(vendorErrorCode) }, interceptor);
 				}
 
 				if (sqlState.startsWith("22")) {
@@ -1002,7 +1002,7 @@ public class SQLError {
 									new Class[] { String.class, String.class,
 											Integer.TYPE  }, new Object[] {
 											message, sqlState,
-											Constants.integerValueOf(vendorErrorCode) });
+											Constants.integerValueOf(vendorErrorCode) }, interceptor);
 				}
 
 				if (sqlState.startsWith("23")) {
@@ -1018,7 +1018,7 @@ public class SQLError {
 									new Class[] { String.class, String.class,
 											Integer.TYPE  }, new Object[] {
 											message, sqlState,
-											Constants.integerValueOf(vendorErrorCode) });
+											Constants.integerValueOf(vendorErrorCode) }, interceptor);
 				}
 
 				if (sqlState.startsWith("42")) {
@@ -1033,7 +1033,7 @@ public class SQLError {
 									new Class[] { String.class, String.class,
 											Integer.TYPE  }, new Object[] {
 											message, sqlState,
-											Constants.integerValueOf(vendorErrorCode) });
+											Constants.integerValueOf(vendorErrorCode) }, interceptor);
 				}
 
 				if (sqlState.startsWith("40")) {
@@ -1048,7 +1048,7 @@ public class SQLError {
 									new Class[] { String.class, String.class,
 											Integer.TYPE  }, new Object[] {
 											message, sqlState,
-											Constants.integerValueOf(vendorErrorCode) });
+											Constants.integerValueOf(vendorErrorCode) }, interceptor);
 				}
 			}
 
@@ -1063,7 +1063,7 @@ public class SQLError {
 	
 	public static SQLException createCommunicationsException(ConnectionImpl conn, long lastPacketSentTimeMs, 
 			long lastPacketReceivedTimeMs,
-			Exception underlyingException) {
+			Exception underlyingException, ExceptionInterceptor interceptor) {
 		SQLException exToReturn = null;
 		
 		if (!Util.isJdbc4()) {
@@ -1072,7 +1072,7 @@ public class SQLError {
 		
 			try {
 				exToReturn = (SQLException) Util.handleNewInstance(JDBC_4_COMMUNICATIONS_EXCEPTION_CTOR, new Object[] {
-					conn, Constants.longValueOf(lastPacketSentTimeMs), Constants.longValueOf(lastPacketReceivedTimeMs), underlyingException});
+					conn, Constants.longValueOf(lastPacketSentTimeMs), Constants.longValueOf(lastPacketReceivedTimeMs), underlyingException}, interceptor);
 			} catch (SQLException sqlEx) {
 				// We should _never_ get this, but let's not swallow it either
 				
@@ -1142,7 +1142,8 @@ public class SQLError {
 		}
 
 		long timeSinceLastPacket = (System.currentTimeMillis() - lastPacketSentTimeMs) / 1000;
-		long timeSinceLastPacketReceived = (System.currentTimeMillis() - lastPacketReceivedTimeMs) / 1000;
+		long timeSinceLastPacketMs = (System.currentTimeMillis() - lastPacketSentTimeMs);
+		long timeSinceLastPacketReceivedMs = (System.currentTimeMillis() - lastPacketReceivedTimeMs);
 		
 		int dueToTimeout = DUE_TO_TIMEOUT_FALSE;
 
@@ -1188,17 +1189,19 @@ public class SQLError {
 			if (dueToTimeout == DUE_TO_TIMEOUT_TRUE
 					|| dueToTimeout == DUE_TO_TIMEOUT_MAYBE) {
 
-				exceptionMessageBuf.append(Messages
-						.getString("CommunicationsException.9_1")); //$NON-NLS-1$
-				exceptionMessageBuf.append(timeSinceLastPacketReceived);
-				exceptionMessageBuf.append(Messages
-						.getString("CommunicationsException.9_2")); //$NON-NLS-1$
-				
-				exceptionMessageBuf.append(Messages
-						.getString("CommunicationsException.9")); //$NON-NLS-1$
-				exceptionMessageBuf.append(timeSinceLastPacket);
-				exceptionMessageBuf.append(Messages
-						.getString("CommunicationsException.10")); //$NON-NLS-1$
+				if (lastPacketReceivedTimeMs != 0) {
+					Object[] timingInfo = {
+							new Long(timeSinceLastPacketReceivedMs),
+							new Long(timeSinceLastPacketMs)
+					};
+					exceptionMessageBuf.append(Messages
+							.getString("CommunicationsException.ServerPacketTimingInfo", //$NON-NLS-1$
+									timingInfo));
+				} else {
+					exceptionMessageBuf.append(Messages
+							.getString("CommunicationsException.ServerPacketTimingInfoNoRecv", //$NON-NLS-1$
+									new Object[] { new Long(timeSinceLastPacketMs)}));
+				}
 
 				if (timeoutMessageBuf != null) {
 					exceptionMessageBuf.append(timeoutMessageBuf);
@@ -1222,21 +1225,11 @@ public class SQLError {
 							&& !Util.interfaceExists(conn
 									.getLocalSocketAddress())) {
 						exceptionMessageBuf.append(Messages
-								.getString("CommunicationsException.19a")); //$NON-NLS-1$
+								.getString("CommunicationsException.LocalSocketAddressNotAvailable")); //$NON-NLS-1$
 					} else {
 						// too many client connections???
 						exceptionMessageBuf.append(Messages
-								.getString("CommunicationsException.14")); //$NON-NLS-1$
-						exceptionMessageBuf.append(Messages
-								.getString("CommunicationsException.15")); //$NON-NLS-1$
-						exceptionMessageBuf.append(Messages
-								.getString("CommunicationsException.16")); //$NON-NLS-1$
-						exceptionMessageBuf.append(Messages
-								.getString("CommunicationsException.17")); //$NON-NLS-1$
-						exceptionMessageBuf.append(Messages
-								.getString("CommunicationsException.18")); //$NON-NLS-1$
-						exceptionMessageBuf.append(Messages
-								.getString("CommunicationsException.19")); //$NON-NLS-1$
+								.getString("CommunicationsException.TooManyClientConnections")); //$NON-NLS-1$
 					}
 				}
 			}
@@ -1257,11 +1250,20 @@ public class SQLError {
 
 			if (conn != null && conn.getMaintainTimeStats()
 					&& !conn.getParanoid()) {
-				exceptionMessageBuf
-						.append("\n\nLast packet sent to the server was ");
-				exceptionMessageBuf.append(System.currentTimeMillis()
-						- lastPacketSentTimeMs);
-				exceptionMessageBuf.append(" ms ago.");
+				exceptionMessageBuf.append("\n\n"); //$NON-NLS-1$
+				if (lastPacketReceivedTimeMs != 0) {
+					Object[] timingInfo = {
+							new Long(timeSinceLastPacketReceivedMs),
+							new Long(timeSinceLastPacketMs)
+					};
+					exceptionMessageBuf.append(Messages
+							.getString("CommunicationsException.ServerPacketTimingInfo", //$NON-NLS-1$
+									timingInfo));
+				} else {
+					exceptionMessageBuf.append(Messages
+							.getString("CommunicationsException.ServerPacketTimingInfoNoRecv", //$NON-NLS-1$
+									new Object[] { new Long(timeSinceLastPacketMs)}));
+				}
 			}
 		}
 		
