@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2002-2007 MySQL AB
+ Copyright  2002-2007 MySQL AB, 2008 Sun Microsystems
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License as 
@@ -265,6 +265,8 @@ public class ServerPreparedStatement extends PreparedStatement {
 	 * (seconds) + 4 (microseconds)
 	 */
 	private static final byte MAX_TIME_REP_LENGTH = 13;
+	
+	private boolean hasOnDuplicateKeyUpdate = false;
 
 	private void storeTime(Buffer intoBuf, Time tm) throws SQLException {
 		
@@ -390,6 +392,8 @@ public class ServerPreparedStatement extends PreparedStatement {
 
 		checkNullOrEmptyQuery(sql);
 
+		this.hasOnDuplicateKeyUpdate = containsOnDuplicateKeyInString(sql);
+		
 		int startOfStatement = findStartOfStatement(sql);
 		
 		this.firstCharOfStmt = StringUtils.firstAlphaCharUc(sql, startOfStatement);
@@ -429,7 +433,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 			realClose(false, true);
 
 			SQLException sqlEx = SQLError.createSQLException(ex.toString(),
-					SQLError.SQL_STATE_GENERAL_ERROR);
+					SQLError.SQL_STATE_GENERAL_ERROR, getExceptionInterceptor());
 			sqlEx.initCause(ex);
 			
 			throw sqlEx;
@@ -679,7 +683,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 			throw SQLError.createSQLException(Messages
 					.getString("ServerPreparedStatement.2") //$NON-NLS-1$
 					+ Messages.getString("ServerPreparedStatement.3"), //$NON-NLS-1$
-					SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+					SQLError.SQL_STATE_ILLEGAL_ARGUMENT, getExceptionInterceptor());
 		}
 
 		checkClosed();
@@ -770,7 +774,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 											while (rs.next()) {
 												this.batchedGeneratedKeys
 														.add(new ByteArrayRow(new byte[][] { rs
-																.getBytes(1) }));
+																.getBytes(1) }, getExceptionInterceptor()));
 											}
 										} finally {
 											if (rs != null) {
@@ -783,7 +787,8 @@ public class ServerPreparedStatement extends PreparedStatement {
 									
 									if (this.continueBatchOnError && 
 											!(ex instanceof MySQLTimeoutException) && 
-											!(ex instanceof MySQLStatementCancelledException)) {
+											!(ex instanceof MySQLStatementCancelledException)
+											&& !hasDeadlockOrTimeoutRolledBackTx(ex)) {
 										sqlEx = ex;
 									} else {
 										int[] newUpdateCounts = new int[commandIndex];
@@ -852,7 +857,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 				messageBuf.append(extractedSql);
 
 				sqlEx = ConnectionImpl.appendMessageToException(sqlEx, messageBuf
-						.toString());
+						.toString(), getExceptionInterceptor());
 			}
 
 			throw sqlEx;
@@ -862,7 +867,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 			}
 
 			SQLException sqlEx = SQLError.createSQLException(ex.toString(),
-					SQLError.SQL_STATE_GENERAL_ERROR);
+					SQLError.SQL_STATE_GENERAL_ERROR, getExceptionInterceptor());
 
 			if (this.connection.getDumpQueriesOnException()) {
 				String extractedSql = toString();
@@ -873,7 +878,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 				messageBuf.append(extractedSql);
 
 				sqlEx = ConnectionImpl.appendMessageToException(sqlEx, messageBuf
-						.toString());
+						.toString(), getExceptionInterceptor());
 			}
 
 			sqlEx.initCause(ex);
@@ -915,7 +920,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 		if (this.parameterBindings.length == 0) {
 			throw SQLError.createSQLException(Messages
 					.getString("ServerPreparedStatement.8"), //$NON-NLS-1$
-					SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+					SQLError.SQL_STATE_ILLEGAL_ARGUMENT, getExceptionInterceptor());
 		}
 
 		parameterIndex--;
@@ -927,7 +932,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 					+ (parameterIndex + 1)
 					+ Messages.getString("ServerPreparedStatement.10") //$NON-NLS-1$
 					+ this.parameterBindings.length,
-					SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+					SQLError.SQL_STATE_ILLEGAL_ARGUMENT, getExceptionInterceptor());
 		}
 
 		if (this.parameterBindings[parameterIndex] == null) {
@@ -991,7 +996,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 		}
 
 		return new ResultSetMetaData(this.resultFields, 
-				this.connection.getUseOldAliasMetadataBehavior());
+				this.connection.getUseOldAliasMetadataBehavior(), getExceptionInterceptor());
 	}
 
 	/**
@@ -1002,7 +1007,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 		
 		if (this.parameterMetaData == null) {
 			this.parameterMetaData = new MysqlParameterMetadata(
-					this.parameterFields, this.parameterCount);
+					this.parameterFields, this.parameterCount, getExceptionInterceptor());
 		}
 		
 		return this.parameterMetaData;
@@ -1061,7 +1066,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 						packet.writeLong(this.serverStatementId);
 
 						mysql.sendCommand(MysqlDefs.COM_CLOSE_STATEMENT, null,
-								packet, true, null);
+								packet, true, null, 0);
 					} catch (SQLException sqlEx) {
 						exceptionDuringClose = sqlEx;
 					}
@@ -1099,7 +1104,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 			this.invalidationException = sqlEx;
 		} catch (Exception ex) {
 			this.invalidationException = SQLError.createSQLException(ex.toString(),
-					SQLError.SQL_STATE_GENERAL_ERROR);
+					SQLError.SQL_STATE_GENERAL_ERROR, getExceptionInterceptor());
 			this.invalidationException.initCause(ex);
 		}
 
@@ -1180,7 +1185,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 							throw SQLError.createSQLException(Messages
 									.getString("ServerPreparedStatement.11") //$NON-NLS-1$
 									+ Messages.getString("ServerPreparedStatement.12"), //$NON-NLS-1$
-									SQLError.SQL_STATE_DRIVER_NOT_CAPABLE);
+									SQLError.SQL_STATE_DRIVER_NOT_CAPABLE, getExceptionInterceptor());
 						} else {
 							firstFound = true;
 							boundTimeToCheck = this.parameterBindings[i].boundBeforeExecutionNum;
@@ -1201,7 +1206,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 					throw SQLError.createSQLException(Messages
 							.getString("ServerPreparedStatement.13") + (i + 1) //$NON-NLS-1$
 							+ Messages.getString("ServerPreparedStatement.14"),
-							SQLError.SQL_STATE_ILLEGAL_ARGUMENT); //$NON-NLS-1$
+							SQLError.SQL_STATE_ILLEGAL_ARGUMENT, getExceptionInterceptor()); //$NON-NLS-1$
 				}
 			}
 
@@ -1326,7 +1331,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 				}
 				
 				Buffer resultPacket = mysql.sendCommand(MysqlDefs.COM_EXECUTE,
-					null, packet, false, null);
+					null, packet, false, null, 0);
 				
 				long queryEndTime = 0L;
 				
@@ -1516,7 +1521,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 				packet.writeBytesNoNull((byte[]) longData.value);
 
 				mysql.sendCommand(MysqlDefs.COM_LONG_DATA, null, packet, true,
-						null);
+						null, 0);
 			} else if (value instanceof InputStream) {
 				storeStream(mysql, parameterIndex, packet, (InputStream) value);
 			} else if (value instanceof java.sql.Blob) {
@@ -1528,7 +1533,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 				throw SQLError.createSQLException(Messages
 						.getString("ServerPreparedStatement.18") //$NON-NLS-1$
 						+ value.getClass().getName() + "'", //$NON-NLS-1$
-						SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+						SQLError.SQL_STATE_ILLEGAL_ARGUMENT, getExceptionInterceptor());
 			}
 		}
 	}
@@ -1564,7 +1569,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 
 				Buffer prepareResultPacket = mysql.sendCommand(
 						MysqlDefs.COM_PREPARE, sql, null, false,
-						characterEncoding);
+						characterEncoding, 0);
 
 				if (this.connection.versionMeetsMinimum(4, 1, 1)) {
 					// 4.1.1 and newer use the first byte
@@ -1642,7 +1647,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 					messageBuf.append(this.originalSql);
 
 					sqlEx = ConnectionImpl.appendMessageToException(sqlEx,
-							messageBuf.toString());
+							messageBuf.toString(), getExceptionInterceptor());
 				}
 
 				throw sqlEx;
@@ -1685,12 +1690,12 @@ public class ServerPreparedStatement extends PreparedStatement {
 
 			try {
 				mysql.sendCommand(MysqlDefs.COM_RESET_STMT, null, packet,
-						!this.connection.versionMeetsMinimum(4, 1, 2), null);
+						!this.connection.versionMeetsMinimum(4, 1, 2), null, 0);
 			} catch (SQLException sqlEx) {
 				throw sqlEx;
 			} catch (Exception ex) {
 				SQLException sqlEx = SQLError.createSQLException(ex.toString(),
-						SQLError.SQL_STATE_GENERAL_ERROR);
+						SQLError.SQL_STATE_GENERAL_ERROR, getExceptionInterceptor());
 				sqlEx.initCause(ex);
 				
 				throw sqlEx;
@@ -1954,7 +1959,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 						|| x == Double.NEGATIVE_INFINITY || Double.isNaN(x))) {
 			throw SQLError.createSQLException("'" + x
 					+ "' is not a valid numeric or approximate numeric value",
-					SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+					SQLError.SQL_STATE_ILLEGAL_ARGUMENT, getExceptionInterceptor());
 
 		}
 
@@ -2364,7 +2369,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 			throw SQLError.createSQLException(Messages
 					.getString("ServerPreparedStatement.22") //$NON-NLS-1$
 					+ this.connection.getEncoding() + "'", //$NON-NLS-1$
-					SQLError.SQL_STATE_GENERAL_ERROR);
+					SQLError.SQL_STATE_GENERAL_ERROR, getExceptionInterceptor());
 		}
 	}
 
@@ -2568,7 +2573,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 				byte[] valueAsBytes = StringUtils.getBytes(buf, null,
 						clobEncoding, this.connection
 								.getServerCharacterEncoding(), 0, numRead,
-						this.connection.parserKnowsUnicode());
+						this.connection.parserKnowsUnicode(), getExceptionInterceptor());
 
 				packet.writeBytesNoNull(valueAsBytes, 0, valueAsBytes.length);
 
@@ -2579,7 +2584,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 					bytesReadAtLastSend = totalBytesRead;
 
 					mysql.sendCommand(MysqlDefs.COM_LONG_DATA, null, packet,
-							true, null);
+							true, null, 0);
 
 					bytesInPacket = 0;
 					packet.clear();
@@ -2591,17 +2596,17 @@ public class ServerPreparedStatement extends PreparedStatement {
 
 			if (totalBytesRead != bytesReadAtLastSend) {
 				mysql.sendCommand(MysqlDefs.COM_LONG_DATA, null, packet, true,
-						null);
+						null, 0);
 			}
 			
 			if (!readAny) {
 				mysql.sendCommand(MysqlDefs.COM_LONG_DATA, null, packet, true,
-						null);
+						null, 0);
 			}
 		} catch (IOException ioEx) {
 			SQLException sqlEx = SQLError.createSQLException(Messages
 					.getString("ServerPreparedStatement.24") //$NON-NLS-1$
-					+ ioEx.toString(), SQLError.SQL_STATE_GENERAL_ERROR);
+					+ ioEx.toString(), SQLError.SQL_STATE_GENERAL_ERROR, getExceptionInterceptor());
 			sqlEx.initCause(ioEx);
 			
 			throw sqlEx;
@@ -2649,7 +2654,7 @@ public class ServerPreparedStatement extends PreparedStatement {
 					bytesReadAtLastSend = totalBytesRead;
 
 					mysql.sendCommand(MysqlDefs.COM_LONG_DATA, null, packet,
-							true, null);
+							true, null, 0);
 
 					bytesInPacket = 0;
 					packet.clear();
@@ -2661,17 +2666,17 @@ public class ServerPreparedStatement extends PreparedStatement {
 
 			if (totalBytesRead != bytesReadAtLastSend) {
 				mysql.sendCommand(MysqlDefs.COM_LONG_DATA, null, packet, true,
-						null);
+						null, 0);
 			}
 			
 			if (!readAny) {
 				mysql.sendCommand(MysqlDefs.COM_LONG_DATA, null, packet, true,
-						null);
+						null, 0);
 			}
 		} catch (IOException ioEx) {
 			SQLException sqlEx = SQLError.createSQLException(Messages
 					.getString("ServerPreparedStatement.25") //$NON-NLS-1$
-					+ ioEx.toString(), SQLError.SQL_STATE_GENERAL_ERROR);
+					+ ioEx.toString(), SQLError.SQL_STATE_GENERAL_ERROR, getExceptionInterceptor());
 			sqlEx.initCause(ioEx);
 			
 			throw sqlEx;
@@ -2712,8 +2717,23 @@ public class ServerPreparedStatement extends PreparedStatement {
 		return serverStatementId;
 	}
 
-	public synchronized boolean canRewriteAsMultivalueInsertStatement() {
-		if (!super.canRewriteAsMultivalueInsertStatement()) {
+	private boolean hasCheckedRewrite = false;
+	private boolean canRewrite = false;
+	
+	public synchronized boolean canRewriteAsMultiValueInsertAtSqlLevel() throws SQLException {
+		if (!hasCheckedRewrite) {
+			this.hasCheckedRewrite = true;
+			this.canRewrite = canRewrite(this.originalSql, isOnDuplicateKeyUpdate(), getLocationOfOnDuplicateKeyUpdate(), 0);
+			// We need to client-side parse this to get the VALUES clause, etc.
+			this.parseInfo = new ParseInfo(this.originalSql, this.connection, this.connection.getMetaData(), this.charEncoding, this.charConverter);
+		}
+		
+		return this.canRewrite;
+	}
+
+	
+	public synchronized boolean canRewriteAsMultivalueInsertStatement() throws SQLException {
+		if (!canRewriteAsMultiValueInsertAtSqlLevel()) {
 			return false;
 		}
 	
@@ -2745,8 +2765,27 @@ public class ServerPreparedStatement extends PreparedStatement {
 			}
 		}
 		
+		
+		
 		return true;
 	}
+	
+	private int locationOfOnDuplicateKeyUpdate = -2;
+	
+	protected synchronized int getLocationOfOnDuplicateKeyUpdate() {
+		if (this.locationOfOnDuplicateKeyUpdate == -2) {
+			this.locationOfOnDuplicateKeyUpdate = getOnDuplicateKeyLocation(this.originalSql);
+		}
+		
+		return this.locationOfOnDuplicateKeyUpdate;
+	}
+	
+	protected synchronized boolean isOnDuplicateKeyUpdate() {
+		return getLocationOfOnDuplicateKeyUpdate() != -1;
+	}
+
+	
+	
 
 	/** 
 	 *  Computes the maximum parameter set size, and entire batch size given 
@@ -2867,14 +2906,15 @@ public class ServerPreparedStatement extends PreparedStatement {
 									(String) value);
 						}
 	
-						BindValue asBound = ((ServerPreparedStatement) batchedStatement)
-								.getBinding(
-										batchedParamIndex + 1 /*
-																 * uses 1-based
-																 * offset
-																 */,
-										false);
-						asBound.bufferType = paramArg[j].bufferType;
+						// If we ended up here as a multi-statement, we're not working with a server prepared statement
+						
+						if (batchedStatement instanceof ServerPreparedStatement) {
+							BindValue asBound = ((ServerPreparedStatement) batchedStatement)
+									.getBinding(
+											batchedParamIndex,
+											false);
+							asBound.bufferType = paramArg[j].bufferType;
+						}
 	
 						batchedParamIndex++;
 	
@@ -2887,9 +2927,26 @@ public class ServerPreparedStatement extends PreparedStatement {
 				}
 			}
 		}
-	
+
 		return batchedParamIndex;
 	}
 
-
+	protected boolean containsOnDuplicateKeyUpdateInSQL() {
+		return this.hasOnDuplicateKeyUpdate;
+	}
+	
+	protected PreparedStatement prepareBatchedInsertSQL(ConnectionImpl localConn, int numBatches) throws SQLException {
+		try {
+			PreparedStatement pstmt = new ServerPreparedStatement(localConn, this.parseInfo.getSqlForBatch(numBatches), this.currentCatalog, this.resultSetConcurrency, this.resultSetType);
+			pstmt.setRetrieveGeneratedKeys(this.retrieveGeneratedKeys);
+			
+			return pstmt;
+		} catch (UnsupportedEncodingException e) {
+			SQLException sqlEx = SQLError.createSQLException("Unable to prepare batch statement", SQLError.SQL_STATE_GENERAL_ERROR, getExceptionInterceptor());
+			sqlEx.initCause(e);
+			
+			throw sqlEx;
+		}
+		
+	}
 }
