@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2002-2004 MySQL AB
+ Copyright  2002-2004 MySQL AB, 2008 Sun Microsystems
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License as 
@@ -31,9 +31,7 @@ import java.io.UnsupportedEncodingException;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 import java.math.BigDecimal;
-
 import java.sql.SQLException;
-
 import java.util.ArrayList;
 import java.util.List;
 import java.util.StringTokenizer;
@@ -394,7 +392,7 @@ public class StringUtils {
 
 	public static final byte[] getBytes(char[] c,
 			SingleByteCharsetConverter converter, String encoding,
-			String serverEncoding, boolean parserKnowsUnicode)
+			String serverEncoding, boolean parserKnowsUnicode, ExceptionInterceptor exceptionInterceptor)
 			throws SQLException {
 		try {
 			byte[] b = null;
@@ -422,14 +420,14 @@ public class StringUtils {
 		} catch (UnsupportedEncodingException uee) {
 			throw SQLError.createSQLException(Messages.getString("StringUtils.5") //$NON-NLS-1$
 					+ encoding + Messages.getString("StringUtils.6"),
-					SQLError.SQL_STATE_ILLEGAL_ARGUMENT); //$NON-NLS-1$
+					SQLError.SQL_STATE_ILLEGAL_ARGUMENT, exceptionInterceptor); //$NON-NLS-1$
 		}
 	}
 
 	public static final byte[] getBytes(char[] c,
 			SingleByteCharsetConverter converter, String encoding,
 			String serverEncoding, int offset, int length,
-			boolean parserKnowsUnicode) throws SQLException {
+			boolean parserKnowsUnicode, ExceptionInterceptor exceptionInterceptor) throws SQLException {
 		try {
 			byte[] b = null;
 
@@ -466,13 +464,13 @@ public class StringUtils {
 		} catch (UnsupportedEncodingException uee) {
 			throw SQLError.createSQLException(Messages.getString("StringUtils.10") //$NON-NLS-1$
 					+ encoding + Messages.getString("StringUtils.11"),
-					SQLError.SQL_STATE_ILLEGAL_ARGUMENT); //$NON-NLS-1$
+					SQLError.SQL_STATE_ILLEGAL_ARGUMENT, exceptionInterceptor); //$NON-NLS-1$
 		}
 	}
 
 	public static final byte[] getBytes(char[] c, String encoding,
 			String serverEncoding, boolean parserKnowsUnicode, 
-			ConnectionImpl conn)
+			ConnectionImpl conn, ExceptionInterceptor exceptionInterceptor)
 			throws SQLException {
 		try {
 			
@@ -485,11 +483,11 @@ public class StringUtils {
 			}
 
 			return getBytes(c, converter, encoding, serverEncoding,
-					parserKnowsUnicode);
+					parserKnowsUnicode, exceptionInterceptor);
 		} catch (UnsupportedEncodingException uee) {
 			throw SQLError.createSQLException(Messages.getString("StringUtils.0") //$NON-NLS-1$
 					+ encoding + Messages.getString("StringUtils.1"),
-					SQLError.SQL_STATE_ILLEGAL_ARGUMENT); //$NON-NLS-1$
+					SQLError.SQL_STATE_ILLEGAL_ARGUMENT, exceptionInterceptor); //$NON-NLS-1$
 		}
 	}
 
@@ -515,7 +513,7 @@ public class StringUtils {
 	 */
 	public static final byte[] getBytes(String s,
 			SingleByteCharsetConverter converter, String encoding,
-			String serverEncoding, boolean parserKnowsUnicode)
+			String serverEncoding, boolean parserKnowsUnicode, ExceptionInterceptor exceptionInterceptor)
 			throws SQLException {
 		try {
 			byte[] b = null;
@@ -541,13 +539,13 @@ public class StringUtils {
 		} catch (UnsupportedEncodingException uee) {
 			throw SQLError.createSQLException(Messages.getString("StringUtils.5") //$NON-NLS-1$
 					+ encoding + Messages.getString("StringUtils.6"),
-					SQLError.SQL_STATE_ILLEGAL_ARGUMENT); //$NON-NLS-1$
+					SQLError.SQL_STATE_ILLEGAL_ARGUMENT, exceptionInterceptor); //$NON-NLS-1$
 		}
 	}
 
 	public static final byte[] getBytesWrapped(String s, char beginWrap, char endWrap,
 			SingleByteCharsetConverter converter, String encoding,
-			String serverEncoding, boolean parserKnowsUnicode)
+			String serverEncoding, boolean parserKnowsUnicode, ExceptionInterceptor exceptionInterceptor)
 			throws SQLException {
 		try {
 			byte[] b = null;
@@ -583,7 +581,7 @@ public class StringUtils {
 		} catch (UnsupportedEncodingException uee) {
 			throw SQLError.createSQLException(Messages.getString("StringUtils.5") //$NON-NLS-1$
 					+ encoding + Messages.getString("StringUtils.6"),
-					SQLError.SQL_STATE_ILLEGAL_ARGUMENT); //$NON-NLS-1$
+					SQLError.SQL_STATE_ILLEGAL_ARGUMENT, exceptionInterceptor); //$NON-NLS-1$
 		}
 	}
 	
@@ -613,7 +611,7 @@ public class StringUtils {
 	public static final byte[] getBytes(String s,
 			SingleByteCharsetConverter converter, String encoding,
 			String serverEncoding, int offset, int length,
-			boolean parserKnowsUnicode) throws SQLException {
+			boolean parserKnowsUnicode, ExceptionInterceptor exceptionInterceptor) throws SQLException {
 		try {
 			byte[] b = null;
 
@@ -650,7 +648,7 @@ public class StringUtils {
 		} catch (UnsupportedEncodingException uee) {
 			throw SQLError.createSQLException(Messages.getString("StringUtils.10") //$NON-NLS-1$
 					+ encoding + Messages.getString("StringUtils.11"),
-					SQLError.SQL_STATE_ILLEGAL_ARGUMENT); //$NON-NLS-1$
+					SQLError.SQL_STATE_ILLEGAL_ARGUMENT, exceptionInterceptor); //$NON-NLS-1$
 		}
 	}
 
@@ -672,7 +670,7 @@ public class StringUtils {
 	 */
 	public static final byte[] getBytes(String s, String encoding,
 			String serverEncoding, boolean parserKnowsUnicode, 
-			ConnectionImpl conn)
+			ConnectionImpl conn, ExceptionInterceptor exceptionInterceptor)
 			throws SQLException {
 		try {
 			SingleByteCharsetConverter converter = null;
@@ -684,11 +682,11 @@ public class StringUtils {
 			}
 
 			return getBytes(s, converter, encoding, serverEncoding,
-					parserKnowsUnicode);
+					parserKnowsUnicode, exceptionInterceptor);
 		} catch (UnsupportedEncodingException uee) {
 			throw SQLError.createSQLException(Messages.getString("StringUtils.0") //$NON-NLS-1$
 					+ encoding + Messages.getString("StringUtils.1"),
-					SQLError.SQL_STATE_ILLEGAL_ARGUMENT); //$NON-NLS-1$
+					SQLError.SQL_STATE_ILLEGAL_ARGUMENT, exceptionInterceptor); //$NON-NLS-1$
 		}
 	}
 
@@ -931,8 +929,6 @@ public class StringUtils {
 		int stringLength = searchIn.length();
 		int stopSearchingAt = stringLength - patternLength;
 
-		int i = startingPosition;
-
 		if (patternLength == 0) {
 			return -1;
 		}
@@ -942,50 +938,39 @@ public class StringUtils {
 		char firstCharOfPatternUc = Character.toUpperCase(searchFor.charAt(0));
 		char firstCharOfPatternLc = Character.toLowerCase(searchFor.charAt(0));
 
-		lookForFirstChar: while (true) {
-			while ((i < stopSearchingAt)
-					&& (Character.toUpperCase(searchIn.charAt(i)) != firstCharOfPatternUc)
-					&& Character.toLowerCase(searchIn.charAt(i)) != firstCharOfPatternLc) {
-				i++;
-			}
+		// note, this also catches the case where patternLength > stringLength
+        for (int i = startingPosition; i <= stopSearchingAt; i++) {
+            if (isNotEqualIgnoreCharCase(searchIn, firstCharOfPatternUc,
+					firstCharOfPatternLc, i)) {
+            	// find the first occurrence of the first character of searchFor in searchIn
+                while (++i <= stopSearchingAt && (isNotEqualIgnoreCharCase(searchIn, firstCharOfPatternUc,
+						firstCharOfPatternLc, i)));
+            }
 
-			if (i > stopSearchingAt) {
-				return -1;
-			}
+            if (i <= stopSearchingAt /* searchFor might be one character long! */) {
+            	// walk searchIn and searchFor in lock-step starting just past the first match,bail out if not 
+            	// a match, or we've hit the end of searchFor...
+                int j = i + 1;
+                int end = j + patternLength - 1;
+                for (int k = 1; j < end && (Character.toLowerCase(searchIn.charAt(j)) == 
+                	Character.toLowerCase(searchFor.charAt(k)) || Character.toUpperCase(searchIn.charAt(j)) == 
+                    	Character.toUpperCase(searchFor.charAt(k))); j++, k++);
 
-			int j = i + 1;
-			int end = (j + patternLength) - 1;
-
-			int k = 1; // start at second char of pattern
-
-			while (j < end) {
-				int searchInPos = j++;
-				int searchForPos = k++;
-
-				if (Character.toUpperCase(searchIn.charAt(searchInPos)) != Character
-						.toUpperCase(searchFor.charAt(searchForPos))) {
-					i++;
-
-					// start over
-					continue lookForFirstChar;
-				}
-
-				// Georgian and Turkish locales don't have same convention, so
-				// need to check lowercase
-				// too!
-				if (Character.toLowerCase(searchIn.charAt(searchInPos)) != Character
-						.toLowerCase(searchFor.charAt(searchForPos))) {
-					i++;
-
-					// start over
-					continue lookForFirstChar;
-				}
-			}
-
-			return i; // found entire pattern
-		}
+                if (j == end) {
+                    return i;
+                }
+            }
+        }
+        
+        return -1;
 	}
 
+	private final static boolean isNotEqualIgnoreCharCase(String searchIn,
+			char firstCharOfPatternUc, char firstCharOfPatternLc, int i) {
+		return Character.toLowerCase(searchIn.charAt(i)) != firstCharOfPatternLc && Character.toUpperCase(searchIn.charAt(i)) != firstCharOfPatternUc;
+	}
+	
+
 	/**
 	 * DOCUMENT ME!
 	 * 
@@ -1020,9 +1005,10 @@ public class StringUtils {
 					&& contextMarker == Character.MIN_VALUE) {
 				markerTypeFound = ind;
 				contextMarker = c;
-			} else if (c == target.charAt(0) && !escaped
+			} else if ((Character.toUpperCase(c) == Character.toUpperCase(target.charAt(0)) ||
+					Character.toLowerCase(c) == Character.toLowerCase(target.charAt(0))) && !escaped
 					&& contextMarker == Character.MIN_VALUE) {
-				if (indexOfIgnoreCase(i, src, target) != -1)
+				if (startsWithIgnoreCase(src, i, target))
 					return i;
 			}
 		}
