@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2002-2007 MySQL AB
+ Copyright  2002-2007 MySQL AB, 2008 Sun Microsystems
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License as
@@ -234,199 +234,204 @@ public class UpdatableResultSet extends ResultSetImpl {
 	 *             DOCUMENT ME!
 	 */
 	protected void checkUpdatability() throws SQLException {
-		if (this.fields == null) {
-			// we've been created to be populated with cached
-			// metadata, and we don't have the metadata yet,
-			// we'll be called again by
-			// Connection.initializeResultsMetadataFromCache()
-			// when the metadata has been made available
-
-			return;
-		}
-
-		String singleTableName = null;
-		String catalogName = null;
-
-		int primaryKeyCount = 0;
-
-		// We can only do this if we know that there is a currently
-		// selected database, or if we're talking to a > 4.1 version
-		// of MySQL server (as it returns database names in field
-		// info)
-		//
-		if ((this.catalog == null) || (this.catalog.length() == 0)) {
-			this.catalog = this.fields[0].getDatabaseName();
-
-			if ((this.catalog == null) || (this.catalog.length() == 0)) {
-				throw SQLError.createSQLException(Messages
-						.getString("UpdatableResultSet.43") //$NON-NLS-1$
-						, SQLError.SQL_STATE_ILLEGAL_ARGUMENT); //$NON-NLS-1$ //$NON-NLS-2$
-			}
-		}
-
-		if (this.fields.length > 0) {
-			singleTableName = this.fields[0].getOriginalTableName();
-			catalogName = this.fields[0].getDatabaseName();
-
-			if (singleTableName == null) {
-				singleTableName = this.fields[0].getTableName();
-				catalogName = this.catalog;
-			}
-
-			if (singleTableName != null && singleTableName.length() == 0) {
-				this.isUpdatable = false;
-				this.notUpdatableReason = Messages.getString("NotUpdatableReason.3");
-
+		try {
+			if (this.fields == null) {
+				// we've been created to be populated with cached
+				// metadata, and we don't have the metadata yet,
+				// we'll be called again by
+				// Connection.initializeResultsMetadataFromCache()
+				// when the metadata has been made available
+	
 				return;
 			}
-
-			if (this.fields[0].isPrimaryKey()) {
-				primaryKeyCount++;
-			}
-
+	
+			String singleTableName = null;
+			String catalogName = null;
+	
+			int primaryKeyCount = 0;
+	
+			// We can only do this if we know that there is a currently
+			// selected database, or if we're talking to a > 4.1 version
+			// of MySQL server (as it returns database names in field
+			// info)
 			//
-			// References only one table?
-			//
-			for (int i = 1; i < this.fields.length; i++) {
-				String otherTableName = this.fields[i].getOriginalTableName();
-				String otherCatalogName = this.fields[i].getDatabaseName();
-
-				if (otherTableName == null) {
-					otherTableName = this.fields[i].getTableName();
-					otherCatalogName = this.catalog;
+			if ((this.catalog == null) || (this.catalog.length() == 0)) {
+				this.catalog = this.fields[0].getDatabaseName();
+	
+				if ((this.catalog == null) || (this.catalog.length() == 0)) {
+					throw SQLError.createSQLException(Messages
+							.getString("UpdatableResultSet.43") //$NON-NLS-1$
+							, SQLError.SQL_STATE_ILLEGAL_ARGUMENT, getExceptionInterceptor()); //$NON-NLS-1$ //$NON-NLS-2$
 				}
-
-				if (otherTableName != null && otherTableName.length() == 0) {
+			}
+	
+			if (this.fields.length > 0) {
+				singleTableName = this.fields[0].getOriginalTableName();
+				catalogName = this.fields[0].getDatabaseName();
+	
+				if (singleTableName == null) {
+					singleTableName = this.fields[0].getTableName();
+					catalogName = this.catalog;
+				}
+	
+				if (singleTableName != null && singleTableName.length() == 0) {
 					this.isUpdatable = false;
 					this.notUpdatableReason = Messages.getString("NotUpdatableReason.3");
-
+	
 					return;
 				}
-
-				if ((singleTableName == null)
-						|| !otherTableName.equals(singleTableName)) {
-					this.isUpdatable = false;
-					this.notUpdatableReason = Messages.getString("NotUpdatableReason.0");
-
-					return;
-				}
-
-				// Can't reference more than one database
-				if ((catalogName == null)
-						|| !otherCatalogName.equals(catalogName)) {
-					this.isUpdatable = false;
-					this.notUpdatableReason = Messages.getString("NotUpdatableReason.1");
-
-					return;
-				}
-
-				if (this.fields[i].isPrimaryKey()) {
+	
+				if (this.fields[0].isPrimaryKey()) {
 					primaryKeyCount++;
 				}
-			}
-
-			if ((singleTableName == null) || (singleTableName.length() == 0)) {
+	
+				//
+				// References only one table?
+				//
+				for (int i = 1; i < this.fields.length; i++) {
+					String otherTableName = this.fields[i].getOriginalTableName();
+					String otherCatalogName = this.fields[i].getDatabaseName();
+	
+					if (otherTableName == null) {
+						otherTableName = this.fields[i].getTableName();
+						otherCatalogName = this.catalog;
+					}
+	
+					if (otherTableName != null && otherTableName.length() == 0) {
+						this.isUpdatable = false;
+						this.notUpdatableReason = Messages.getString("NotUpdatableReason.3");
+	
+						return;
+					}
+	
+					if ((singleTableName == null)
+							|| !otherTableName.equals(singleTableName)) {
+						this.isUpdatable = false;
+						this.notUpdatableReason = Messages.getString("NotUpdatableReason.0");
+	
+						return;
+					}
+	
+					// Can't reference more than one database
+					if ((catalogName == null)
+							|| !otherCatalogName.equals(catalogName)) {
+						this.isUpdatable = false;
+						this.notUpdatableReason = Messages.getString("NotUpdatableReason.1");
+	
+						return;
+					}
+	
+					if (this.fields[i].isPrimaryKey()) {
+						primaryKeyCount++;
+					}
+				}
+	
+				if ((singleTableName == null) || (singleTableName.length() == 0)) {
+					this.isUpdatable = false;
+					this.notUpdatableReason = Messages.getString("NotUpdatableReason.2");
+	
+					return;
+				}
+			} else {
 				this.isUpdatable = false;
-				this.notUpdatableReason = Messages.getString("NotUpdatableReason.2");
-
+				this.notUpdatableReason = Messages.getString("NotUpdatableReason.3");
+	
 				return;
 			}
-		} else {
-			this.isUpdatable = false;
-			this.notUpdatableReason = Messages.getString("NotUpdatableReason.3");
-
-			return;
-		}
-
-		if (this.connection.getStrictUpdates()) {
-			java.sql.DatabaseMetaData dbmd = this.connection.getMetaData();
-
-			java.sql.ResultSet rs = null;
-			HashMap primaryKeyNames = new HashMap();
-
-			try {
-				rs = dbmd.getPrimaryKeys(catalogName, null, singleTableName);
-
-				while (rs.next()) {
-					String keyName = rs.getString(4);
-					keyName = keyName.toUpperCase();
-					primaryKeyNames.put(keyName, keyName);
-				}
-			} finally {
-				if (rs != null) {
-					try {
-						rs.close();
-					} catch (Exception ex) {
-						AssertionFailedException.shouldNotHappen(ex);
+	
+			if (this.connection.getStrictUpdates()) {
+				java.sql.DatabaseMetaData dbmd = this.connection.getMetaData();
+	
+				java.sql.ResultSet rs = null;
+				HashMap primaryKeyNames = new HashMap();
+	
+				try {
+					rs = dbmd.getPrimaryKeys(catalogName, null, singleTableName);
+	
+					while (rs.next()) {
+						String keyName = rs.getString(4);
+						keyName = keyName.toUpperCase();
+						primaryKeyNames.put(keyName, keyName);
+					}
+				} finally {
+					if (rs != null) {
+						try {
+							rs.close();
+						} catch (Exception ex) {
+							AssertionFailedException.shouldNotHappen(ex);
+						}
+	
+						rs = null;
 					}
-
-					rs = null;
 				}
-			}
-
-			int existingPrimaryKeysCount = primaryKeyNames.size();
-
-			if (existingPrimaryKeysCount == 0) {
-				this.isUpdatable = false;
-				this.notUpdatableReason = Messages.getString("NotUpdatableReason.5");
-
-				return; // we can't update tables w/o keys
-			}
-
-			//
-			// Contains all primary keys?
-			//
-			for (int i = 0; i < this.fields.length; i++) {
-				if (this.fields[i].isPrimaryKey()) {
-					String columnNameUC = this.fields[i].getName()
-							.toUpperCase();
-
-					if (primaryKeyNames.remove(columnNameUC) == null) {
-						// try original name
-						String originalName = this.fields[i].getOriginalName();
-
-						if (originalName != null) {
-							if (primaryKeyNames.remove(originalName
-									.toUpperCase()) == null) {
-								// we don't know about this key, so give up :(
-								this.isUpdatable = false;
-								this.notUpdatableReason = Messages.getString("NotUpdatableReason.6",
-										new Object[] {originalName});
-
-								return;
+	
+				int existingPrimaryKeysCount = primaryKeyNames.size();
+	
+				if (existingPrimaryKeysCount == 0) {
+					this.isUpdatable = false;
+					this.notUpdatableReason = Messages.getString("NotUpdatableReason.5");
+	
+					return; // we can't update tables w/o keys
+				}
+	
+				//
+				// Contains all primary keys?
+				//
+				for (int i = 0; i < this.fields.length; i++) {
+					if (this.fields[i].isPrimaryKey()) {
+						String columnNameUC = this.fields[i].getName()
+								.toUpperCase();
+	
+						if (primaryKeyNames.remove(columnNameUC) == null) {
+							// try original name
+							String originalName = this.fields[i].getOriginalName();
+	
+							if (originalName != null) {
+								if (primaryKeyNames.remove(originalName
+										.toUpperCase()) == null) {
+									// we don't know about this key, so give up :(
+									this.isUpdatable = false;
+									this.notUpdatableReason = Messages.getString("NotUpdatableReason.6",
+											new Object[] {originalName});
+	
+									return;
+								}
 							}
 						}
 					}
 				}
-			}
-
-			this.isUpdatable = primaryKeyNames.isEmpty();
-
-			if (!this.isUpdatable) {
-				if (existingPrimaryKeysCount > 1) {
-					this.notUpdatableReason = Messages.getString("NotUpdatableReason.7");
-				} else {
-					this.notUpdatableReason = Messages.getString("NotUpdatableReason.4");
+	
+				this.isUpdatable = primaryKeyNames.isEmpty();
+	
+				if (!this.isUpdatable) {
+					if (existingPrimaryKeysCount > 1) {
+						this.notUpdatableReason = Messages.getString("NotUpdatableReason.7");
+					} else {
+						this.notUpdatableReason = Messages.getString("NotUpdatableReason.4");
+					}
+	
+					return;
 				}
-
+			}
+	
+			//
+			// Must have at least one primary key
+			//
+			if (primaryKeyCount == 0) {
+				this.isUpdatable = false;
+				this.notUpdatableReason = Messages.getString("NotUpdatableReason.4");
+	
 				return;
 			}
-		}
-
-		//
-		// Must have at least one primary key
-		//
-		if (primaryKeyCount == 0) {
-			this.isUpdatable = false;
-			this.notUpdatableReason = Messages.getString("NotUpdatableReason.4");
-
+	
+			this.isUpdatable = true;
+			this.notUpdatableReason = null;
+	
 			return;
+		} catch (SQLException sqlEx) {
+			this.isUpdatable = false;
+			this.notUpdatableReason = sqlEx.getMessage();
 		}
-
-		this.isUpdatable = true;
-		this.notUpdatableReason = null;
-
-		return;
 	}
 
 	/**
@@ -447,13 +452,13 @@ public class UpdatableResultSet extends ResultSetImpl {
 		}
 
 		if (this.onInsertRow) {
-			throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.1")); //$NON-NLS-1$
+			throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.1"), getExceptionInterceptor()); //$NON-NLS-1$
 		} else if (this.rowData.size() == 0) {
-			throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.2")); //$NON-NLS-1$
+			throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.2"), getExceptionInterceptor()); //$NON-NLS-1$
 		} else if (isBeforeFirst()) {
-			throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.3")); //$NON-NLS-1$
+			throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.3"), getExceptionInterceptor()); //$NON-NLS-1$
 		} else if (isAfterLast()) {
-			throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.4")); //$NON-NLS-1$
+			throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.4"), getExceptionInterceptor()); //$NON-NLS-1$
 		}
 
 		if (this.deleter == null) {
@@ -473,38 +478,29 @@ public class UpdatableResultSet extends ResultSetImpl {
 			characterEncoding = this.connection.getEncoding();
 		}
 
-		//
-		// FIXME: Use internal routines where possible for character
-		// conversion!
-		try {
-			int numKeys = this.primaryKeyIndicies.size();
+		int numKeys = this.primaryKeyIndicies.size();
 
-			if (numKeys == 1) {
-				int index = ((Integer) this.primaryKeyIndicies.get(0))
+		if (numKeys == 1) {
+			int index = ((Integer) this.primaryKeyIndicies.get(0))
+					.intValue();
+			byte[] currentVal = this.thisRow.getColumnValue(index);
+			this.deleter.setBytes(1, currentVal);
+		} else {
+			for (int i = 0; i < numKeys; i++) {
+				int index = ((Integer) this.primaryKeyIndicies.get(i))
 						.intValue();
-				String currentVal = ((characterEncoding == null) ? new String(
-						(byte[]) this.thisRow.getColumnValue(index)) : new String(
-						(byte[]) this.thisRow.getColumnValue(index), characterEncoding));
-				this.deleter.setString(1, currentVal);
-			} else {
-				for (int i = 0; i < numKeys; i++) {
-					int index = ((Integer) this.primaryKeyIndicies.get(i))
-							.intValue();
-					String currentVal = ((characterEncoding == null) ? new String(
-							(byte[]) this.thisRow.getColumnValue(index))
-							: new String((byte[]) this.thisRow.getColumnValue(index),
-									characterEncoding));
-					this.deleter.setString(i + 1, currentVal);
-				}
+				byte[] currentVal = this.thisRow.getColumnValue(index);
+						
+				this.deleter.setBytes(i + 1, currentVal);
 			}
-
-			this.deleter.executeUpdate();
-			this.rowData.removeRow(this.rowData.getCurrentRowNumber());
-		} catch (java.io.UnsupportedEncodingException encodingEx) {
-			throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.39", //$NON-NLS-1$
-					new Object[] { this.charEncoding }) //$NON-NLS-1$
-					, SQLError.SQL_STATE_ILLEGAL_ARGUMENT); //$NON-NLS-1$ //$NON-NLS-2$
 		}
+
+		this.deleter.executeUpdate();
+		this.rowData.removeRow(this.rowData.getCurrentRowNumber());
+		
+		// position on previous row - Bug#27431
+		previous();
+		
 	}
 
 	private synchronized void extractDefaultValues() throws SQLException {
@@ -846,7 +842,7 @@ public class UpdatableResultSet extends ResultSetImpl {
 		checkClosed();
 
 		if (!this.onInsertRow) {
-			throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.7")); //$NON-NLS-1$
+			throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.7"), getExceptionInterceptor()); //$NON-NLS-1$
 		}
 
 		this.inserter.executeUpdate();
@@ -872,7 +868,7 @@ public class UpdatableResultSet extends ResultSetImpl {
 			}
 		}
 
-		ResultSetRow resultSetRow = new ByteArrayRow(newRow);
+		ResultSetRow resultSetRow = new ByteArrayRow(newRow, getExceptionInterceptor());
 
 		refreshRow(this.inserter, resultSetRow);
 
@@ -1039,7 +1035,7 @@ public class UpdatableResultSet extends ResultSetImpl {
 		this.doingUpdates = false;
 		this.savedCurrentRow = this.thisRow;
 		byte[][] newRowData = new byte[numFields][];
-		this.thisRow = new ByteArrayRow(newRowData);
+		this.thisRow = new ByteArrayRow(newRowData, getExceptionInterceptor());
 
 		for (int i = 0; i < numFields; i++) {
 			if (!this.populateInserterWithDefaultValues) {
@@ -1257,13 +1253,13 @@ public class UpdatableResultSet extends ResultSetImpl {
 		}
 
 		if (this.onInsertRow) {
-			throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.8")); //$NON-NLS-1$
+			throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.8"), getExceptionInterceptor()); //$NON-NLS-1$
 		} else if (this.rowData.size() == 0) {
-			throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.9")); //$NON-NLS-1$
+			throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.9"), getExceptionInterceptor()); //$NON-NLS-1$
 		} else if (isBeforeFirst()) {
-			throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.10")); //$NON-NLS-1$
+			throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.10"), getExceptionInterceptor()); //$NON-NLS-1$
 		} else if (isAfterLast()) {
-			throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.11")); //$NON-NLS-1$
+			throw SQLError.createSQLException(Messages.getString("UpdatableResultSet.11"), getExceptionInterceptor()); //$NON-NLS-1$
 		}
 
 		refreshRow(this.updater, this.thisRow);
@@ -1345,7 +1341,7 @@ public class UpdatableResultSet extends ResultSetImpl {
 			} else {
 				throw SQLError.createSQLException(Messages
 						.getString("UpdatableResultSet.12"), //$NON-NLS-1$
-						SQLError.SQL_STATE_GENERAL_ERROR); //$NON-NLS-1$
+						SQLError.SQL_STATE_GENERAL_ERROR, getExceptionInterceptor()); //$NON-NLS-1$
 			}
 		} finally {
 			if (rs != null) {
@@ -2456,7 +2452,7 @@ public class UpdatableResultSet extends ResultSetImpl {
 					this.thisRow.setColumnValue(columnIndex - 1, StringUtils.getBytes(x,
 							this.charConverter, this.charEncoding,
 							this.connection.getServerCharacterEncoding(),
-							this.connection.parserKnowsUnicode()));
+							this.connection.parserKnowsUnicode(), getExceptionInterceptor()));
 				} else {
 					this.thisRow.setColumnValue(columnIndex - 1, x.getBytes());
 				}
