@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2005 MySQL AB
+ Copyright  2005 MySQL AB, 2008 Sun Microsystems
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License as 
@@ -25,7 +25,9 @@ package com.mysql.jdbc.exceptions.jdbc4;
 
 import java.sql.SQLTransactionRollbackException;
 
-public class MySQLTransactionRollbackException extends SQLTransactionRollbackException {
+import com.mysql.jdbc.exceptions.DeadlockTimeoutRollbackMarker;
+
+public class MySQLTransactionRollbackException extends SQLTransactionRollbackException implements DeadlockTimeoutRollbackMarker {
 
 	public MySQLTransactionRollbackException(String reason, String SQLState,
 			int vendorCode) {
