@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2002-2007 MySQL AB
+ Copyright  2002-2007 MySQL AB, 2008-2009 Sun Microsystems
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License as 
@@ -28,9 +28,11 @@ import java.lang.reflect.Constructor;
 import java.sql.SQLException;
 import java.sql.Savepoint;
 import java.sql.Statement;
+import java.util.Map;
 import java.util.TimeZone;
 
 import com.mysql.jdbc.Connection;
+import com.mysql.jdbc.ExceptionInterceptor;
 import com.mysql.jdbc.Extension;
 import com.mysql.jdbc.MysqlErrorNumbers;
 import com.mysql.jdbc.SQLError;
@@ -62,8 +64,6 @@ import com.mysql.jdbc.log.Log;
 public class ConnectionWrapper extends WrapperBase implements Connection {
 	protected Connection mc = null;
 
-	private MysqlPooledConnection mpc = null;
-
 	private String invalidHandleStr = "Logical handle no longer valid";
 
 	private boolean closed;
@@ -103,7 +103,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 		return (ConnectionWrapper) Util.handleNewInstance(
 				JDBC_4_CONNECTION_WRAPPER_CTOR, new Object[] {
 						mysqlPooledConnection, mysqlConnection,
-						Boolean.valueOf(forXa) });
+						Boolean.valueOf(forXa) }, mysqlPooledConnection.getExceptionInterceptor());
 	}
 
 	/**
@@ -119,10 +119,10 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 	 */
 	public ConnectionWrapper(MysqlPooledConnection mysqlPooledConnection,
 			Connection mysqlConnection, boolean forXa) throws SQLException {
-		this.mpc = mysqlPooledConnection;
+		super(mysqlPooledConnection);
+		
 		this.mc = mysqlConnection;
 		this.closed = false;
-		this.pooledConnection = this.mpc;
 		this.isForXa = forXa;
 
 		if (this.isForXa) {
@@ -143,7 +143,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 			throw SQLError.createSQLException(
 					"Can't set autocommit to 'true' on an XAConnection",
 					SQLError.SQL_STATE_INVALID_TRANSACTION_TERMINATION,
-					MysqlErrorNumbers.ER_XA_RMERR);
+					MysqlErrorNumbers.ER_XA_RMERR, this.exceptionInterceptor);
 		}
 
 		try {
@@ -325,7 +325,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 			throw SQLError.createSQLException(
 					"Can't set autocommit to 'true' on an XAConnection",
 					SQLError.SQL_STATE_INVALID_TRANSACTION_TERMINATION,
-					MysqlErrorNumbers.ER_XA_RMERR);
+					MysqlErrorNumbers.ER_XA_RMERR, this.exceptionInterceptor);
 		}
 
 		try {
@@ -347,7 +347,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 			throw SQLError.createSQLException(
 					"Can't set autocommit to 'true' on an XAConnection",
 					SQLError.SQL_STATE_INVALID_TRANSACTION_TERMINATION,
-					MysqlErrorNumbers.ER_XA_RMERR);
+					MysqlErrorNumbers.ER_XA_RMERR, this.exceptionInterceptor);
 		}
 
 		try {
@@ -492,7 +492,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 					.createSQLException(
 							"Can't call commit() on an XAConnection associated with a global transaction",
 							SQLError.SQL_STATE_INVALID_TRANSACTION_TERMINATION,
-							MysqlErrorNumbers.ER_XA_RMERR);
+							MysqlErrorNumbers.ER_XA_RMERR, this.exceptionInterceptor);
 		}
 
 		try {
@@ -512,7 +512,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 		checkClosed();
 
 		try {
-			return StatementWrapper.getInstance(this, this.mpc, this.mc
+			return StatementWrapper.getInstance(this, this.pooledConnection, this.mc
 					.createStatement());
 		} catch (SQLException sqlException) {
 			checkAndFireConnectionError(sqlException);
@@ -532,7 +532,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 		checkClosed();
 
 		try {
-			return StatementWrapper.getInstance(this, this.mpc, this.mc
+			return StatementWrapper.getInstance(this, this.pooledConnection, this.mc
 					.createStatement(resultSetType, resultSetConcurrency));
 		} catch (SQLException sqlException) {
 			checkAndFireConnectionError(sqlException);
@@ -549,7 +549,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 		checkClosed();
 
 		try {
-			return StatementWrapper.getInstance(this, this.mpc, this.mc
+			return StatementWrapper.getInstance(this, this.pooledConnection, this.mc
 					.createStatement(arg0, arg1, arg2));
 		} catch (SQLException sqlException) {
 			checkAndFireConnectionError(sqlException);
@@ -587,7 +587,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 		checkClosed();
 
 		try {
-			return CallableStatementWrapper.getInstance(this, this.mpc, this.mc
+			return CallableStatementWrapper.getInstance(this, this.pooledConnection, this.mc
 					.prepareCall(sql));
 		} catch (SQLException sqlException) {
 			checkAndFireConnectionError(sqlException);
@@ -607,7 +607,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 		checkClosed();
 
 		try {
-			return CallableStatementWrapper.getInstance(this, this.mpc, this.mc
+			return CallableStatementWrapper.getInstance(this, this.pooledConnection, this.mc
 					.prepareCall(sql, resultSetType, resultSetConcurrency));
 		} catch (SQLException sqlException) {
 			checkAndFireConnectionError(sqlException);
@@ -624,7 +624,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 		checkClosed();
 
 		try {
-			return CallableStatementWrapper.getInstance(this, this.mpc, this.mc
+			return CallableStatementWrapper.getInstance(this, this.pooledConnection, this.mc
 					.prepareCall(arg0, arg1, arg2, arg3));
 		} catch (SQLException sqlException) {
 			checkAndFireConnectionError(sqlException);
@@ -638,7 +638,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 		checkClosed();
 
 		try {
-			return new PreparedStatementWrapper(this, this.mpc, this.mc
+			return new PreparedStatementWrapper(this, this.pooledConnection, this.mc
 					.clientPrepareStatement(sql));
 		} catch (SQLException sqlException) {
 			checkAndFireConnectionError(sqlException);
@@ -652,7 +652,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 		checkClosed();
 
 		try {
-			return new PreparedStatementWrapper(this, this.mpc, this.mc
+			return new PreparedStatementWrapper(this, this.pooledConnection, this.mc
 					.clientPrepareStatement(sql, resultSetType,
 							resultSetConcurrency));
 		} catch (SQLException sqlException) {
@@ -673,7 +673,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 		checkClosed();
 
 		try {
-			return PreparedStatementWrapper.getInstance(this, this.mpc, this.mc
+			return PreparedStatementWrapper.getInstance(this, this.pooledConnection, this.mc
 					.prepareStatement(sql));
 		} catch (SQLException sqlException) {
 			checkAndFireConnectionError(sqlException);
@@ -694,7 +694,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 
 		try {
 			return PreparedStatementWrapper
-					.getInstance(this, this.mpc, this.mc.prepareStatement(sql,
+					.getInstance(this, this.pooledConnection, this.mc.prepareStatement(sql,
 							resultSetType, resultSetConcurrency));
 		} catch (SQLException sqlException) {
 			checkAndFireConnectionError(sqlException);
@@ -711,7 +711,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 		checkClosed();
 
 		try {
-			return PreparedStatementWrapper.getInstance(this, this.mpc, this.mc
+			return PreparedStatementWrapper.getInstance(this, this.pooledConnection, this.mc
 					.prepareStatement(arg0, arg1, arg2, arg3));
 		} catch (SQLException sqlException) {
 			checkAndFireConnectionError(sqlException);
@@ -728,7 +728,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 		checkClosed();
 
 		try {
-			return PreparedStatementWrapper.getInstance(this, this.mpc, this.mc
+			return PreparedStatementWrapper.getInstance(this, this.pooledConnection, this.mc
 					.prepareStatement(arg0, arg1));
 		} catch (SQLException sqlException) {
 			checkAndFireConnectionError(sqlException);
@@ -745,7 +745,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 		checkClosed();
 
 		try {
-			return PreparedStatementWrapper.getInstance(this, this.mpc, this.mc
+			return PreparedStatementWrapper.getInstance(this, this.pooledConnection, this.mc
 					.prepareStatement(arg0, arg1));
 		} catch (SQLException sqlException) {
 			checkAndFireConnectionError(sqlException);
@@ -762,7 +762,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 		checkClosed();
 
 		try {
-			return PreparedStatementWrapper.getInstance(this, this.mpc, this.mc
+			return PreparedStatementWrapper.getInstance(this, this.pooledConnection, this.mc
 					.prepareStatement(arg0, arg1));
 		} catch (SQLException sqlException) {
 			checkAndFireConnectionError(sqlException);
@@ -798,7 +798,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 					.createSQLException(
 							"Can't call rollback() on an XAConnection associated with a global transaction",
 							SQLError.SQL_STATE_INVALID_TRANSACTION_TERMINATION,
-							MysqlErrorNumbers.ER_XA_RMERR);
+							MysqlErrorNumbers.ER_XA_RMERR, this.exceptionInterceptor);
 		}
 
 		try {
@@ -819,7 +819,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 					.createSQLException(
 							"Can't call rollback() on an XAConnection associated with a global transaction",
 							SQLError.SQL_STATE_INVALID_TRANSACTION_TERMINATION,
-							MysqlErrorNumbers.ER_XA_RMERR);
+							MysqlErrorNumbers.ER_XA_RMERR, this.exceptionInterceptor);
 		}
 
 		try {
@@ -840,7 +840,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 	}
 
 	protected void close(boolean fireClosedEvent) throws SQLException {
-		synchronized (this.mpc) {
+		synchronized (this.pooledConnection) {
 			if (this.closed) {
 				return;
 			}
@@ -851,7 +851,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 			}
 
 			if (fireClosedEvent) {
-				this.mpc.callConnectionEventListeners(
+				this.pooledConnection.callConnectionEventListeners(
 						MysqlPooledConnection.CONNECTION_CLOSED_EVENT, null);
 			}
 
@@ -866,7 +866,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 
 	protected void checkClosed() throws SQLException {
 		if (this.closed) {
-			throw SQLError.createSQLException(this.invalidHandleStr);
+			throw SQLError.createSQLException(this.invalidHandleStr, this.exceptionInterceptor);
 		}
 	}
 
@@ -904,7 +904,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 		checkClosed();
 
 		try {
-			return PreparedStatementWrapper.getInstance(this, this.mpc, this.mc
+			return PreparedStatementWrapper.getInstance(this, this.pooledConnection, this.mc
 					.clientPrepareStatement(sql));
 		} catch (SQLException sqlException) {
 			checkAndFireConnectionError(sqlException);
@@ -916,7 +916,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 	public java.sql.PreparedStatement clientPrepareStatement(String sql,
 			int autoGenKeyIndex) throws SQLException {
 		try {
-			return PreparedStatementWrapper.getInstance(this, this.mpc, this.mc
+			return PreparedStatementWrapper.getInstance(this, this.pooledConnection, this.mc
 					.clientPrepareStatement(sql, autoGenKeyIndex));
 		} catch (SQLException sqlException) {
 			checkAndFireConnectionError(sqlException);
@@ -928,7 +928,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 	public java.sql.PreparedStatement clientPrepareStatement(String sql,
 			int resultSetType, int resultSetConcurrency) throws SQLException {
 		try {
-			return PreparedStatementWrapper.getInstance(this, this.mpc, this.mc
+			return PreparedStatementWrapper.getInstance(this, this.pooledConnection, this.mc
 					.clientPrepareStatement(sql, resultSetType,
 							resultSetConcurrency));
 		} catch (SQLException sqlException) {
@@ -942,7 +942,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 			int resultSetType, int resultSetConcurrency,
 			int resultSetHoldability) throws SQLException {
 		try {
-			return PreparedStatementWrapper.getInstance(this, this.mpc, this.mc
+			return PreparedStatementWrapper.getInstance(this, this.pooledConnection, this.mc
 					.clientPrepareStatement(sql, resultSetType,
 							resultSetConcurrency, resultSetHoldability));
 		} catch (SQLException sqlException) {
@@ -955,7 +955,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 	public java.sql.PreparedStatement clientPrepareStatement(String sql,
 			int[] autoGenKeyIndexes) throws SQLException {
 		try {
-			return PreparedStatementWrapper.getInstance(this, this.mpc, this.mc
+			return PreparedStatementWrapper.getInstance(this, this.pooledConnection, this.mc
 					.clientPrepareStatement(sql, autoGenKeyIndexes));
 		} catch (SQLException sqlException) {
 			checkAndFireConnectionError(sqlException);
@@ -967,7 +967,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 	public java.sql.PreparedStatement clientPrepareStatement(String sql,
 			String[] autoGenKeyColNames) throws SQLException {
 		try {
-			return PreparedStatementWrapper.getInstance(this, this.mpc, this.mc
+			return PreparedStatementWrapper.getInstance(this, this.pooledConnection, this.mc
 					.clientPrepareStatement(sql, autoGenKeyColNames));
 		} catch (SQLException sqlException) {
 			checkAndFireConnectionError(sqlException);
@@ -1035,7 +1035,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 		checkClosed();
 
 		try {
-			return PreparedStatementWrapper.getInstance(this, this.mpc, this.mc
+			return PreparedStatementWrapper.getInstance(this, this.pooledConnection, this.mc
 					.serverPrepareStatement(sql));
 		} catch (SQLException sqlException) {
 			checkAndFireConnectionError(sqlException);
@@ -1047,7 +1047,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 	public java.sql.PreparedStatement serverPrepareStatement(String sql,
 			int autoGenKeyIndex) throws SQLException {
 		try {
-			return PreparedStatementWrapper.getInstance(this, this.mpc, this.mc
+			return PreparedStatementWrapper.getInstance(this, this.pooledConnection, this.mc
 					.serverPrepareStatement(sql, autoGenKeyIndex));
 		} catch (SQLException sqlException) {
 			checkAndFireConnectionError(sqlException);
@@ -1059,7 +1059,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 	public java.sql.PreparedStatement serverPrepareStatement(String sql,
 			int resultSetType, int resultSetConcurrency) throws SQLException {
 		try {
-			return PreparedStatementWrapper.getInstance(this, this.mpc, this.mc
+			return PreparedStatementWrapper.getInstance(this, this.pooledConnection, this.mc
 					.serverPrepareStatement(sql, resultSetType,
 							resultSetConcurrency));
 		} catch (SQLException sqlException) {
@@ -1073,7 +1073,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 			int resultSetType, int resultSetConcurrency,
 			int resultSetHoldability) throws SQLException {
 		try {
-			return PreparedStatementWrapper.getInstance(this, this.mpc, this.mc
+			return PreparedStatementWrapper.getInstance(this, this.pooledConnection, this.mc
 					.serverPrepareStatement(sql, resultSetType,
 							resultSetConcurrency, resultSetHoldability));
 		} catch (SQLException sqlException) {
@@ -1086,7 +1086,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 	public java.sql.PreparedStatement serverPrepareStatement(String sql,
 			int[] autoGenKeyIndexes) throws SQLException {
 		try {
-			return PreparedStatementWrapper.getInstance(this, this.mpc, this.mc
+			return PreparedStatementWrapper.getInstance(this, this.pooledConnection, this.mc
 					.serverPrepareStatement(sql, autoGenKeyIndexes));
 		} catch (SQLException sqlException) {
 			checkAndFireConnectionError(sqlException);
@@ -1098,7 +1098,7 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 	public java.sql.PreparedStatement serverPrepareStatement(String sql,
 			String[] autoGenKeyColNames) throws SQLException {
 		try {
-			return PreparedStatementWrapper.getInstance(this, this.mpc, this.mc
+			return PreparedStatementWrapper.getInstance(this, this.pooledConnection, this.mc
 					.serverPrepareStatement(sql, autoGenKeyColNames));
 		} catch (SQLException sqlException) {
 			checkAndFireConnectionError(sqlException);
@@ -2538,4 +2538,85 @@ public class ConnectionWrapper extends WrapperBase implements Connection {
 	public void setSelfDestructOnPingSecondsLifetime(int seconds) {
 		this.mc.setSelfDestructOnPingSecondsLifetime(seconds);
 	}
+
+	public boolean getUseColumnNamesInFindColumn() {
+		return this.mc.getUseColumnNamesInFindColumn();
+	}
+
+	public void setUseColumnNamesInFindColumn(boolean flag) {
+		this.mc.setUseColumnNamesInFindColumn(flag);
+	}
+
+	public boolean getUseLocalTransactionState() {
+		return this.mc.getUseLocalTransactionState();
+	}
+
+	public void setUseLocalTransactionState(boolean flag) {
+		this.mc.setUseLocalTransactionState(flag);
+	}
+	
+	public boolean getCompensateOnDuplicateKeyUpdateCounts() {
+		return this.mc.getCompensateOnDuplicateKeyUpdateCounts();
+	}
+
+	public void setCompensateOnDuplicateKeyUpdateCounts(boolean flag) {
+		this.mc.setCompensateOnDuplicateKeyUpdateCounts(flag);
+	}
+
+	public boolean getUseAffectedRows() {
+		return this.mc.getUseAffectedRows();
+	}
+
+	public void setUseAffectedRows(boolean flag) {
+		this.mc.setUseAffectedRows(flag);
+	}
+
+	public String getPasswordCharacterEncoding() {
+		return this.mc.getPasswordCharacterEncoding();
+	}
+
+	public void setPasswordCharacterEncoding(String characterSet) {
+		this.mc.setPasswordCharacterEncoding(characterSet);
+	}
+
+	public int getAutoIncrementIncrement() {
+		return this.mc.getAutoIncrementIncrement();
+	}
+
+	public int getLoadBalanceBlacklistTimeout() {
+		return this.mc.getLoadBalanceBlacklistTimeout();
+	}
+
+	public void setLoadBalanceBlacklistTimeout(int loadBalanceBlacklistTimeout) {
+		this.mc.setLoadBalanceBlacklistTimeout(loadBalanceBlacklistTimeout);
+	}
+	
+	public void setRetriesAllDown(int retriesAllDown) {
+		this.mc.setRetriesAllDown(retriesAllDown);
+	}
+	
+	public int getRetriesAllDown() {
+		return this.mc.getRetriesAllDown();
+	}
+
+	public ExceptionInterceptor getExceptionInterceptor() {
+		return this.pooledConnection.getExceptionInterceptor();
+	}
+
+	public String getExceptionInterceptors() {
+		return this.mc.getExceptionInterceptors();
+	}
+
+	public void setExceptionInterceptors(String exceptionInterceptors) {
+		this.mc.setExceptionInterceptors(exceptionInterceptors);
+	}
+
+	public boolean getQueryTimeoutKillsConnection() {
+		return this.mc.getQueryTimeoutKillsConnection();
+	}
+
+	public void setQueryTimeoutKillsConnection(
+			boolean queryTimeoutKillsConnection) {
+		this.mc.setQueryTimeoutKillsConnection(queryTimeoutKillsConnection);
+	}
 }
