@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2002-2007 MySQL AB
+ Copyright  2002-2007 MySQL AB, 2008 Sun Microsystems
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License as 
@@ -62,13 +62,28 @@ public class JDBC4PreparedStatementWrapper extends PreparedStatementWrapper {
 		super(c, conn, toWrap);
 	}
 	
-	public void close() throws SQLException {
+	public synchronized void close() throws SQLException {
+		if (this.pooledConnection == null) {
+			// no-op
+			return;
+		}
+		
+		MysqlPooledConnection con = this.pooledConnection; // we need this
+														   // later...
+
 		try {
 			super.close();
 		} finally {
 			try {
-				((JDBC4MysqlPooledConnection)this.pooledConnection).fireStatementEvent(
-						new StatementEvent(this.pooledConnection, this));
+				StatementEvent e = new StatementEvent(con, this);
+				// todo: pull this all up into base classes when we support *only* JDK6 or newer
+				if (con instanceof JDBC4MysqlPooledConnection) {
+					((JDBC4MysqlPooledConnection) con).fireStatementEvent(e);
+				} else if (con instanceof JDBC4MysqlXAConnection) {
+					((JDBC4MysqlXAConnection) con).fireStatementEvent(e);
+				} else if (con instanceof JDBC4SuspendableXAConnection) {
+					((JDBC4SuspendableXAConnection) con).fireStatementEvent(e);
+				}
 			} finally {
 				this.unwrappedInterfaces = null;
 			}
@@ -81,7 +96,7 @@ public class JDBC4PreparedStatementWrapper extends PreparedStatementWrapper {
 				return this.wrappedStmt.isClosed();
 			} else {
 				throw SQLError.createSQLException("Statement already closed",
-						SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+						SQLError.SQL_STATE_ILLEGAL_ARGUMENT, this.exceptionInterceptor);
 			}
 		} catch (SQLException sqlEx) {
 			checkAndFireConnectionError(sqlEx);
@@ -96,7 +111,7 @@ public class JDBC4PreparedStatementWrapper extends PreparedStatementWrapper {
 				this.wrappedStmt.setPoolable(poolable);
 			} else {
 				throw SQLError.createSQLException("Statement already closed",
-						SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+						SQLError.SQL_STATE_ILLEGAL_ARGUMENT, this.exceptionInterceptor);
 			}
 		} catch (SQLException sqlEx) {
 			checkAndFireConnectionError(sqlEx);
@@ -109,7 +124,7 @@ public class JDBC4PreparedStatementWrapper extends PreparedStatementWrapper {
 				return this.wrappedStmt.isPoolable();
 			} else {
 				throw SQLError.createSQLException("Statement already closed",
-						SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+						SQLError.SQL_STATE_ILLEGAL_ARGUMENT, this.exceptionInterceptor);
 			}
 		} catch (SQLException sqlEx) {
 			checkAndFireConnectionError(sqlEx);
@@ -126,7 +141,7 @@ public class JDBC4PreparedStatementWrapper extends PreparedStatementWrapper {
 			} else {
 				throw SQLError.createSQLException(
 						"No operations allowed after statement closed",
-						SQLError.SQL_STATE_GENERAL_ERROR);
+						SQLError.SQL_STATE_GENERAL_ERROR, this.exceptionInterceptor);
 			}
 		} catch (SQLException sqlEx) {
 			checkAndFireConnectionError(sqlEx);
@@ -141,7 +156,7 @@ public class JDBC4PreparedStatementWrapper extends PreparedStatementWrapper {
 			} else {
 				throw SQLError.createSQLException(
 						"No operations allowed after statement closed",
-						SQLError.SQL_STATE_GENERAL_ERROR);
+						SQLError.SQL_STATE_GENERAL_ERROR, this.exceptionInterceptor);
 			}
 		} catch (SQLException sqlEx) {
 			checkAndFireConnectionError(sqlEx);
@@ -157,7 +172,7 @@ public class JDBC4PreparedStatementWrapper extends PreparedStatementWrapper {
 			} else {
 				throw SQLError.createSQLException(
 						"No operations allowed after statement closed",
-						SQLError.SQL_STATE_GENERAL_ERROR);
+						SQLError.SQL_STATE_GENERAL_ERROR, this.exceptionInterceptor);
 			}
 		} catch (SQLException sqlEx) {
 			checkAndFireConnectionError(sqlEx);
@@ -175,7 +190,7 @@ public class JDBC4PreparedStatementWrapper extends PreparedStatementWrapper {
 			} else {
 				throw SQLError.createSQLException(
 						"No operations allowed after statement closed",
-						SQLError.SQL_STATE_GENERAL_ERROR);
+						SQLError.SQL_STATE_GENERAL_ERROR, this.exceptionInterceptor);
 			}
 		} catch (SQLException sqlEx) {
 			checkAndFireConnectionError(sqlEx);
@@ -193,7 +208,7 @@ public class JDBC4PreparedStatementWrapper extends PreparedStatementWrapper {
 			} else {
 				throw SQLError.createSQLException(
 						"No operations allowed after statement closed",
-						SQLError.SQL_STATE_GENERAL_ERROR);
+						SQLError.SQL_STATE_GENERAL_ERROR, this.exceptionInterceptor);
 			}
 		} catch (SQLException sqlEx) {
 			checkAndFireConnectionError(sqlEx);
@@ -211,7 +226,7 @@ public class JDBC4PreparedStatementWrapper extends PreparedStatementWrapper {
 			} else {
 				throw SQLError.createSQLException(
 						"No operations allowed after statement closed",
-						SQLError.SQL_STATE_GENERAL_ERROR);
+						SQLError.SQL_STATE_GENERAL_ERROR, this.exceptionInterceptor);
 			}
 		} catch (SQLException sqlEx) {
 			checkAndFireConnectionError(sqlEx);
@@ -229,7 +244,7 @@ public class JDBC4PreparedStatementWrapper extends PreparedStatementWrapper {
 			} else {
 				throw SQLError.createSQLException(
 						"No operations allowed after statement closed",
-						SQLError.SQL_STATE_GENERAL_ERROR);
+						SQLError.SQL_STATE_GENERAL_ERROR, this.exceptionInterceptor);
 			}
 		} catch (SQLException sqlEx) {
 			checkAndFireConnectionError(sqlEx);
@@ -247,7 +262,7 @@ public class JDBC4PreparedStatementWrapper extends PreparedStatementWrapper {
 			} else {
 				throw SQLError.createSQLException(
 						"No operations allowed after statement closed",
-						SQLError.SQL_STATE_GENERAL_ERROR);
+						SQLError.SQL_STATE_GENERAL_ERROR, this.exceptionInterceptor);
 			}
 		} catch (SQLException sqlEx) {
 			checkAndFireConnectionError(sqlEx);
@@ -265,7 +280,7 @@ public class JDBC4PreparedStatementWrapper extends PreparedStatementWrapper {
 			} else {
 				throw SQLError.createSQLException(
 						"No operations allowed after statement closed",
-						SQLError.SQL_STATE_GENERAL_ERROR);
+						SQLError.SQL_STATE_GENERAL_ERROR, this.exceptionInterceptor);
 			}
 		} catch (SQLException sqlEx) {
 			checkAndFireConnectionError(sqlEx);
@@ -283,7 +298,7 @@ public class JDBC4PreparedStatementWrapper extends PreparedStatementWrapper {
 			} else {
 				throw SQLError.createSQLException(
 						"No operations allowed after statement closed",
-						SQLError.SQL_STATE_GENERAL_ERROR);
+						SQLError.SQL_STATE_GENERAL_ERROR, this.exceptionInterceptor);
 			}
 		} catch (SQLException sqlEx) {
 			checkAndFireConnectionError(sqlEx);
@@ -301,7 +316,7 @@ public class JDBC4PreparedStatementWrapper extends PreparedStatementWrapper {
 			} else {
 				throw SQLError.createSQLException(
 						"No operations allowed after statement closed",
-						SQLError.SQL_STATE_GENERAL_ERROR);
+						SQLError.SQL_STATE_GENERAL_ERROR, this.exceptionInterceptor);
 			}
 		} catch (SQLException sqlEx) {
 			checkAndFireConnectionError(sqlEx);
@@ -318,7 +333,7 @@ public class JDBC4PreparedStatementWrapper extends PreparedStatementWrapper {
 			} else {
 				throw SQLError.createSQLException(
 						"No operations allowed after statement closed",
-						SQLError.SQL_STATE_GENERAL_ERROR);
+						SQLError.SQL_STATE_GENERAL_ERROR, this.exceptionInterceptor);
 			}
 		} catch (SQLException sqlEx) {
 			checkAndFireConnectionError(sqlEx);
@@ -335,7 +350,7 @@ public class JDBC4PreparedStatementWrapper extends PreparedStatementWrapper {
 			} else {
 				throw SQLError.createSQLException(
 						"No operations allowed after statement closed",
-						SQLError.SQL_STATE_GENERAL_ERROR);
+						SQLError.SQL_STATE_GENERAL_ERROR, this.exceptionInterceptor);
 			}
 		} catch (SQLException sqlEx) {
 			checkAndFireConnectionError(sqlEx);
@@ -352,7 +367,7 @@ public class JDBC4PreparedStatementWrapper extends PreparedStatementWrapper {
 			} else {
 				throw SQLError.createSQLException(
 						"No operations allowed after statement closed",
-						SQLError.SQL_STATE_GENERAL_ERROR);
+						SQLError.SQL_STATE_GENERAL_ERROR, this.exceptionInterceptor);
 			}
 		} catch (SQLException sqlEx) {
 			checkAndFireConnectionError(sqlEx);
@@ -370,7 +385,7 @@ public class JDBC4PreparedStatementWrapper extends PreparedStatementWrapper {
 			} else {
 				throw SQLError.createSQLException(
 						"No operations allowed after statement closed",
-						SQLError.SQL_STATE_GENERAL_ERROR);
+						SQLError.SQL_STATE_GENERAL_ERROR, this.exceptionInterceptor);
 			}
 		} catch (SQLException sqlEx) {
 			checkAndFireConnectionError(sqlEx);
@@ -388,7 +403,7 @@ public class JDBC4PreparedStatementWrapper extends PreparedStatementWrapper {
 			} else {
 				throw SQLError.createSQLException(
 						"No operations allowed after statement closed",
-						SQLError.SQL_STATE_GENERAL_ERROR);
+						SQLError.SQL_STATE_GENERAL_ERROR, this.exceptionInterceptor);
 			}
 		} catch (SQLException sqlEx) {
 			checkAndFireConnectionError(sqlEx);
@@ -406,7 +421,7 @@ public class JDBC4PreparedStatementWrapper extends PreparedStatementWrapper {
 			} else {
 				throw SQLError.createSQLException(
 						"No operations allowed after statement closed",
-						SQLError.SQL_STATE_GENERAL_ERROR);
+						SQLError.SQL_STATE_GENERAL_ERROR, this.exceptionInterceptor);
 			}
 		} catch (SQLException sqlEx) {
 			checkAndFireConnectionError(sqlEx);
@@ -423,7 +438,7 @@ public class JDBC4PreparedStatementWrapper extends PreparedStatementWrapper {
 			} else {
 				throw SQLError.createSQLException(
 						"No operations allowed after statement closed",
-						SQLError.SQL_STATE_GENERAL_ERROR);
+						SQLError.SQL_STATE_GENERAL_ERROR, this.exceptionInterceptor);
 			}
 		} catch (SQLException sqlEx) {
 			checkAndFireConnectionError(sqlEx);
@@ -516,7 +531,7 @@ public class JDBC4PreparedStatementWrapper extends PreparedStatementWrapper {
 			return iface.cast(cachedUnwrapped);
 		} catch (ClassCastException cce) {
 			throw SQLError.createSQLException("Unable to unwrap to "
-					+ iface.toString(), SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
+					+ iface.toString(), SQLError.SQL_STATE_ILLEGAL_ARGUMENT, this.exceptionInterceptor);
 		}
 	}
 }
