@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2002-2007 MySQL AB
+ Copyright  2002-2007 MySQL AB, 2008 Sun Microsystems
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License as 
@@ -23,20 +23,21 @@
 
 package com.mysql.jdbc.jdbc2.optional;
 
+import java.lang.reflect.Constructor;
 import java.sql.Connection;
 import java.sql.SQLException;
-
-import java.util.Enumeration;
-import java.util.Hashtable;
+import java.util.HashMap;
+import java.util.Iterator;
+import java.util.Map;
 
 import javax.sql.ConnectionEvent;
 import javax.sql.ConnectionEventListener;
 import javax.sql.PooledConnection;
 
 import com.mysql.jdbc.ConnectionImpl;
-import com.mysql.jdbc.Constants;
+import com.mysql.jdbc.ExceptionInterceptor;
 import com.mysql.jdbc.SQLError;
-import com.mysql.jdbc.exceptions.NotYetImplementedException;
+import com.mysql.jdbc.Util;
 
 /**
  * This class is used to wrap and return a physical connection within a logical
@@ -49,6 +50,37 @@ import com.mysql.jdbc.exceptions.NotYetImplementedException;
  */
 public class MysqlPooledConnection implements PooledConnection {
 
+	private static final Constructor JDBC_4_POOLED_CONNECTION_WRAPPER_CTOR;
+
+	static {
+		if (Util.isJdbc4()) {
+			try {
+				JDBC_4_POOLED_CONNECTION_WRAPPER_CTOR = Class.forName(
+						"com.mysql.jdbc.jdbc2.optional.JDBC4MysqlPooledConnection")
+						.getConstructor(
+								new Class[] { com.mysql.jdbc.Connection.class });
+			} catch (SecurityException e) {
+				throw new RuntimeException(e);
+			} catch (NoSuchMethodException e) {
+				throw new RuntimeException(e);
+			} catch (ClassNotFoundException e) {
+				throw new RuntimeException(e);
+			}
+		} else {
+			JDBC_4_POOLED_CONNECTION_WRAPPER_CTOR = null;
+		}
+	}
+
+	protected static MysqlPooledConnection getInstance(com.mysql.jdbc.Connection connection) throws SQLException {
+		if (!Util.isJdbc4()) {
+			return new MysqlPooledConnection(connection);
+		}
+
+		return (MysqlPooledConnection) Util.handleNewInstance(
+				JDBC_4_POOLED_CONNECTION_WRAPPER_CTOR, new Object[] {
+						connection}, connection.getExceptionInterceptor());
+	}
+	
 	/**
 	 * The flag for an exception being thrown.
 	 */
@@ -61,11 +93,13 @@ public class MysqlPooledConnection implements PooledConnection {
 
 	// ~ Instance/static variables .............................................
 
-	private Hashtable eventListeners;
+	private Map connectionEventListeners;
 
 	private Connection logicalHandle;
 
 	private com.mysql.jdbc.Connection physicalConn;
+	
+	private ExceptionInterceptor exceptionInterceptor;
 
 	// ~ Constructors ..........................................................
 
@@ -78,11 +112,10 @@ public class MysqlPooledConnection implements PooledConnection {
 	public MysqlPooledConnection(com.mysql.jdbc.Connection connection) {
 		this.logicalHandle = null;
 		this.physicalConn = connection;
-		this.eventListeners = new Hashtable(10);
+		this.connectionEventListeners = new HashMap();
+		this.exceptionInterceptor = this.physicalConn.getExceptionInterceptor();
 	}
 
-	// ~ Methods ...............................................................
-
 	/**
 	 * Adds ConnectionEventListeners to a hash table to be used for notification
 	 * of ConnectionEvents
@@ -93,8 +126,8 @@ public class MysqlPooledConnection implements PooledConnection {
 	public synchronized void addConnectionEventListener(
 			ConnectionEventListener connectioneventlistener) {
 
-		if (this.eventListeners != null) {
-			this.eventListeners.put(connectioneventlistener,
+		if (this.connectionEventListeners != null) {
+			this.connectionEventListeners.put(connectioneventlistener,
 					connectioneventlistener);
 		}
 	}
@@ -109,8 +142,8 @@ public class MysqlPooledConnection implements PooledConnection {
 	public synchronized void removeConnectionEventListener(
 			ConnectionEventListener connectioneventlistener) {
 
-		if (this.eventListeners != null) {
-			this.eventListeners.remove(connectioneventlistener);
+		if (this.connectionEventListeners != null) {
+			this.connectionEventListeners.remove(connectioneventlistener);
 		}
 	}
 
@@ -131,8 +164,8 @@ public class MysqlPooledConnection implements PooledConnection {
 		if (this.physicalConn == null) {
 
 			SQLException sqlException = SQLError.createSQLException(
-					"Physical Connection doesn't exist");
-			callListener(CONNECTION_ERROR_EVENT, sqlException);
+					"Physical Connection doesn't exist", this.exceptionInterceptor);
+			callConnectionEventListeners(CONNECTION_ERROR_EVENT, sqlException);
 
 			throw sqlException;
 		}
@@ -148,10 +181,10 @@ public class MysqlPooledConnection implements PooledConnection {
 			}
 
 			this.logicalHandle = ConnectionWrapper.getInstance(this, 
-					(ConnectionImpl)this.physicalConn, 
+					this.physicalConn, 
 					forXa);
 		} catch (SQLException sqlException) {
-			callListener(CONNECTION_ERROR_EVENT, sqlException);
+			callConnectionEventListeners(CONNECTION_ERROR_EVENT, sqlException);
 
 			throw sqlException;
 		}
@@ -169,9 +202,15 @@ public class MysqlPooledConnection implements PooledConnection {
 	public synchronized void close() throws SQLException {
 		if (this.physicalConn != null) {
 			this.physicalConn.close();
+			
+			this.physicalConn = null;
+		}
+		
+		if (this.connectionEventListeners != null) {
+			this.connectionEventListeners.clear();
+			
+			this.connectionEventListeners = null;
 		}
-
-		this.physicalConn = null;
 	}
 
 	/**
@@ -186,63 +225,34 @@ public class MysqlPooledConnection implements PooledConnection {
 	 * @param sqlException
 	 *            the exception being thrown
 	 */
-	protected synchronized void callListener(int eventType,
+	protected synchronized void callConnectionEventListeners(int eventType,
 			SQLException sqlException) {
 
-		if (this.eventListeners == null) {
+		if (this.connectionEventListeners == null) {
 
 			return;
 		}
 
-		Enumeration enumeration = this.eventListeners.keys();
+		Iterator iterator = this.connectionEventListeners.entrySet().iterator();
+		
 		ConnectionEvent connectionevent = new ConnectionEvent(this,
 				sqlException);
 
-		while (enumeration.hasMoreElements()) {
+		while (iterator.hasNext()) {
 
-			ConnectionEventListener connectioneventlistener = (ConnectionEventListener) enumeration
-					.nextElement();
-			ConnectionEventListener connectioneventlistener1 = (ConnectionEventListener) this.eventListeners
-					.get(connectioneventlistener);
+			ConnectionEventListener connectioneventlistener = (ConnectionEventListener) ((Map.Entry)iterator
+					.next()).getValue();
 
 			if (eventType == CONNECTION_CLOSED_EVENT) {
-				connectioneventlistener1.connectionClosed(connectionevent);
+				connectioneventlistener.connectionClosed(connectionevent);
 			} else if (eventType == CONNECTION_ERROR_EVENT) {
-				connectioneventlistener1
+				connectioneventlistener
 						.connectionErrorOccurred(connectionevent);
 			}
 		}
 	}
 	
-//	/**
-//	 * Registers a <code>StatementEventListener</code> with this <code>PooledConnection</code> object.  Components that 
-//	 * wish to be notified when  <code>PreparedStatement</code>s created by the
-//         * connection are closed or are detected to be invalid may use this method 
-//         * to register a <code>StatementEventListener</code> with this <code>PooledConnection</code> object.
-//	 * <p>
-//	 * @param listener	an component which implements the <code>StatementEventListener</code> 
-//	 * 					interface that is to be registered with this <code>PooledConnection</code> object
-//	 * <p>
-//	 * @since 1.6
-//	 */
-//	public void addStatementEventListener(StatementEventListener listener) {
-//		throw new NotYetImplementedException();
-//	}
-//	
-//	/**
-//	 * Removes the specified <code>StatementEventListener</code> from the list of 
-//	 * components that will be notified when the driver detects that a 
-//	 * <code>PreparedStatement</code> has been closed or is invalid.
-//	 * <p> 
-//	 * @param listener	the component which implements the
-//	 * 					<code>StatementEventListener</code> interface that was previously 
-//	 * 					registered with this <code>PooledConnection</code> object
-//	 * <p>
-//	 * @since 1.6
-//	 */
-//	public void removeStatementEventListener(StatementEventListener listener) {
-//		throw new NotYetImplementedException();
-//	}
-
-
+	protected ExceptionInterceptor getExceptionInterceptor() {
+		return this.exceptionInterceptor;
+	}
 }
\ No newline at end of file
