@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2005 MySQL AB
+ Copyright  2005 MySQL AB, 2008 Sun Microsystems
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License as 
@@ -52,10 +52,10 @@ public class MysqlXADataSource extends MysqlDataSource implements
 	/**
 	 * @see javax.sql.XADataSource#getXAConnection(String, String)
 	 */
-	public XAConnection getXAConnection(String user, String password)
+	public XAConnection getXAConnection(String u, String p)
 			throws SQLException {
 
-		Connection conn = getConnection(user, password);
+		Connection conn = getConnection(u, p);
 
 		return wrapConnection(conn);
 	}
@@ -67,9 +67,9 @@ public class MysqlXADataSource extends MysqlDataSource implements
 	private XAConnection wrapConnection(Connection conn) throws SQLException {
 		if (getPinGlobalTxToPhysicalConnection() || 
 				((com.mysql.jdbc.Connection)conn).getPinGlobalTxToPhysicalConnection()) {
-			return new SuspendableXAConnection((com.mysql.jdbc.ConnectionImpl) conn);
+			return SuspendableXAConnection.getInstance((com.mysql.jdbc.ConnectionImpl) conn);
 		}
 		
-		return new MysqlXAConnection((com.mysql.jdbc.ConnectionImpl) conn, getLogXaCommands());
+		return MysqlXAConnection.getInstance((com.mysql.jdbc.ConnectionImpl) conn, getLogXaCommands());
 	}
 }
\ No newline at end of file
