@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2002-2007 MySQL AB
+ Copyright  2002-2007 MySQL AB, 2008 Sun Microsystems
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License as 
@@ -25,9 +25,12 @@
 package testsuite.regression;
 
 import java.io.ByteArrayOutputStream;
+import java.io.IOException;
 import java.io.PrintStream;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
+import java.net.Socket;
+import java.net.SocketException;
 import java.sql.Connection;
 import java.sql.DriverManager;
 import java.sql.DriverPropertyInfo;
@@ -35,22 +38,40 @@ import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.sql.Statement;
+import java.util.Collection;
 import java.util.Enumeration;
 import java.util.HashMap;
 import java.util.Iterator;
+import java.util.LinkedList;
+import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 import java.util.Properties;
 import java.util.StringTokenizer;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
+
+import javax.sql.XAConnection;
+import javax.transaction.xa.XAResource;
+import javax.transaction.xa.Xid;
 
 import testsuite.BaseTestCase;
+import testsuite.UnreliableSocketFactory;
 
 import com.mysql.jdbc.ConnectionImpl;
 import com.mysql.jdbc.Driver;
+import com.mysql.jdbc.Messages;
+import com.mysql.jdbc.MysqlDataTruncation;
+import com.mysql.jdbc.MysqlErrorNumbers;
 import com.mysql.jdbc.NonRegisteringDriver;
 import com.mysql.jdbc.ReplicationConnection;
 import com.mysql.jdbc.ReplicationDriver;
+import com.mysql.jdbc.SQLError;
+import com.mysql.jdbc.StandardSocketFactory;
 import com.mysql.jdbc.integration.jboss.MysqlValidConnectionChecker;
+import com.mysql.jdbc.jdbc2.optional.MysqlXADataSource;
+import com.mysql.jdbc.jdbc2.optional.MysqlXid;
+import com.mysql.jdbc.jdbc2.optional.SuspendableXAConnection;
 import com.mysql.jdbc.log.StandardLogger;
 
 /**
@@ -158,9 +179,7 @@ public class ConnectionRegressionTest extends BaseTestCase {
 		Properties props = new Properties();
 
 		try {
-			this.stmt.executeUpdate("DROP TABLE IF EXISTS testBug3790");
-			this.stmt
-					.executeUpdate("CREATE TABLE testBug3790 (field1 INT NOT NULL PRIMARY KEY, field2 VARCHAR(32)) TYPE=InnoDB");
+			createTable("testBug3790", "(field1 INT NOT NULL PRIMARY KEY, field2 VARCHAR(32)) ", "InnoDB");
 			this.stmt.executeUpdate("INSERT INTO testBug3790 VALUES ("
 					+ field1OldValue + ", '" + field2OldValue + "')");
 
@@ -183,8 +202,6 @@ public class ConnectionRegressionTest extends BaseTestCase {
 			assertTrue(rs2.getInt(1) == field1OldValue);
 			assertTrue(rs2.getString(2).equals(field2NewValue));
 		} finally {
-			this.stmt.executeUpdate("DROP TABLE IF EXISTS testBug3790");
-
 			if (rs2 != null) {
 				rs2.close();
 			}
@@ -561,65 +578,29 @@ public class ConnectionRegressionTest extends BaseTestCase {
 	public void testBug6966() throws Exception {
 		Properties props = new Driver().parseURL(BaseTestCase.dbUrl, null);
 		props.setProperty("autoReconnect", "true");
+		props.setProperty("socketFactory", "testsuite.UnreliableSocketFactory");
 
-		// Re-build the connection information
-		int firstIndexOfHost = BaseTestCase.dbUrl.indexOf("//") + 2;
-		int lastIndexOfHost = BaseTestCase.dbUrl.indexOf("/", firstIndexOfHost);
-
-		String hostPortPair = BaseTestCase.dbUrl.substring(firstIndexOfHost,
-				lastIndexOfHost);
-
-		StringTokenizer st = new StringTokenizer(hostPortPair, ":");
-
-		String host = null;
-		String port = null;
-
-		if (st.hasMoreTokens()) {
-			String possibleHostOrPort = st.nextToken();
-
-			if (Character.isDigit(possibleHostOrPort.charAt(0)) && 
-					(possibleHostOrPort.indexOf(".") == -1 /* IPV4 */)  &&
-					(possibleHostOrPort.indexOf("::") == -1 /* IPV6 */)) {
-				port = possibleHostOrPort;
-				host = "localhost";
-			} else {
-				host = possibleHostOrPort;
-			}
-		}
-
-		if (st.hasMoreTokens()) {
-			port = st.nextToken();
-		}
-
-		if (host == null) {
-			host = "";
-		}
-
-		if (port == null) {
-			port = "3306";
-		}
-
-		StringBuffer newHostBuf = new StringBuffer();
-		newHostBuf.append(host);
-		newHostBuf.append(":65532"); // make sure the master fails
-		newHostBuf.append(",");
-		newHostBuf.append(host);
-		if (port != null) {
-			newHostBuf.append(":");
-			newHostBuf.append(port);
-		}
-
-		props.remove("PORT");
-
-		props.setProperty("HOST", newHostBuf.toString());
+		Properties urlProps = new NonRegisteringDriver().parseURL(this.dbUrl, null);
+		
+		String host = urlProps.getProperty(Driver.HOST_PROPERTY_KEY);
+		String port = urlProps.getProperty(Driver.PORT_PROPERTY_KEY);
+		
+		props.remove(Driver.HOST_PROPERTY_KEY);
+		props.remove(Driver.NUM_HOSTS_PROPERTY_KEY);
+		props.remove(Driver.HOST_PROPERTY_KEY + ".1");
+		props.remove(Driver.PORT_PROPERTY_KEY + ".1");
+		
 		props.setProperty("queriesBeforeRetryMaster", "50");
 		props.setProperty("maxReconnects", "1");
 
+		UnreliableSocketFactory.mapHost("master", host);
+		UnreliableSocketFactory.mapHost("slave", host);
+		UnreliableSocketFactory.downHost("master");
+		
 		Connection failoverConnection = null;
 
 		try {
-			failoverConnection = getConnectionWithProps("jdbc:mysql://"
-					+ newHostBuf.toString() + "/", props);
+			failoverConnection = getConnectionWithProps("jdbc:mysql://master:" + port + ",slave:" + port + "/", props);
 			failoverConnection.setAutoCommit(false);
 
 			String originalConnectionId = getSingleIndexedValueWithQuery(
@@ -630,6 +611,7 @@ public class ConnectionRegressionTest extends BaseTestCase {
 			}
 
 			((com.mysql.jdbc.Connection)failoverConnection).clearHasTriedMaster();
+			UnreliableSocketFactory.dontDownHost("master");
 			
 			failoverConnection.setAutoCommit(true);
 
@@ -642,6 +624,8 @@ public class ConnectionRegressionTest extends BaseTestCase {
 
 			failoverConnection.createStatement().executeQuery("SELECT 1");
 		} finally {
+			UnreliableSocketFactory.flushAllHostLists();
+			
 			if (failoverConnection != null) {
 				failoverConnection.close();
 			}
@@ -993,6 +977,8 @@ public class ConnectionRegressionTest extends BaseTestCase {
 	 * 
 	 * @throws Exception
 	 */
+	
+	/* FIXME: This test is no longer valid with random selection of hosts 
 	public void testBug8643() throws Exception {
 		if (runMultiHostTests()) {
 			Properties defaultProps = getMasterSlaveProps();
@@ -1083,6 +1069,8 @@ public class ConnectionRegressionTest extends BaseTestCase {
 			}
 		}
 	}
+	
+	*/
 
 	/**
 	 * Tests fix for BUG#9206, can not use 'UTF-8' for characterSetResults
@@ -1219,6 +1207,10 @@ public class ConnectionRegressionTest extends BaseTestCase {
 			return; // test not valid on JDK-1.3.1
 		}
 
+		if (!versionMeetsMinimum(6, 0)) {
+			return; // server status is broken until MySQL-6.0
+		}
+		
 		Properties props = new Properties();
 		props.setProperty("useConfigs", "maxPerformance");
 
@@ -1606,7 +1598,7 @@ public class ConnectionRegressionTest extends BaseTestCase {
 		}
 	}
 
-	private Connection getMasterSlaveReplicationConnection()
+	protected Connection getMasterSlaveReplicationConnection()
 			throws SQLException {
 
 		Connection replConn = new ReplicationDriver().connect(
@@ -1829,7 +1821,7 @@ public class ConnectionRegressionTest extends BaseTestCase {
 	 * @throws Exception if the test fails.
 	 */
 	public void testBug24706() throws Exception {
-		if (!versionMeetsMinimum(5, 0)) {
+		if (!versionMeetsMinimum(6, 0)) {
 			return; // server status isn't there to support this feature
 		}
 		
@@ -2393,4 +2385,390 @@ public class ConnectionRegressionTest extends BaseTestCase {
 			replConn.setReadOnly(readOnly);
 		}	
 	}
-}
\ No newline at end of file
+	
+	public void testBug35660() throws Exception {
+		
+		Connection lbConn = getLoadBalancedConnection(null);
+		Connection lbConn2 = getLoadBalancedConnection(null);
+		
+		try {
+			assertEquals(this.conn, this.conn);
+			assertEquals(lbConn, lbConn);
+			assertFalse(lbConn.equals(this.conn));
+			assertFalse(lbConn.equals(lbConn2));
+		} finally {
+			lbConn.close();
+			lbConn2.close();
+		}
+	}
+	
+	public void testBug37570() throws Exception {
+		Properties props = new Properties();
+		props.setProperty("characterEncoding", "utf-8");
+		props.setProperty("passwordCharacterEncoding", "utf-8");
+		
+		Connection adminConn = getAdminConnectionWithProps(props);
+		
+		if (adminConn != null) {
+			try {
+				String unicodePassword = "\u0430\u0431\u0432"; // Cyrillic string
+				String user = "bug37570";
+				Statement adminStmt = adminConn.createStatement();
+
+				adminStmt.executeUpdate("grant usage on *.* to '" + user + "'@'127.0.0.1' identified by 'foo'");
+				adminStmt.executeUpdate("update mysql.user set password=PASSWORD('"+ unicodePassword +"') where user = '" + user + "'");
+				adminStmt.executeUpdate("flush privileges");
+				
+				try {
+					((ConnectionImpl)adminConn).changeUser(user, unicodePassword);
+				} catch (SQLException sqle) {
+					assertTrue("Connection with non-latin1 password failed", false);
+				}
+			} finally {
+		    	closeMemberJDBCResources();
+			}
+		}
+	}
+	public void testUnreliableSocketFactory() throws Exception {
+		Properties props = new Properties();
+		props.setProperty("loadBalanceStrategy", "bestResponseTime");
+		Connection conn2 = this.getUnreliableLoadBalancedConnection(new String[]{"first", "second"}, props);
+		assertNotNull("Connection should not be null", conn);
+		try {
+			conn2.createStatement().execute("SELECT 1");
+			conn2.createStatement().execute("SELECT 1");
+			// both connections are live now
+			UnreliableSocketFactory.downHost("first");
+			UnreliableSocketFactory.downHost("second");
+			try{
+				conn2.createStatement().execute("SELECT 1");
+				fail("Should hang here.");
+			} catch (SQLException sqlEx){
+				assertEquals("08S01", sqlEx.getSQLState());
+			}
+		} finally {
+	    	closeMemberJDBCResources();
+		}
+	}
+
+	private void copyBasePropertiesIntoProps(Properties props, NonRegisteringDriver d)
+			throws SQLException {
+		Properties testCaseProps = d.parseURL(BaseTestCase.dbUrl, null);
+		String user = testCaseProps.getProperty(NonRegisteringDriver.USER_PROPERTY_KEY);
+		
+		if (user != null) {
+			props.setProperty(NonRegisteringDriver.USER_PROPERTY_KEY, user);
+		}
+		
+		String password =  testCaseProps.getProperty(NonRegisteringDriver.PASSWORD_PROPERTY_KEY);
+		
+		if (password != null) {
+			props.setProperty(NonRegisteringDriver.PASSWORD_PROPERTY_KEY, password);
+		}
+		
+		String port = testCaseProps.getProperty(NonRegisteringDriver.PORT_PROPERTY_KEY);
+		
+		if (port != null) {
+			props.setProperty(NonRegisteringDriver.PORT_PROPERTY_KEY, port);
+		} else {
+			String host = testCaseProps.getProperty(NonRegisteringDriver.HOST_PROPERTY_KEY);
+			
+			if (host != null) {
+				String[] hostPort = host.split(":");
+				
+				if (hostPort.length > 1) {
+					props.setProperty(NonRegisteringDriver.PORT_PROPERTY_KEY, hostPort[1]);
+				}
+			}
+		}
+	}
+
+	private String getPortFreeHostname(Properties props, NonRegisteringDriver d)
+			throws SQLException {
+		String host = d.parseURL(BaseTestCase.dbUrl, props).getProperty(NonRegisteringDriver.HOST_PROPERTY_KEY);
+		
+		if(host == null){
+			host = "localhost";
+		}
+		
+		host = host.split(":")[0];
+		return host;
+	}	
+	
+	private Connection getUnreliableLoadBalancedConnection(String[] hostNames, Properties props) throws Exception{
+		if(props == null){
+			props = new Properties();
+		}
+		NonRegisteringDriver d = new NonRegisteringDriver();
+		this.copyBasePropertiesIntoProps(props, d);
+		props.setProperty("socketFactory", "testsuite.UnreliableSocketFactory");
+		String db = d.parseURL(BaseTestCase.dbUrl, props).getProperty(NonRegisteringDriver.DBNAME_PROPERTY_KEY);
+		
+		String host = getPortFreeHostname(props, d);
+		UnreliableSocketFactory.flushAllHostLists();
+		StringBuffer hostString = new StringBuffer();
+		String glue = "";
+		for(int i = 0; i < hostNames.length; i++){
+			UnreliableSocketFactory.mapHost(hostNames[i], host);
+			hostString.append(glue);
+			glue = ",";
+			hostString.append(hostNames[i]);
+		}
+		
+		UnreliableSocketFactory.mapHost("second", host);
+		props.remove(NonRegisteringDriver.HOST_PROPERTY_KEY);
+			
+		return getConnectionWithProps("jdbc:mysql:loadbalance://" + hostString.toString() +"/" + db, props);
+		
+	}
+	
+	public void testBug43421() throws Exception {
+		
+		Properties props = new Properties();
+		props.setProperty("loadBalanceStrategy", "bestResponseTime");
+		
+		Connection conn2 = this.getUnreliableLoadBalancedConnection(new String[]{"first", "second"}, props);
+			
+		assertNotNull("Connection should not be null", conn2);
+		
+		try {
+			conn2.createStatement().execute("SELECT 1");
+			conn2.createStatement().execute("SELECT 1");
+			// both connections are live now
+			UnreliableSocketFactory.downHost("second");
+			UnreliableSocketFactory.downHost("first");
+			try{
+				conn2.createStatement().execute("/* ping */");
+				fail("Pings will not succeed when one host is down and using loadbalance w/o global blacklist.");
+			} catch (SQLException sqlEx){
+			}
+		} finally {
+	    	closeMemberJDBCResources();
+		}
+	
+		UnreliableSocketFactory.flushAllHostLists();
+		props = new Properties();
+		props.setProperty("globalBlacklistTimeout", "200");
+		props.setProperty("loadBalanceStrategy", "bestResponseTime");
+		
+		conn2 = this.getUnreliableLoadBalancedConnection(new String[]{"first", "second"}, props);
+		
+		assertNotNull("Connection should not be null", conn);
+		
+		try {
+			conn2.createStatement().execute("SELECT 1");
+			conn2.createStatement().execute("SELECT 1");
+			// both connections are live now
+			UnreliableSocketFactory.downHost("second");
+			try{
+				conn2.createStatement().execute("/* ping */");
+			} catch (SQLException sqlEx){
+				fail("Pings should succeed even though host is down.");
+			}
+		} finally {
+	    	closeMemberJDBCResources();
+		}
+
+	}
+	
+	public void testBug45171() throws Exception {
+		List statementsToTest = new LinkedList();
+		statementsToTest.add(this.conn.createStatement());
+		statementsToTest.add(((com.mysql.jdbc.Connection)this.conn).clientPrepareStatement("SELECT 1"));
+		statementsToTest.add(((com.mysql.jdbc.Connection)this.conn).clientPrepareStatement("SELECT 1", Statement.RETURN_GENERATED_KEYS));
+		statementsToTest.add(((com.mysql.jdbc.Connection)this.conn).clientPrepareStatement("SELECT 1", new int[0]));
+		statementsToTest.add(((com.mysql.jdbc.Connection)this.conn).clientPrepareStatement("SELECT 1", new String[0]));
+		statementsToTest.add(((com.mysql.jdbc.Connection)this.conn).serverPrepareStatement("SELECT 1"));
+		statementsToTest.add(((com.mysql.jdbc.Connection)this.conn).serverPrepareStatement("SELECT 1", Statement.RETURN_GENERATED_KEYS));
+		statementsToTest.add(((com.mysql.jdbc.Connection)this.conn).serverPrepareStatement("SELECT 1", new int[0]));
+		statementsToTest.add(((com.mysql.jdbc.Connection)this.conn).serverPrepareStatement("SELECT 1", new String[0]));
+		
+		Iterator iter = statementsToTest.iterator();
+		
+		while (iter.hasNext()) {
+			Statement toTest = (Statement) iter.next();
+			assertEquals(toTest.getResultSetType(), ResultSet.TYPE_FORWARD_ONLY);
+			assertEquals(toTest.getResultSetConcurrency(), ResultSet.CONCUR_READ_ONLY);
+		}
+		
+	}
+	
+	/**
+	 * Tests fix for BUG#44587, provide last packet sent/received
+	 * timing in all connection failure errors.
+	 */
+	public void testBug44587() throws Exception {
+		Exception e = null;
+		String msg = SQLError.createLinkFailureMessageBasedOnHeuristics(
+				(ConnectionImpl) this.conn, 
+				System.currentTimeMillis() - 1000,
+				System.currentTimeMillis() - 2000,
+				e, 
+				false);
+		assertTrue(containsMessage(msg,"CommunicationsException.ServerPacketTimingInfo"));
+	}
+	
+	/**
+	 * Tests fix for BUG#45419, ensure that time is not converted to seconds
+	 * before being reported as milliseconds.
+	 */
+	public void testBug45419() throws Exception {
+		Exception e = null;
+		String msg = SQLError.createLinkFailureMessageBasedOnHeuristics(
+				(ConnectionImpl) this.conn, 
+				System.currentTimeMillis() - 1000,
+				System.currentTimeMillis() - 2000,
+				e, 
+				false);
+		Matcher m = Pattern.compile("([\\d\\,]+)").matcher(msg);
+		assertTrue(m.find());
+		assertTrue(Long.parseLong(m.group(0).replaceAll(",", "")) >= 2000);
+		assertTrue(Long.parseLong(m.group(1).replaceAll(",", "")) >= 1000);
+	}
+	
+	public static boolean containsMessage(String msg, String key) {
+		String [] expectedFragments = Messages.getString(key).split("\\{\\d\\}");
+		for(int i = 0; i < expectedFragments.length; i++) {
+			if(msg.indexOf(expectedFragments[i]) < 0) {
+				return false;
+			}
+		}
+		return true;
+	}
+	
+	public void testBug46637() throws Exception {
+		NonRegisteringDriver driver = new NonRegisteringDriver();
+		Properties props = new Properties();
+		copyBasePropertiesIntoProps(props, driver);
+		String hostname = getPortFreeHostname(props, driver);
+		UnreliableSocketFactory.flushAllHostLists();
+		UnreliableSocketFactory.downHost(hostname);
+		
+		try {
+			Connection noConn = getConnectionWithProps("socketFactory=testsuite.UnreliableSocketFactory");
+		} catch (SQLException sqlEx) {
+			assertTrue(sqlEx.getMessage().indexOf("has not received") != -1);
+		} finally {
+			UnreliableSocketFactory.flushAllHostLists();
+		}
+	}
+	
+	public void testBug32216() throws Exception {
+		checkBug32216("www.mysql.com", "12345", "my_database");
+		checkBug32216("www.mysql.com", null, "my_database");
+	}
+	
+	private void checkBug32216(String host, String port, String dbname)
+        throws SQLException
+    {
+		NonRegisteringDriver driver = new NonRegisteringDriver();
+		
+        StringBuffer url = new StringBuffer("jdbc:mysql://");
+        url.append(host);
+
+        if (port != null) {
+            url.append(':');
+            url.append(port);
+        }
+
+        url.append('/');
+        url.append(dbname);
+
+        Properties result = driver.parseURL(url.toString(), new Properties());
+
+        assertEquals("hostname not equal", host, result
+                .getProperty(Driver.HOST_PROPERTY_KEY));
+        if (port != null) {
+        	assertEquals("port not equal", port, result
+                .getProperty(Driver.PORT_PROPERTY_KEY));
+        } else {
+        	assertEquals("port default incorrect", "3306", result.getProperty(Driver.PORT_PROPERTY_KEY));	
+        }
+        
+        assertEquals("dbname not equal", dbname, result
+                .getProperty(Driver.DBNAME_PROPERTY_KEY));
+    }
+	
+	public void testBug44324() throws Exception {
+		createTable(
+				"bug44324",
+				"(Id INT NOT NULL AUTO_INCREMENT PRIMARY KEY, SomeVChar VARCHAR(10)) ENGINE=MyISAM;");
+
+		try {
+			this.stmt
+					.executeUpdate("INSERT INTO bug44324 values (null, 'Some text much longer than 10 characters')");
+		} catch (MysqlDataTruncation sqlEx) {
+			assertTrue(0 != sqlEx.getErrorCode());
+		}
+
+	}
+	
+	public void testBug46925() throws Exception {
+		MysqlXADataSource xads1 = new MysqlXADataSource();
+		MysqlXADataSource xads2 = new MysqlXADataSource();
+
+		Xid txid = new MysqlXid(new byte[] {0x1}, new byte[] {0xf}, 3306);
+		
+		xads1.setPinGlobalTxToPhysicalConnection(true);
+		xads1.setUrl(dbUrl);
+		
+		xads2.setPinGlobalTxToPhysicalConnection(true);
+		xads2.setUrl(dbUrl);
+		
+		XAConnection c1 = xads1.getXAConnection();
+		assertTrue(c1 instanceof SuspendableXAConnection);
+		// start a transaction on one connection
+		c1.getXAResource().start(txid, XAResource.TMNOFLAGS);
+		c1.getXAResource().end(txid, XAResource.TMSUCCESS);
+		
+		XAConnection c2 = xads2.getXAConnection();
+		assertTrue(c2 instanceof SuspendableXAConnection);
+		// prepare on another one. Since we are using a "pinned" connection
+		// we should have the same "currentXAConnection" for both SuspendableXAConnection 
+		c2.getXAResource().prepare(txid); // this will fail without the fix.
+		c2.getXAResource().commit(txid,false);
+	}
+	
+	public void testBug47494() throws Exception {
+		try {
+			getConnectionWithProps("jdbc:mysql://localhost:9999/test?socketFactory=testsuite.regression.ConnectionRegressionTest$PortNumberSocketFactory");
+		} catch (SQLException sqlEx) {
+			assertTrue(sqlEx.getCause() instanceof IOException);
+		}
+		
+		
+		try {
+			getConnectionWithProps("jdbc:mysql://:9999/test?socketFactory=testsuite.regression.ConnectionRegressionTest$PortNumberSocketFactory");
+		} catch (SQLException sqlEx) {
+			assertTrue(sqlEx.getCause() instanceof IOException);
+		}
+		
+		try {
+			getConnectionWithProps("jdbc:mysql://:9999,:9999/test?socketFactory=testsuite.regression.ConnectionRegressionTest$PortNumberSocketFactory");
+		} catch (SQLException sqlEx) {
+			assertTrue(sqlEx.getCause() instanceof IOException);
+		}
+		
+		try {
+			getConnectionWithProps("jdbc:mysql://localhost:9999,localhost:9999/test?socketFactory=testsuite.regression.ConnectionRegressionTest$PortNumberSocketFactory");
+		} catch (SQLException sqlEx) {
+			assertTrue(sqlEx.getCause() instanceof IOException);
+		}
+	}
+	
+	public static class PortNumberSocketFactory extends StandardSocketFactory {
+		
+		public PortNumberSocketFactory() {
+			
+		}
+		
+		public Socket connect(String hostname, int portNumber, Properties props)
+				throws SocketException, IOException {
+			assertEquals(9999, portNumber);
+			
+			throw new IOException();
+		}
+		
+	}
+
+}
