@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2002-2007 MySQL AB
+ Copyright  2002-2007 MySQL AB, 2008 Sun Microsystems
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License as 
@@ -24,6 +24,8 @@
  */
 package testsuite.regression;
 
+import java.lang.reflect.Field;
+import java.lang.reflect.Modifier;
 import java.sql.Connection;
 import java.sql.DatabaseMetaData;
 import java.sql.DriverPropertyInfo;
@@ -34,8 +36,11 @@ import java.sql.SQLException;
 import java.sql.Statement;
 import java.sql.Types;
 import java.util.HashMap;
+import java.util.Map;
 import java.util.Properties;
 
+import junit.framework.ComparisonFailure;
+
 import testsuite.BaseTestCase;
 
 import com.mysql.jdbc.Driver;
@@ -1200,7 +1205,7 @@ public class MetaDataRegressionTest extends BaseTestCase {
 		
 		createTable(
 				"`app tab`",
-				"( C1 int(11) NULL, INDEX NEWINX (C1), INDEX NEWINX2 (C1)) ENGINE = InnoDB CHECKSUM = 0 COMMENT = 'InnoDB free: 3072 kB; (`C1`) REFER`test/app tab`(`C1`)' PACK_KEYS = 0");
+				"( C1 int(11) NULL, INDEX NEWINX (C1), INDEX NEWINX2 (C1))", "InnoDB");
 
 		this.stmt
 				.executeUpdate("ALTER TABLE `app tab` ADD CONSTRAINT APPFK FOREIGN KEY (C1) REFERENCES `app tab` (C1)");
@@ -1602,7 +1607,7 @@ public class MetaDataRegressionTest extends BaseTestCase {
 		
 		createTable("testBug21544",
 	            "(foo_id INT NOT NULL, stuff LONGTEXT"
-	            + ", PRIMARY KEY (foo_id)) TYPE=INNODB");
+	            + ", PRIMARY KEY (foo_id))", "INNODB");
 		
 		Connection infoSchemConn = null;
 		
@@ -1637,7 +1642,7 @@ public class MetaDataRegressionTest extends BaseTestCase {
 	 */
 	public void testBug22613() throws Exception {
 		
-		createTable("bug22613", "( s set('a','bc','def','ghij') default NULL, t enum('a', 'ab', 'cdef'))");
+		createTable("bug22613", "( s set('a','bc','def','ghij') default NULL, t enum('a', 'ab', 'cdef'), s2 SET('1','2','3','4','1585','ONE','TWO','Y','N','THREE'))");
 
 		try {
 			checkMetadataForBug22613(this.conn);
@@ -1665,14 +1670,20 @@ public class MetaDataRegressionTest extends BaseTestCase {
 	
 	private void checkMetadataForBug22613(Connection c) throws Exception {
 		String maxValue = "a,bc,def,ghij";
+		String maxValue2 = "1,2,3,4,1585,ONE,TWO,Y,N,THREE";
 		
 		try {
 			DatabaseMetaData meta = c.getMetaData();
 			this.rs = meta.getColumns(null, this.conn.getCatalog(), "bug22613", "s");
 			this.rs.first();
-
+			
 			assertEquals(maxValue.length(), rs.getInt("COLUMN_SIZE"));
 			
+			this.rs = meta.getColumns(null, this.conn.getCatalog(), "bug22613", "s2");
+			this.rs.first();
+			
+			assertEquals(maxValue2.length(), rs.getInt("COLUMN_SIZE"));
+			
 			this.rs = meta.getColumns(null, c.getCatalog(), "bug22613", "t");
 			this.rs.first();
 
@@ -1693,15 +1704,19 @@ public class MetaDataRegressionTest extends BaseTestCase {
 				new Properties());
 		
 		boolean foundHost = false;
+		boolean foundPort = false;
 		
 		for (int i = 0; i < dpi.length; i++) {
-			if ("bogus:9999".equals(dpi[i].value)) {
+			if ("bogus".equals(dpi[i].value)) {
 				foundHost = true;
-				break;
+			}
+			
+			if ("9999".equals(dpi[i].value)) {
+				foundPort = true;
 			}
 		}
 		
-		assertTrue(foundHost);
+		assertTrue(foundHost && foundPort);
 	}
 	
 	private void testAbsenceOfMetadataForQuery(String query) throws Exception {
@@ -2073,8 +2088,8 @@ public class MetaDataRegressionTest extends BaseTestCase {
 	
 	public void testBug20491() throws Exception {
 		try {
-			String[] fields = { "field1_ae_", "field2_ue_", "field3_oe_",
-			"field4_sz_" };
+			String[] fields = { "field1_ae_\u00e4", "field2_ue_\u00fc", "field3_oe_\u00f6",
+			"field4_sz_\u00df" };
 			
 			createTable("tst",
 					"(`" + fields[0] + "` int(10) unsigned NOT NULL default '0',"
@@ -2086,7 +2101,18 @@ public class MetaDataRegressionTest extends BaseTestCase {
 			// demonstrate that these are all in the Cp1252 encoding
 			
 			for (int i = 0; i < fields.length; i++) {
-				assertEquals(fields[i], new String(fields[i].getBytes("Cp1252"), "Cp1252"));
+				try {
+					assertEquals(fields[i], new String(fields[i].getBytes("Cp1252"), "Cp1252"));
+				} catch (ComparisonFailure cfEx) {
+					if (i == 3) {
+						// If we're on a mac, we're out of luck
+						// we can't store this in the filesystem...
+						
+						if (!System.getProperty("os.name").startsWith("Mac")) {
+							throw cfEx;
+						}
+					}
+				}
 			}
 			
 			byte[] asBytes = fields[0].getBytes("utf-8");
@@ -2098,8 +2124,19 @@ public class MetaDataRegressionTest extends BaseTestCase {
 			int j = 0;
 			
 			while (this.rs.next()) {
-				assertEquals("Wrong column name:" + this.rs.getString(4),
+				try {
+					assertEquals("Wrong column name:" + this.rs.getString(4),
 						fields[j++], this.rs.getString(4));
+				} catch (ComparisonFailure cfEx) {
+					if (j == 3) {
+						// If we're on a mac, we're out of luck
+						// we can't store this in the filesystem...
+						
+						if (!System.getProperty("os.name").startsWith("Mac")) {
+							throw cfEx;
+						}
+					}
+				}
 			}
 			
 			this.rs.close();
@@ -2109,8 +2146,19 @@ public class MetaDataRegressionTest extends BaseTestCase {
 			ResultSetMetaData rsmd = this.rs.getMetaData();
 			
 			for (int i = 1; i <= rsmd.getColumnCount(); i++) {
-				assertEquals("Wrong column name:" + rsmd.getColumnName(i),
+				try {
+					assertEquals("Wrong column name:" + rsmd.getColumnName(i),
 						fields[i - 1], rsmd.getColumnName(i));
+				} catch (ComparisonFailure cfEx) {
+					if (i - 1 == 3) {
+						// If we're on a mac, we're out of luck
+						// we can't store this in the filesystem...
+						
+						if (!System.getProperty("os.name").startsWith("Mac")) {
+							throw cfEx;
+						}
+					}
+				}
 			}
 		} finally {
 			closeMemberJDBCResources();
@@ -2208,4 +2256,311 @@ public class MetaDataRegressionTest extends BaseTestCase {
 			closeMemberJDBCResources();
 		}
 	}
+	
+	public void testNoSystemTablesReturned() throws Exception {
+		if (!versionMeetsMinimum(5, 0)) {
+			return; // no information schema
+		}
+		
+		try {
+			this.rs = this.conn.getMetaData().getTables("information_schema", "null", "%", new String[] {"SYSTEM TABLE"});
+			assertTrue(this.rs.next());
+			this.rs = this.conn.getMetaData().getTables("information_schema", "null", "%", new String[] {"TABLE"});
+			assertFalse(this.rs.next());
+			this.rs = this.conn.getMetaData().getTables("information_schema", "null", "%", new String[] {"TABLE", "SYSTEM TABLE"});
+			assertTrue(this.rs.next());
+			this.rs = this.conn.getMetaData().getColumns("information_schema", null, "TABLES", "%");
+			assertTrue(this.rs.next());
+		} finally {
+			closeMemberJDBCResources();
+		}
+	}
+	
+	public void testABunchOfReturnTypes() throws Exception {
+		checkABunchOfReturnTypesForConnection(this.conn);
+		
+		if (versionMeetsMinimum(5, 0)) {
+			checkABunchOfReturnTypesForConnection(getConnectionWithProps("useInformationSchema=true"));
+		}
+	}
+	
+	private void checkABunchOfReturnTypesForConnection(Connection mdConn) throws Exception {
+		
+		DatabaseMetaData md = mdConn.getMetaData();
+		
+		// Bug#44862 - getBestRowIdentifier does not return resultset as per JDBC API specifications
+		this.rs = md.getBestRowIdentifier(this.conn.getCatalog(), null, "returnTypesTest", DatabaseMetaData.bestRowSession, false);
+		
+		int[] types = new int[] { 
+				Types.SMALLINT, // 1.  SCOPE short => actual scope of result
+				Types.CHAR,     // 2. COLUMN_NAME String => column name
+				Types.INTEGER,  // 3. DATA_TYPE int => SQL data type from java.sql.Types
+				Types.CHAR,     // 4. TYPE_NAME String => Data source dependent type name, for a UDT the type name is fully qualified
+				Types.INTEGER,  // 5. COLUMN_SIZE int => precision
+				Types.INTEGER,  // 6. BUFFER_LENGTH int => not used
+				Types.SMALLINT, // 7. DECIMAL_DIGITS short => scale
+				Types.SMALLINT, // 8. PSEUDO_COLUMN short => is this a pseudo column like an Oracle ROWID
+		}; 
+		
+		checkTypes(this.rs, types);
+		
+		// Bug#44683 - getVersionColumns does not return resultset as per JDBC API specifications
+		this.rs = md.getVersionColumns(this.conn.getCatalog(), null, "returnTypesTest");
+		
+		types = new int[] {
+				Types.SMALLINT, // SCOPE short => is not used
+				Types.CHAR,     // COLUMN_NAME String => column name
+				Types.INTEGER,  // DATA_TYPE int => SQL data type from java.sql.Types
+				Types.CHAR,     // TYPE_NAME String => Data source-dependent type name
+				Types.INTEGER,  // COLUMN_SIZE int => precision
+				Types.INTEGER,  // BUFFER_LENGTH int => length of column value in bytes
+				Types.SMALLINT, // DECIMAL_DIGITS short => scale
+				Types.SMALLINT  // PSEUDO_COLUMN short => whether this is pseudo column like an Oracle ROWID 	
+		};
+		
+		checkTypes(this.rs, types);
+		
+		// Bug#44865 - getColumns does not return resultset as per JDBC API specifications
+		this.rs = md.getColumns(this.conn.getCatalog(), null, "returnTypesTest", "foo");
+		
+		types = new int[] {
+				Types.CHAR,     //  1. TABLE_CAT String => table catalog (may be null)
+				Types.CHAR,     //  2. TABLE_SCHEM String => table schema (may be null)
+				Types.CHAR,     //  3. TABLE_NAME String => table name
+				Types.CHAR,     //  4. COLUMN_NAME String => column name
+				Types.INTEGER,  //  5. DATA_TYPE int => SQL type from java.sql.Types
+				Types.CHAR,     //  6. TYPE_NAME String => Data source dependent type name, for a UDT the type name is fully qualified
+				Types.INTEGER,  //  7. COLUMN_SIZE int => column size. For char or date types this is the maximum number of characters, for numeric or decimal types this is precision.
+				Types.INTEGER,  //  8. BUFFER_LENGTH is not used.
+				Types.INTEGER,  //  9. DECIMAL_DIGITS int => the number of fractional digits
+				Types.INTEGER,  // 10. NUM_PREC_RADIX int => Radix (typically either 10 or 2)
+				Types.INTEGER,  // 11. NULLABLE int => is NULL allowed.
+				Types.CHAR,     // 12. REMARKS String => comment describing column (may be null)
+				Types.CHAR,     // 13. COLUMN_DEF String => default value (may be null)
+				Types.INTEGER,  // 14. SQL_DATA_TYPE int => unused
+				Types.INTEGER,  // 15. SQL_DATETIME_SUB int => unused
+				Types.INTEGER,  // 16. CHAR_OCTET_LENGTH int => for char types the maximum number of bytes in the column
+				Types.INTEGER,  // 17. ORDINAL_POSITION int => index of column in table (starting at 1)
+				Types.CHAR,     // 18. IS_NULLABLE String => "NO" means column definitely does not allow NULL values; "YES" means the column might allow NULL values. An empty string means nobody knows.
+				Types.CHAR,     // 19. SCOPE_CATLOG String => catalog of table that is the scope of a reference attribute (null if DATA_TYPE isn't REF)
+				Types.CHAR,     // 20. SCOPE_SCHEMA String => schema of table that is the scope of a reference attribute (null if the DATA_TYPE isn't REF)
+				Types.CHAR,     // 21. SCOPE_TABLE String => table name that this the scope of a reference attribure (null if the DATA_TYPE isn't REF)
+				Types.SMALLINT, // 22. SOURCE_DATA_TYPE short => source type of a distinct type or user-generated Ref type, SQL type from java.sql.Types (null if DATA_TYPE isn't DISTINCT or user-generated REF) 	
+				Types.CHAR, // 23. IS_AUTOINCREMENT String => Indicates whether this column is auto incremented 
+		};
+		
+		checkTypes(this.rs, types);
+
+		// Bug#44868 - getTypeInfo does not return resultset as per JDBC API specifications
+		this.rs = md.getTypeInfo();
+		
+		types = new int[] {
+			Types.CHAR,     //  1. TYPE_NAME String => Type name
+			Types.INTEGER,  //  2. DATA_TYPE int => SQL data type from java.sql.Types
+			Types.INTEGER,  //  3. PRECISION int => maximum precision
+			Types.CHAR,     //  4. LITERAL_PREFIX String => prefix used to quote a literal (may be null)
+			Types.CHAR,     //  5. LITERAL_SUFFIX String => suffix used to quote a literal (may be null)
+			Types.CHAR,     //  6. CREATE_PARAMS String => parameters used in creating the type (may be null)
+			Types.SMALLINT, //  7. NULLABLE short => can you use NULL for this type.
+			Types.BOOLEAN,  //  8. CASE_SENSITIVE boolean=> is it case sensitive.
+			Types.SMALLINT, //  9. SEARCHABLE short => can you use "WHERE" based on this type:
+			Types.BOOLEAN,  // 10. UNSIGNED_ATTRIBUTE boolean => is it unsigned.
+			Types.BOOLEAN,  // 11. FIXED_PREC_SCALE boolean => can it be a money value.
+			Types.BOOLEAN,  // 12. AUTO_INCREMENT boolean => can it be used for an auto-increment value.
+			Types.CHAR,     // 13. LOCAL_TYPE_NAME String => localized version of type name (may be null)
+			Types.SMALLINT, // 14. MINIMUM_SCALE short => minimum scale supported
+			Types.SMALLINT, // 15. MAXIMUM_SCALE short => maximum scale supported
+			Types.INTEGER,  // 16. SQL_DATA_TYPE int => unused
+			Types.INTEGER,  // 17. SQL_DATETIME_SUB int => unused
+			Types.INTEGER   // 18. NUM_PREC_RADIX int => usually 2 or 10 
+		};
+		
+		checkTypes(this.rs, types);
+		
+		// Bug#44869 - getIndexInfo does not return resultset as per JDBC API specifications
+		this.rs = md.getIndexInfo(this.conn.getCatalog(), null, "returnTypesTest", false, false);
+
+		types = new int[] {
+			Types.CHAR,     //  1. TABLE_CAT String => table catalog (may be null)
+			Types.CHAR,     //  2. TABLE_SCHEM String => table schema (may be null)
+			Types.CHAR,     //  3. TABLE_NAME String => table name
+			Types.BOOLEAN,  //  4. NON_UNIQUE boolean => Can index values be non-unique. false when TYPE is tableIndexStatistic
+			Types.CHAR,     //  5. INDEX_QUALIFIER String => index catalog (may be null); null when TYPE is tableIndexStatistic
+			Types.CHAR,     //  6. INDEX_NAME String => index name; null when TYPE is tableIndexStatistic
+			Types.SMALLINT, //  7. TYPE short => index type:
+			Types.SMALLINT, //  8. ORDINAL_POSITION short => column sequence number within index; zero when TYPE is tableIndexStatistic
+			Types.CHAR,     //  9. COLUMN_NAME String => column name; null when TYPE is tableIndexStatistic
+			Types.CHAR,     // 10. ASC_OR_DESC String => column sort sequence, "A" => ascending, "D" => descending, may be null if sort sequence is not supported; null when TYPE is tableIndexStatistic
+			Types.INTEGER,  // 11. CARDINALITY int => When TYPE is tableIndexStatistic, then this is the number of rows in the table; otherwise, it is the number of unique values in the index.
+			Types.INTEGER,  // 12. PAGES int => When TYPE is tableIndexStatisic then this is the number of pages used for the table, otherwise it is the number of pages used for the current index.
+			Types.CHAR      // 13. FILTER_CONDITION String => Filter condition, if any. (may be null) 	
+		};
+		
+		checkTypes(this.rs, types);
+
+		// Bug#44867 - getImportedKeys/exportedKeys/crossReference doesn't have correct type for DEFERRABILITY
+		this.rs = md.getImportedKeys(this.conn.getCatalog(), null, "returnTypesTest");
+		
+		types = new int[] {
+			Types.CHAR,     // PKTABLE_CAT String => primary key table catalog being imported (may be null)
+			Types.CHAR,     // PKTABLE_SCHEM String => primary key table schema being imported (may be null)
+			Types.CHAR,     // PKTABLE_NAME String => primary key table name being imported
+			Types.CHAR,     // PKCOLUMN_NAME String => primary key column name being imported
+			Types.CHAR,     // FKTABLE_CAT String => foreign key table catalog (may be null)
+			Types.CHAR,     // FKTABLE_SCHEM String => foreign key table schema (may be null)
+			Types.CHAR,     // FKTABLE_NAME String => foreign key table name
+			Types.CHAR,     // FKCOLUMN_NAME String => foreign key column name
+			Types.SMALLINT, // KEY_SEQ short => sequence number within a foreign key
+			Types.SMALLINT, // UPDATE_RULE short => What happens to a foreign key when the primary key is updated:
+			Types.SMALLINT, // DELETE_RULE short => What happens to the foreign key when primary is deleted
+			Types.CHAR,     // FK_NAME String => foreign key name (may be null)
+			Types.CHAR,     // PK_NAME String => primary key name (may be null)
+			Types.SMALLINT  // DEFERRABILITY short => can the evaluation of foreign key constraints be deferred until commit 
+		};
+		
+		checkTypes(this.rs, types);
+		
+		this.rs = md.getExportedKeys(this.conn.getCatalog(), null, "returnTypesTest");
+		
+		types = new int[] {
+			Types.CHAR,     // PKTABLE_CAT String => primary key table catalog being imported (may be null)
+			Types.CHAR,     // PKTABLE_SCHEM String => primary key table schema being imported (may be null)
+			Types.CHAR,     // PKTABLE_NAME String => primary key table name being imported
+			Types.CHAR,     // PKCOLUMN_NAME String => primary key column name being imported
+			Types.CHAR,     // FKTABLE_CAT String => foreign key table catalog (may be null)
+			Types.CHAR,     // FKTABLE_SCHEM String => foreign key table schema (may be null)
+			Types.CHAR,     // FKTABLE_NAME String => foreign key table name
+			Types.CHAR,     // FKCOLUMN_NAME String => foreign key column name
+			Types.SMALLINT, // KEY_SEQ short => sequence number within a foreign key
+			Types.SMALLINT, // UPDATE_RULE short => What happens to a foreign key when the primary key is updated:
+			Types.SMALLINT, // DELETE_RULE short => What happens to the foreign key when primary is deleted
+			Types.CHAR,     // FK_NAME String => foreign key name (may be null)
+			Types.CHAR,     // PK_NAME String => primary key name (may be null)
+			Types.SMALLINT  // DEFERRABILITY short => can the evaluation of foreign key constraints be deferred until commit 
+		};
+		
+		checkTypes(this.rs, types);
+		
+		this.rs = md.getCrossReference(this.conn.getCatalog(), null, "returnTypesTest", this.conn.getCatalog(), null, "bar");
+		
+		types = new int[] {
+			Types.CHAR,     // PKTABLE_CAT String => primary key table catalog being imported (may be null)
+			Types.CHAR,     // PKTABLE_SCHEM String => primary key table schema being imported (may be null)
+			Types.CHAR,     // PKTABLE_NAME String => primary key table name being imported
+			Types.CHAR,     // PKCOLUMN_NAME String => primary key column name being imported
+			Types.CHAR,     // FKTABLE_CAT String => foreign key table catalog (may be null)
+			Types.CHAR,     // FKTABLE_SCHEM String => foreign key table schema (may be null)
+			Types.CHAR,     // FKTABLE_NAME String => foreign key table name
+			Types.CHAR,     // FKCOLUMN_NAME String => foreign key column name
+			Types.SMALLINT, // KEY_SEQ short => sequence number within a foreign key
+			Types.SMALLINT, // UPDATE_RULE short => What happens to a foreign key when the primary key is updated:
+			Types.SMALLINT, // DELETE_RULE short => What happens to the foreign key when primary is deleted
+			Types.CHAR,     // FK_NAME String => foreign key name (may be null)
+			Types.CHAR,     // PK_NAME String => primary key name (may be null)
+			Types.SMALLINT  // DEFERRABILITY short => can the evaluation of foreign key constraints be deferred until commit 
+		};
+		
+		checkTypes(this.rs, types);
+	}
+	
+	private final static Map TYPES_MAP = new HashMap();
+	
+	static {
+		Field[] typeFields = Types.class.getFields();
+		
+		for (int i = 0; i < typeFields.length; i++) {
+			System.out.println(typeFields[i].getName() + " -> " + typeFields[i].getType().getClass());
+			
+			if (Modifier.isStatic(typeFields[i].getModifiers())) {
+				try {
+					TYPES_MAP.put(new Integer(typeFields[i].getInt(null)), "java.sql.Types." + typeFields[i].getName());
+				} catch (IllegalArgumentException e) {
+					// ignore
+				} catch (IllegalAccessException e) {
+					// ignore
+				}
+			}
+		}
+	}
+	
+	private void checkTypes(ResultSet rsToCheck, int[] types) throws Exception {
+		ResultSetMetaData rsmd = rsToCheck.getMetaData();
+		assertEquals(types.length, rsmd.getColumnCount());
+		for (int i = 0; i < types.length; i++) {
+			String expectedType = (String)TYPES_MAP.get(new Integer(types[i]));
+			String actualType = (String)TYPES_MAP.get(new Integer(rsmd.getColumnType(i + 1)));
+			assertNotNull(expectedType);
+			assertNotNull(actualType);
+			assertEquals("Unexpected type in column " + (i + 1), expectedType, actualType);
+		}
+	}
+
+	/**
+	 * Bug #43714 - useInformationSchema with DatabaseMetaData.getExportedKeys() throws exception
+	 */
+	public void testBug43714() throws Exception {
+		Connection c_IS = null;
+		try {
+			c_IS = getConnectionWithProps("useInformationSchema=true");
+    		DatabaseMetaData dbmd = c_IS.getMetaData();
+    		rs = dbmd.getExportedKeys("x", "y", "z");
+		} finally {
+			try {
+				c_IS.close();
+			} catch (SQLException ex) {}
+			closeMemberJDBCResources();
+		}
+	}
+	
+	/**
+	 * Bug #41269 - DatabaseMetadata.getProcedureColumns() returns wrong value for column length
+	 */
+	public void testBug41269() throws Exception {
+		createProcedure("bug41269",
+				"(in param1 int, out result varchar(197)) BEGIN select 1, ''; END");
+		try {
+			ResultSet procMD = this.conn.getMetaData()
+							.getProcedureColumns(null, null, "bug41269", "%");
+			assertTrue(procMD.next());
+			assertEquals("Int param length", 10, procMD.getInt(9));
+			assertTrue(procMD.next());
+			assertEquals("String param length", 197, procMD.getInt(9));
+			assertFalse(procMD.next());
+		} finally {
+			closeMemberJDBCResources();
+		}
+	}
+	
+	public void testBug31187() throws Exception {
+		createTable("testBug31187", "(field1 int)");
+		
+		Connection nullCatConn = getConnectionWithProps("nullCatalogMeansCurrent=false");
+		DatabaseMetaData dbmd = nullCatConn.getMetaData();
+		ResultSet dbTblCols = dbmd.getColumns(null, null, "testBug31187", "%");
+		
+		boolean found = false;
+		
+		while (dbTblCols.next()) {
+			String catalog = dbTblCols.getString("TABLE_CAT");
+			String table = dbTblCols.getString("TABLE_NAME");
+			boolean useLowerCaseTableNames = dbmd.storesLowerCaseIdentifiers();
+			
+			if (catalog.equals(nullCatConn.getCatalog()) && 
+					(((useLowerCaseTableNames && "testBug31187".equalsIgnoreCase(table)) || "testBug31187".equals(table)))) {
+				found = true;
+			}
+		}
+		
+		assertTrue("Didn't find any columns for table named 'testBug31187' in database " + this.conn.getCatalog(), found);
+	}
+	
+	public void testBug44508() throws Exception {
+		DatabaseMetaData dbmd = this.conn.getMetaData();
+
+		this.rs = dbmd.getSuperTypes("", "", "");
+		ResultSetMetaData rsmd = this.rs.getMetaData();
+
+		assertEquals("TYPE_CAT", rsmd.getColumnName(1)); // Gives TABLE_CAT
+		assertEquals("TYPE_SCHEM", rsmd.getColumnName(2)); // Gives TABLE_SCHEM
+	}
 }
