@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2002-2007 MySQL AB
+ Copyright  2002-2007 MySQL AB, 2008 Sun Microsystems
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of version 2 of the GNU General Public License as
@@ -52,6 +52,8 @@ import com.mysql.jdbc.NotImplemented;
 import com.mysql.jdbc.ParameterBindings;
 import com.mysql.jdbc.SQLError;
 import com.mysql.jdbc.StringUtils;
+import com.mysql.jdbc.exceptions.MySQLStatementCancelledException;
+import com.mysql.jdbc.exceptions.MySQLTimeoutException;
 
 /**
  * DOCUMENT ME!
@@ -287,12 +289,10 @@ public class StatementsTest extends BaseTestCase {
 	public void testAutoIncrement() throws SQLException {
 		if (!isRunningOnJdk131()) {
 			try {
-				this.stmt = this.conn.createStatement(
-						java.sql.ResultSet.TYPE_FORWARD_ONLY,
-						java.sql.ResultSet.CONCUR_READ_ONLY);
 				this.stmt.setFetchSize(Integer.MIN_VALUE);
+				
 				this.stmt
-						.executeUpdate("INSERT INTO statement_test (strdata1) values ('blah')");
+						.executeUpdate("INSERT INTO statement_test (strdata1) values ('blah')", Statement.RETURN_GENERATED_KEYS);
 
 				int autoIncKeyFromApi = -1;
 				this.rs = this.stmt.getGeneratedKeys();
@@ -766,6 +766,24 @@ public class StatementsTest extends BaseTestCase {
 
 				assertTrue(this.rs.next());
 				assertEquals(1, this.rs.getInt(1));
+				
+				Connection forceCancel = getConnectionWithProps("queryTimeoutKillsConnection=true");
+				Statement forceStmt = forceCancel.createStatement();
+				forceStmt.setQueryTimeout(1);
+				
+				try {
+					forceStmt.execute("SELECT SLEEP(30)");
+					fail("Statement should have been cancelled");
+				} catch (MySQLTimeoutException timeout) {
+					// expected
+				}
+				
+				try {
+					forceCancel.setAutoCommit(true); // should fail too
+				} catch (SQLException sqlEx) {
+					assertTrue(sqlEx.getCause() instanceof MySQLStatementCancelledException);
+				}
+				
 			} finally {
 				if (this.rs != null) {
 					ResultSet toClose = this.rs;
@@ -948,7 +966,7 @@ public class StatementsTest extends BaseTestCase {
 				int insertIdFromGeneratedKeys = Integer.MIN_VALUE;
 
 				this.stmt
-						.executeUpdate("INSERT INTO statement_test (strdata1, strdata2) values ('a', 'a'), ('b', 'b'), ('c', 'c')");
+						.executeUpdate("INSERT INTO statement_test (strdata1, strdata2) values ('a', 'a'), ('b', 'b'), ('c', 'c')", Statement.RETURN_GENERATED_KEYS);
 				this.rs = this.stmt.getGeneratedKeys();
 
 				if (this.rs.next()) {
@@ -1350,7 +1368,7 @@ public class StatementsTest extends BaseTestCase {
 			createTable("testStatementRewriteBatch", "(pk_field INT PRIMARY KEY NOT NULL AUTO_INCREMENT, field1 INT)");
 			props.clear();
 			props.setProperty("rewriteBatchedStatements", "true");
-			props.setProperty("sessionVariables", "max_allowed_packet=1024");
+			props.setProperty("maxAllowedPacket", "1024");
 			multiConn = getConnectionWithProps(props);
 			multiStmt = multiConn.createStatement();
 
@@ -1400,7 +1418,7 @@ public class StatementsTest extends BaseTestCase {
 			createTable("testStatementRewriteBatch", "(pk_field INT PRIMARY KEY NOT NULL AUTO_INCREMENT, field1 INT)");
 			props.setProperty("useServerPrepStmts", j == 0 ? "true" : "false");
 			props.setProperty("rewriteBatchedStatements", "true");
-			props.setProperty("sessionVariables", "max_allowed_packet=1024");
+			props.setProperty("maxAllowedPacket", "1024");
 			multiConn = getConnectionWithProps(props);
 
 			if (!isRunningOnJdk131()) {
@@ -1451,7 +1469,7 @@ public class StatementsTest extends BaseTestCase {
 
 			props.setProperty("useServerPrepStmts", j == 0 ? "true" : "false");
 			props.setProperty("rewriteBatchedStatements", "true");
-			props.setProperty("sessionVariables", "max_allowed_packet=1024");
+			props.setProperty("maxAllowedPacket", "1024");
 			multiConn = getConnectionWithProps(props);
 			pStmt = multiConn.prepareStatement("INSERT INTO rewriteBatchTypes(internalOrder,f1,f2,f3,f4,f5,f6,f7,f8,f9,f10,f11,f12,f13,f14) VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)");
 
@@ -1568,9 +1586,11 @@ public class StatementsTest extends BaseTestCase {
 	
 			if (j == 1) {
 				props.setProperty("continueBatchOnError", "false");
+			} else {
+				props.setProperty("continueBatchOnError", "true");
 			}
 			
-			props.setProperty("sessionVariables", "max_allowed_packet=1024");
+			props.setProperty("maxAllowedPacket", "1024");
 			props.setProperty("rewriteBatchedStatements", "true");
 			multiConn = getConnectionWithProps(props);
 			this.pstmt = multiConn.prepareStatement("INSERT INTO rewriteErrors VALUES (?)");
@@ -1874,7 +1894,7 @@ public class StatementsTest extends BaseTestCase {
 
 	public void testParameterBindings() throws Exception {
 		// Need to check character set stuff, so need a new connection
-		Connection utfConn = getConnectionWithProps("characterEncoding=utf-8");
+		Connection utfConn = getConnectionWithProps("characterEncoding=utf-8,treatUtilDateAsTimestamp=false,autoDeserialize=true");
 
 		java.util.Date now = new java.util.Date();
 
@@ -1905,10 +1925,21 @@ public class StatementsTest extends BaseTestCase {
 		ParameterBindings bindings = ((com.mysql.jdbc.PreparedStatement)this.pstmt).getParameterBindings();
 
 		for (int i = 0; i < valuesToTest.length; i++) {
-			if (bindings.getObject(i + 1) instanceof Number) {
-				assertEquals("For binding " + (i + 1), bindings.getObject(i + 1).toString(), valuesToTest[i].toString());
+			Object boundObject = bindings.getObject(i + 1);
+			
+			if (boundObject == null && valuesToTest[i] == null) {
+				continue;
+			}
+			
+			Class boundObjectClass= boundObject.getClass();
+			Class testObjectClass = valuesToTest[i].getClass();
+			
+			if (boundObject instanceof Number) {
+				assertEquals("For binding #" + (i + 1) + " of class " + boundObjectClass + " compared to " + testObjectClass, boundObject.toString(), valuesToTest[i].toString());
+			} else if (boundObject instanceof Date) {
+				
 			} else {
-				assertEquals("For binding " + (i + 1), bindings.getObject(i + 1), valuesToTest[i]);
+				assertEquals("For binding #" + (i + 1) + " of class " + boundObjectClass + " compared to " + testObjectClass, boundObject, valuesToTest[i]);
 			}
 		}
 	}
